* MS 2013-10-05

/*

This program creates all of the tables, figures, and numbers reported in the texts of:

  - Chetty, Raj, John N. Friedman, and Jonah E. Rockoff. September 2013. "Measuring the Impacts of
		Teachers I: Evaluating Bias in Teacher Value-Added Estimates." NBER WP 19423.
		
  - Chetty, Raj, John N. Friedman, and Jonah E. Rockoff. September 2013. "Measuring the Impacts of
		Teachers II: Teacher Value-Added and Student Outcomes in Adulthood." NBER WP 19424.


The program is organized into the following sections:

	0. Setup Code Block
	1. Data Setup
		* CREATE TEACHER-SCHOOL WEIGHT MATRIX
		* CREATE SCHOOL DISTRICT COLLAPSES
		* IMPORT IRS COLLAPSE
		* VALUE-ADDED ESTIMATION
		* CROSS-CLASS ANALYSIS DATA SETUP
		* SCHOOL DISTRICT DATA COUNTS
	2. Paper 1
		* Tables
		* Figures
		* Appendix Figures
	3. Paper 2
		* Tables
		* Appendix Tables
		* Figures
		* Appendix Figures

Results that do not appear in the tables or figures, and are reported only in the text of the manuscript, are computed
in the code block of the most relevant table or figure.  These results are often labeled "paper only".

*/

*******************************************
****** SETUP CODE BLOCK - ALWAYS RUN ******
*******************************************

version 12

global root /n/chetty/IRS_NYC/empirics
/*
global root /Volumes/chetty/IRS_NYC/empirics
global root Y:/IRS_NYC/empirics
*/

global datadir2 C:/datadir2
global datadir $root/data
global IRSdir ${datadir}/from_IRS
global logdir $root/logs
global figdir $root/figs
global tab $root/tab

global date 040213
global IRSdate 062513

global SCHD_workdate 040913
global SCHD_worktrimdate 042213

global SCHDclasscollapsedate 032613
global SCHDgradecollapsedate 040913

global tfxdate 042213

global crosssec_apptable_date 090413
global summstats_date 070813

*Control vector for baseline value-added model (note that this excludes teacher experience)
global baseline_VAM_controls PREZ* PREO* MPREO* CL* SG* SY* female ///
	age_current lunch miss_lunch ETHN* sped limited_english repeat_grade ///
	repeat_test absences suspensions post99* hon rem enrich mod foreign ///
	YEAR* GRDE*

*Control vector for second-stage regression includes only class-level variables so we can run on collapsed data
global controls CL* SG* SY* hon-foreign YEAR* GRDE*
global par_controls par_everownhome par_evermarried par_everhave401k par_age_birth par_missing par_age_missing par_inc_trim_mean parinc2 parinc3 parinc4 parincm1 parincm2 parincm3 parincm4

* Load necessary ado-files
adopath ++ ${root}/code/adopath
run ${root}/code/binscatter_v5_10.ado
run ${root}/code/prepare_quasi.ado
run ${root}/code/postvam_save_l2score.ado
run ${root}/code/eventstudy_v2_2.ado
run ${root}/code/residualize_middle_math.ado
run ${root}/code/longterm_crossclass_table.ado
run ${root}/code/reshape_longterm_cc_output.ado
run ${root}/code/multi_graph_export.ado

exit

***********************************************
***** CREATE TEACHER-SCHOOL WEIGHT MATRIX *****
***********************************************

* Used for event studies and cross-cohort regs

*Use final teacher list created in create_schd_work.do
*Only contains teachers who show up in our class links data at some point
use teacher year sch using ${datadir}/final_teacher_list_linked_to_students.dta, clear
tsset teacher year

* Generate indicator for whether the teacher is new to teaching in district.
* 	note: we could define this for 1989 using experience = 0, but we cannot define new to school in 1989
bysort teacher (year): gen new_to_district=_n==1 if year>1989

* Generate indicator for whether the teacher is new to the school but not to teaching in the district.
*	note: if the teacher taught previously in the school, left, and came back, we still consider them "new"
gen new_to_school=new_to_district==0 & sch~=l.sch if year>1989

* Attrition indicators (teacher-year)
bysort teacher (year): gen switch_district=teacher~=teacher[_n+1] if year<2009

* School switch indicator (teacher-year)
gen switch_school=switch_district==0 & sch~=f.sch if year<2009


*MERGE ON ENROLLMENT DATA BY TEACHER BY SCHOOL-YEAR-GRADE-MATH
*	note that we use joinby to create every pairwise combination of sch year with teacher dataset, so each teacher in any sch and year will appear in every sch-grade-subject-year cell for that sch year
*	also note: Enrollment data was created in create_schd_work.do
joinby sch year using ${datadir}/sch_grade_enrollments.dta

merge 1:1 teacher year grade math using ${datadir}/teacher_enrollments.dta
g temp = (_merge==3)
bys teacher year: egen in_class_data = max(temp)
drop _merge temp

*Set number of students to 0 in sch-grade-subject-year cells where the teacher is teaching no students but is found in the class links data in that year
replace n_students = 0 if in_class_data==1 & n_students==.

*Define n_rpool_taught as the total number of students
bys sch grade year math: egen n_rpool_taught = sum(n_students)

*Completely drop school-grade-year-subject cells where we have no info on teachers (n_rpool_taught==0)
drop if n_rpool_taught==0

*Drop teachers not linked to students in rpools where we have some info on teachers
g teach_wt = n_students/n_rpool
drop if teach_wt==0 | teach_wt==.

* GRADE SWITCH INDICATOR (NOTE: TEACHER-YEAR HERE--ANY GRADE SWITCH FOR T'S WITH MORE THAN ONE GRADE)
* LOGIC IS TO SORT EACH TEACHER WITHIN SCHOOL AND GRADE, THEN LOOK FOR ANY BREAKS IN TIME
* OR THE LAST OCCURENCE IN THE GRADE (IF THE TEACHER DOES NOT LEAVE THE SCHOOL OR DISTRICT)
bysort sch math grade: egen maxyear=max(year)
bysort sch math grade: egen minyear=min(year)
bysort teacher sch math grade (year): gen switch_grade= (year!=year[_n+1]-1 | _n==_N) & switch_school==0 & switch_district==0 & year<maxyear if year<2009
bysort teacher sch math grade (year): gen new_to_grade= (year!=year[_n-1]+1 | _n==1) & new_to_school==0 & new_to_district==0 & year>minyear if year>1989
drop maxyear minyear

sum switch_district switch_school switch_grade if year<2009

* Define an indicator for whether a rookie shows up in S-G-Y-M cell
bys sch grade year math: egen has_true_rookie = max(new_to_district)
		
* Define an indicator for whether a teacher new to the school shows up in S-G-Y-M cell
bys sch grade year math: egen has_sch_rookie = max(new_to_school)

save $datadir/teacher_school_weights, replace



**********************************************
****** CREATE SCHOOL DISTRICT COLLAPSES ******
**********************************************


*** Step 1: Create SCHD class-level collapse (PRODUCES SCHD_class_year_collapse data) 

use ${datadir}/schd_work_${SCHD_workdate}.dta if class~=.&sample_to_keep==1, clear

*Rename leads and lags
rename l3_z_score l3_score
rename l4_z_score l4_score
rename f3_z_score f3_score
rename f4_z_score f4_score

bys sch year math class_id: egen f_score_count = count(f_score)
by sch year math class_id: egen f2_score_count = count(f2_score)
by sch year math class_id: egen f3_score_count = count(f3_score)
by sch year math class_id: egen f4_score_count = count(f4_score)
by sch year math class_id: egen l_score_count = count(PREZl_score)
by sch year math class_id: egen l2_score_count = count(l2_score)
by sch year math class_id: egen l3_score_count = count(l3_score)
by sch year math class_id: egen l4_score_count = count(l4_score)
by sch year math class_id: egen other_count = count(other)

* Add gain measures
g gain_t=(score-PREZl_score)
g gain_t_plus1=(f_score-score)

*Class level average of remaining student-level controls
sort class
foreach vary of varlist matchable score other gain_t gain_t_plus1 f_score f2_score f3_score f4_score PREZl_score l2_score l3_score l4_score PREOl_other {
	by class: egen mean_`vary'=mean(`vary')
}
rename mean_PREZl_score mean_l_score

drop matchable score other f_score f2_score f3_score l2_score l3_score l4_score

g l96 = (year-grade)<=1996
bys sch year math class_id: egen any_l96 = max(l96)
drop l96

g l97 = (year-grade)<=1997
bys sch year math class_id: egen any_l97 = max(l97)
drop l97


*Because grade variable varies across students in class, use modal_grade
drop grade
rename modal_grade grade

* Drop individual-level variables from the class-level collapse
drop sped limited_english female ethnicity combined_z_score test_grade lunch miss_lunch ///
    PREO* MPREO* repeat_grade age09 ETHN* post99_sped post99_limited_eng age_current test_district_id test_school_number school_number ///
    student_grade student_pob test_flag_switch_schools prior_test_grade enrolled-school_days_enrolled_total orig_id7 observation_to_keep prior_grade repeat_test ///
    PREZ* stuid l5_z_score l6_z_score f4_score f5_z_score f6_z_score f7_z_score absences suspensions homeroom_id homeroom_teacher_id7 homeroom_teacher_id6 future_tgrade future_repeat rpool gain_t gain_t_plus1

* Collapse to a single obs per class
bys class: keep if _n==1
sort class

save ${datadir}/SCHD_class_year_collapse_${SCHDclasscollapsedate}.dta, replace


*** Step 2: Create School-Grade-Year-level collapse

use ${datadir}/schd_work_${SCHD_workdate}.dta if sch~=.&grade~=.&sample_to_keep==1, clear

*Rename leads and lags
rename l3_z_score l3_score
rename l4_z_score l4_score
rename f3_z_score f3_score

replace CLass_size=. if CLass_size>50
drop teacher teacher_id6 class class_id homeroom_id homeroom_teacher_id7 homeroom_teacher_id6 hon rem enrich mod foreign flag_homeroom flag_sped t_exp_reg TEXP* sample_to_keep

*School-grade-cohort-subject level average of remaining student-level controls
foreach vary of varlist matchable score other f_score f2_score f3_score PREZl_score l2_score l3_score l4_score lunch sped repeat_grade PREOl_other CLass_size {
	bys sch grade year math: egen mean_`vary'=mean(`vary')
}
drop matchable stuid f_score f2_score f3_score PREZl_score l2_score l3_score l4_score score other lunch sped repeat_grade CLass_size

rename mean_PREZl_score mean_l_score

g l96 = (year-grade)<=1996
g l97 = (year-grade)<=1997

*School size
bys sch grade year math: g SGYsize=_N
keep if SGYsize>=10

* Drop variables that are not constant in this collapse
drop PREO* MPREO* ETHN* SGPO* SGPZ* CL* PREZ* ///
     test_district_id district_id test_school_number school_number limited_english student_grade female ethnicity student_pob combined_z_score l5_z_score l6_z_score f4_z_score f5_z_score f6_z_score f7_z_score test_grade test_flag_switch_schools prior_test_grade absences suspensions enrolled start end test_date discharged tested_school late_enrollment early_discharge class_days_enrolled_total school_days_enrolled_total evercourse orig_id7 prior_grade repeat_test future_tgrade future_repeat miss_lunch post99_sped post99_limited_eng age_current age09 orig_class_size modal_grade t_exp_reg_full

* Collapse
bys sch grade year math: keep if _n==1
sort sch grade year math
save ${datadir}/SCHD_sch_gr_year_collapse_${SCHDgradecollapsedate}, replace



*******************************
***** IMPORT IRS COLLAPSE *****
*******************************

***Step 1: merge IRS class-level data onto SCHD class-level data

*First import and clean up IRS class-level data
tempfile class_collapse
set more off
!${root}/code/odyssey_stata_call_stattransfer.sh ${IRSdir}/class_collapse_masked_${IRSdate}.sas7bdat `class_collapse'.dta -y
use `class_collapse'.dta, clear

rename score IRS_score
rename count IRS_count
cap drop grade

*Now merge onto SCHD collapsed data
merge 1:1 sch year class_id math using ${datadir}/SCHD_class_year_collapse_${SCHDclasscollapsedate}.dta
compress female

keep if _merge==3
drop _merge

* Perform trimming on the outside
set more off
do ${root}/code/irs/irs_clean_final.do
drop if class_id==""

order sch year class_id math
sort sch year class_id math

*Test if IRS and SCHD collapses match (if they don't, there's a problem, don't save the file)
assert IRS_count==CLass_size
assert abs(IRS_score-mean_score)<10^-6 | ( missing(IRS_score) & missing(mean_score) )

* Check that pred not missing iff actual not missing
assert predcoll20_nocontrols==. if college20==.
assert predcoll20_nocontrols!=. if college20!=.

assert predcwage20_nocontrols==. if college20==.
assert predcwage20_nocontrols!=. if college20!=.


save ${datadir}/IRS_SCHD_class_collapse_${IRSdate}.dta, replace



***Step 2: merge IRS school-grade-level data onto SCHD school level

*First import and clean up IRS school-grade-year data
tempfile grade_collapse
set more off
!${root}/code/odyssey_stata_call_stattransfer.sh ${IRSdir}/grade_collapse_masked_${IRSdate}.sas7bdat `grade_collapse'.dta -y
use `grade_collapse'.dta, clear

rename score IRS_score
rename count IRS_count
rename grade_orig grade

*Now merge onto SCHD collapsed data
merge 1:1 sch grade year math using ${datadir}/SCHD_sch_gr_year_collapse_${SCHDgradecollapsedate}.dta
compress female

keep if _merge==3
drop _merge

set more off
do ${root}/code/irs/irs_clean_final.do

drop if sch==.|grade==.
order sch grade year math
sort sch grade year math

*Test if IRS and SCHD collapses match (if they don't, there's a problem, don't save the file)
assert IRS_count==SGYsize
assert abs(IRS_score-mean_score)<10^-6 | ( missing(IRS_score) & missing(mean_score) )

* Check that pred not missing iff actual not missing
assert pred_score_nocontrols==. if mean_score==.
assert pred_score_nocontrols!=. if mean_score!=.

assert predcoll20_nocontrols==. if college20==.
assert predcoll20_nocontrols!=. if college20!=.

assert predcwage20_nocontrols==. if college20==.
assert predcwage20_nocontrols!=. if college20!=.


save ${datadir}/IRS_SCHD_sch_gr_yr_collapse_${IRSdate}.dta, replace





**************************************************************************************
***********************  VALUE-ADDED ESTIMATION **************************************
**************************************************************************************

*** Generate schd_work_trim dataset
*	--> subset of schd_work dataset that contains obs that have test scores and have other conditions needed for value-added model estimation

global base_vars stuid year sch modal_grade grade test_grade math teacher teacher_id6 t_exp_reg t_exp_reg_full class class_id score f_score f2_score f3_z_score f4_z_score l2_score l3_z_score l4_z_score flag_homeroom flag_sped observation_to_keep sample_to_keep CLass_size rpool middle
global controls_to_load PREZ* PREO* MPREO* CL* SG* SY* female age_current lunch miss_lunch ETHN* sped limited_english repeat_grade repeat_test absences suspensions post99* hon rem enrich mod foreign TEXP*

use ${base_vars} ${controls_to_load} using ${datadir}/schd_work_${SCHD_workdate} if score~=.&class~=.&teacher~=.&sample_to_keep==1, clear

rename l4_z_score l4_score
rename l3_z_score l3_score
rename f3_z_score f3_score
rename f4_z_score f4_score

*Restrict to grades with lag score data
keep if inrange(grade,4,8)

*Require at least 7 kids with non-missing scores and lagged scores
egen miss = rowmiss(score PREZl* PREOl*)
g nomiss = miss==0
bys class: egen n_tested = sum(nomiss)

count if n_tested < 7
scalar __numerator=r(N)
count
scalar __denominator=r(N)

file open lt7 using ${tab}/paper1/paperonly_counts_VAobsdropped_lt7_tfxdate${tfxdate}.csv, write text replace
file write lt7 "Fraction of student-subject-year observations dropped from VA sample because fewer than 7 students in class had score & lagged score data:" _n
file write lt7 (__numerator/__denominator)
file close lt7


keep if n_tested>=7
keep if miss==0
drop miss nomiss n_tested

*Year and grade dummies
char year[omit] 2009
xi, prefix(YEAR) i.year
char grade[omit] 4
xi, prefix(GRDE) i.grade

egen sch_yr = group(sch year)

g cohort=year-grade
egen sch_cohort = group(sch cohort)

* Label middle and math
label define middle 0 elementary 1 middle
label define math 0 reading 1 math
label values middle middle
label values math math

save ${datadir}/schd_work_trim_${SCHD_worktrimdate}.dta, replace





***** CONSTRUCT BASELINE TFX ESTIMATES TO USE IN WHOLE PAPER
use ${datadir}/schd_work_trim_${SCHD_worktrimdate}.dta, clear

vam score, teacher(teacher) year(year) class(class) output_addvars(sch class_id math) ///
	controls(${baseline_VAM_controls}) output(${datadir}/tfx/tfx_${tfxdate}) ///
	tfx_resid(teacher) by(middle math) driftlimit(7) quasi ///
	data(merge tv score_r)


* save score_r data
keep stuid year class_id teacher sch math middle score_r tv sch_cohort
save ${datadir}/tfx/score_r_${tfxdate}, replace


** Construct teacher-year-math version of tfx for quasi-experiments
use ${datadir}/tfx/tfx_${tfxdate}, clear

collapse (mean) tv*, by (teacher year math)
sort teacher year math
order teacher year math

save ${datadir}/tfx/tfx_${tfxdate}_tym, replace

** Paper only: output correlation between English and math VA for elem teachers
use ${datadir}/tfx/tfx_${tfxdate}, clear
collapse (mean) tv*, by (teacher year math middle)

egen grp=group(teacher year middle)
tsset grp math

corr tv l.tv if middle==0

file open subjectcorr using ${tab}/paper1/paperonly_readmathVAcorr_elem_tv_tfxdate${tfxdate}.csv, write text replace
file write subjectcorr "Correlation between English and math VA for elementary school teachers:" _n
file write subjectcorr (r(rho))
file close subjectcorr

** Paper only: output fraction of student-subject-year obs with controls but without tv
use ${datadir}/tfx/score_r_${tfxdate}, clear

* Drop if missing controls
drop if missing(score_r)

* Compute fraction
count if missing(tv)
scalar __numerator=r(N)

count
scalar __denominator=r(N)

* Check that all are due to having only one year of teacher obs
bys teacher math middle: egen min_year=min(year)
bys teacher math middle: egen max_year=max(year)
gen oneyear=(min_year==max_year)
assert missing(tv) if oneyear==1
assert oneyear==1 if missing(tv)

* Output to file
file open no_tv using ${tab}/paper1/paperonly_fraction_without_leaveout_tv_tfxdate${tfxdate}.csv, write text replace
file write no_tv "Fraction of student-subject-year observations with full control vector but with no leave-out tv measure because teacher only observed for one year:" _n
file write no_tv (__numerator/__denominator)
file close no_tv


** Paper only: output first year test scores of teachers who leave after 1 year vs. whole sample of teachers
use ${datadir}/schd_work_trim_${SCHD_worktrimdate}.dta, clear

* Merge on score_r and tv
merge 1:1 stuid year class_id teacher math using ${datadir}/tfx/score_r_${tfxdate}, keep(2 3) assert(3) keepusing(score_r tv) nogen

* Drop if not in VA sample
drop if missing(score_r)

* Keep first year 
bys teacher math middle: egen min_year=min(year)
bys teacher math middle: egen max_year=max(year)
keep if year==min_year

collapse score score_r tv, by(teacher middle math)

* Output first year scores to csv
file open firstyear using ${tab}/paper1/paperonly_scores_firstyear_teaching_tfxdate${tfxdate}.csv, write text replace

sum score_r if missing(tv)
file write firstyear "Average test scores in the first year for teachers who leave after one year:" _n (r(mean)) _n _n

sum score_r
file write firstyear "Average test scores in the first year for all teachers:" _n (r(mean)) _n _n

file close firstyear



***** PAPER 1, TABLE 2
* Code is up here because the results of the quadratic fit are used for the generation of tv_sd in the "CROSS-CLASS ANALYSIS DATA SETUP" section.

insheet using ${datadir}/tfx/tfx_${tfxdate}_variance.csv, comma clear

outsheet using ${tab}/paper1/table2_panelA_tfxdate${tfxdate}.csv, comma replace

*** Estimate cov_sameyear for elementary and output to a csv
gen lag2=lag^2

assert lag[1]==1
assert lag[_N]==.

file open elem_cov_sameyear using ${tab}/paper1/table2_panelB_SD_sameyear_estimate_tfxdate${tfxdate}.csv, write text replace
file write elem_cov_sameyear ",lower bound,quad exp fit,true value" _n

set more off
foreach level in elementary middle {
	foreach subject in reading math {
		* Label
		file write elem_cov_sameyear "`level' `subject',"
		
		* Lower bound
		file write elem_cov_sameyear (sqrt(cov_lag_`level'_`subject'[1]))
		file write elem_cov_sameyear ","
		
		* Quadratic fit
		gen log_cov_lag_`level'_`subject'=log(cov_lag_`level'_`subject')
		reg log_cov_lag_`level'_`subject' lag lag2 if inrange(lag,1,7) [aw=obs_lag_`level'_`subject']
		file write elem_cov_sameyear (sqrt(exp(_b[_cons])))
		file write elem_cov_sameyear ","
		
		* True value
		if ("`level'"=="middle") file write elem_cov_sameyear (sqrt(cov_sameyear_`level'_`subject'[_N]))
		
		file write elem_cov_sameyear _n
	}
}

file close elem_cov_sameyear



***** CONSTRUCT TV ESTIMATES WITH NON-MISSING L2_SCORE
use ${datadir}/schd_work_trim_${SCHD_worktrimdate}.dta, clear

*Restrict to obs with non-missing l2_score to have appropriate sample for l2_score regs comparison
keep if l2_score~=.

vam score, teacher(teacher) year(year) class(class) output_addvars(sch class_id math) ///
	controls(${baseline_VAM_controls}) output(${datadir}/tfx/tfx_l2_score_notmiss_${tfxdate}) ///
	tfx_resid(teacher) by(middle math) driftlimit(7) ///
	data(merge tv score_r)

* save score_r data
postvam_save_l2score, controls(${baseline_VAM_controls}) output(${datadir}/tfx/score_r_l2_score_notmiss_tfxdate${tfxdate}) score_r_l2 l2_score_r



***** Paper only: Construct baseline model with driftlimit(10) as a robustness check
use ${datadir}/schd_work_trim_${SCHD_worktrimdate}.dta, clear
vam score, teacher(teacher) year(year) class(class) output_addvars(sch class_id math) ///
	controls(${baseline_VAM_controls}) output(${datadir}/tfx/tfx_driftlimit10_${tfxdate}) ///
	tfx_resid(teacher) by(middle math) driftlimit(10)
	
* Construct teacher-year-math version
use ${datadir}/tfx/tfx_driftlimit10_${tfxdate}, clear
collapse tv*, by (teacher year math)
sort teacher year math
order teacher year math
	
rename tv tv_drift10

* Merge in baseline VA estimates
merge 1:1 teacher year math using ${datadir}/tfx/tfx_${tfxdate}_tym, assert(3) nogen keepusing(tv)

corr tv tv_drift10

* Output corr to csv
file open corr using ${tab}/paper1/paperonly_driftlimit10_robustness_tfxdate${tfxdate}.csv, write text replace
file write corr "Correlation between driftlimit(7) and driftlimit(10) VA estimates:" _n
file write corr (r(rho))
file close corr

***************************************************************************************
****************** CROSS-CLASS ANALYSIS DATA SETUP ************************************
***************************************************************************************

set more off

*** Get SD of teacher value added
insheet using ${tab}/paper1/table2_panelB_SD_sameyear_estimate_tfxdate${tfxdate}.csv, clear
gen byte middle=(_n>2)
gen byte math=(mod(_n,2)==0)

gen sd_tfx=truevalue
replace sd_tfx=quadexpfit if middle==0

keep v1 sd_tfx middle math
list
drop v1
save ${datadir}/tfx/sd_tfx_${tfxdate}, replace


*Collapse score_r at the class level
use ${datadir}/tfx/score_r_${tfxdate}, clear
collapse (mean) score_r (count) score_r_count=score_r, by(sch year class_id math)

*Load collapsed dataset (only keep grades 4-8 for cross-class analysis b/c we have no lag scores in grade 3)
merge 1:1 sch year class_id math using ${datadir}/IRS_SCHD_class_collapse_${IRSdate}, assert(2 3) nogen
keep if grade>3
order score_r score_r_count, last

foreach var of varlist score_r_count diff_score_rminuspar diff_score_rminuspar_count score_r_withpar score_r_withpar_count {
	replace `var' = . if score_r == .
}

*Merge on teacher effects, constructed above in VAM section 
merge m:1 teacher year math using ${datadir}/tfx/tfx_${tfxdate}_tym.dta, keep(1 3) nogen
compress math

*Generate middle school dummy
g middle = inlist(substr(class_id,1,1),"M","E")==1
gen middle_math=middle*math

*Generate year and grade dummies
char year[omit] 2009
xi, prefix(YEAR) i.year
char grade[omit] 4
xi, prefix(GRDE) i.grade
g cohort=year-grade
egen sch_cohort=group(sch cohort)

ren mean_score score
ren mean_f_score f_z_score
ren mean_f2_score f2_z_score
ren mean_f3_score f3_z_score
ren mean_f4_score f4_z_score
g l_z_score = CLPZl_score
ren mean_l2_score l2_z_score
ren mean_l3_score l3_z_score
ren mean_l4_score l4_z_score
ren mean_other other

forval i=2/4 {
	rename l`i'_score_count l`i'_z_score_count
	rename f`i'_score_count f`i'_z_score_count
}
rename f_score_count f_z_score_count

*Define college attendance rate by school
g temp = college20_count*college20
bys sch: egen temp1 = sum(temp)
bys sch: egen temp2 = sum(college20_count)
g sch_college = temp1/temp2
drop temp temp1 temp2

sum sch_college [w=CLass_size],d

file open median_sch_college using ${tab}/paper2/paperonly_median_sch_college_irsdate${IRSdate}.csv, write text replace
file write median_sch_college "Median sch_college," (r(p50))
file close median_sch_college

gen high_sch_college=(sch_college>r(p50)) if !missing(sch_college)

*Generate Jacob-Levitt (2003) proxy for teacher cheating
bysort math grade year: egen rank_t=rank(mean_gain_t)
bysort math grade year: egen maxrank_t=max(rank_t)
replace rank_t=rank_t/maxrank_t

bysort math grade year: egen rank_t_plus1=rank(mean_gain_t_plus1)
bysort math grade year: egen maxrank_t_plus1=max(rank_t_plus1)
replace rank_t_plus1=rank_t_plus1/maxrank_t_plus1

gen levitt_score = rank_t^2 + (1 - rank_t_plus1)^2
drop rank_t maxrank_t rank_t_plus1 maxrank_t_plus1

sum levitt_score if tv~=. & teacher~=. & class~=., d
g outlier=levitt_score>=r(p95) & levitt_score<. if teacher~=. & class~=. & tv~=.

bys teacher: egen count_outlier=sum(outlier)
g flag_levitt = count_outlier>1 if count_outlier<.

* Output stats on Jacob-Levitt proxy
file open levitt_gains using ${tab}/paper2/paperonly_levittproxy_gain_loss_irsdate${IRSdate}.csv, write text replace

sum mean_gain_t if outlier==1
file write levitt_gains "Gain in year t," (r(mean)) _n

sum mean_gain_t_plus1 if outlier==1
file write levitt_gains "Loss in year t+1," (r(mean)) _n

file close levitt_gains

* Generate standardized tv
merge m:1 middle math using ${datadir}/tfx/sd_tfx_${tfxdate}, assert(3) nogen
gen tv_sd=tv/sd_tfx

* Generate percentile of tv by middle-math, and output 99% cutoffs
g matched_size = matched*matched_count
g int percent_tv=.

file open tv_insample_cutoffs using ${tab}/paper2/paperonly_tv_insample_cutoffs_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text replace
file write tv_insample_cutoffs "middle,math,tv_sd p99" _n

forvalues middle=0/1 {
	forvalues math=0/1 {
		fastxtile percent_tv_temp=tv_sd if middle==`middle' & math==`math' [w=matched_size], nq(100)
		file write tv_insample_cutoffs "`middle',`math',`r(r99)'" _n
		replace percent_tv=percent_tv_temp if middle==`middle' & math==`math'
		drop percent_tv_temp
	}
}

file close tv_insample_cutoffs

* Outlier trimming for baseline sample
g tv_insample = percent_tv<=99

* Test diff_scorer_minuspar non-missing iff score_r non-missing
assert diff_score_rminuspar==. if score_r==.
assert diff_score_rminuspar!=. if score_r!=.

* Save analysis dataset
save ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}.dta, replace

*** Paper only: Correlate match rates with tv
use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}.dta, clear
qui areg matched tv_sd ${controls} middle math middle_math [w=CLass_size], cluster(sch_cohort) a(cohort)
estimates store match_corr

esttab match_corr using ${tab}/paper2/paperonly_corr_tv_matchrate_irsdate${IRSdate}_tfxdate${tfxdate}.csv, replace keep(tv_sd) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g)) p(fmt(%12.0g))) obslast
estimates clear

*** Construct middle school indicator from cross-class analysis file for use in cross-cohort analyses
use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}.dta, clear
bys sch grade year: egen max_middle = max(middle)
bys sch grade year: keep if _n==1
keep sch grade year max_middle
save ${datadir}/sch_middle_irsdate${IRSdate}.dta, replace


***************************************
***** SCHOOL DISTRICT DATA COUNTS *****
***************************************

use ${datadir}/schd_work_${SCHD_workdate}.dta, clear

file open counts using "${tab}/paper1/paperonly_school_district_data_counts_SCHDworkdate${SCHD_workdate}.csv", write text replace


* Number of students
tempfile codebooklog
log using `codebooklog', text
codebook stuid
log close

file open num_unique using `codebooklog', read text
file read num_unique line
while ("`1'"!="unique" & "`2'"!="values:") & (r(eof)==0) {
	file read num_unique line
	tokenize `"`line'"'
}
file close num_unique

file write counts "Number of students," (`3') _n


* Span of years
sum year
file write counts "Minimum year," (r(min)) _n
file write counts "Maximum year," (r(max)) _n

* Number of tests
keep stuid year math score PREZl_score l2_score l3_z_score l4_z_score l5_z_score l6_z_score f_score f2_score f3_z_score f4_z_score f5_z_score f6_z_score f7_z_score

rename score score10
rename (PREZl_score l2_score l3_z_score l4_z_score l5_z_score l6_z_score) (score9 score8 score7 score6 score5 score4)
rename (f_score f2_score f3_z_score f4_z_score f5_z_score f6_z_score f7_z_score) (score11 score12 score13 score14 score15 score16 score17)

reshape long score, i(stuid year math) j(shiftyear)
replace shiftyear=shiftyear-10

gen testyear=year+shiftyear

bys stuid math testyear: egen error=sd(score)
sum error
assert r(mean)==0

collapse score, by(stuid math testyear)
count if !missing(score)

file write counts "Number of test scores," (r(N)) _n


file close counts


*~*~*~*~*~*~*~*~*~**~*~*~*~*~*~*~
*~*~*~*~*~* PAPER 1 *~*~*~*~*~*~*
*~*~*~*~*~*~*~*~*~**~*~*~*~*~*~*~

*******************
***** Table 1 *****
*******************

* Table 1 is generated at the IRS, except for the t_exp_reg & CLass_size rows.

***** Read in data from IRS log

* Count number of lines in IRS log, set number of obs to number of lines
file open irslog using "${datadir}/from_IRS/summary_stats_${summstats_date}.lst", read
file read irslog line
local lines=1
while (r(eof)==0) {
	file read irslog line
	local ++lines
}
file close irslog

clear
set obs `lines'

* Create vars
gen str var=""
gen float mean=.
gen float sd=.
gen long n=.
gen byte paper=.

local varnum=0
local papernum=1
local blocknum=1

* Process IRS log
file open irslog using "${datadir}/from_IRS/summary_stats_${summstats_date}.lst", read
file read irslog line

set more off
while (r(eof)==0) {
	tokenize ""
	
	* find heading 'Variable' at beginning of line, or end of a section
	while ("`1' `2' `3' `4'"!="Variable Label N Mean") & ("`1' `2' `3'"!="Variable N Mean") & !inlist(trim(`"`line'"'),"Analysis Variable : par_age_birth","Analysis Variable : count_paper1","Analysis Variable : count_paper2") {
		file read irslog line
		tokenize `"`line'"'
	}
	
	if (trim(`"`line'"')=="Analysis Variable : par_age_birth") {
		* augment block counter
		local ++blocknum
	
		* find top of table
		while (substr(trim(`"`line'"'),1,1)!="-") {
			file read irslog line
		}
		
		* read in summary stats
		local ++varnum
		file read irslog line
		qui replace var="par_age_birth_block`blocknum'" in `varnum'
		qui replace n=real(word(`"`line'"',-5)) in `varnum'
		qui replace mean=real(word(`"`line'"',-4)) in `varnum'
		qui replace sd=real(word(`"`line'"',-3)) in `varnum'
		qui replace paper=`papernum' in `varnum'
		
		* restart loop
		continue
	}
	
	if (trim(`"`line'"')=="Analysis Variable : count_paper1") {
		* find top of "count_paper1" table
		while (substr(trim(`"`line'"'),1,1)!="-") {
			file read irslog line
		}
		
		* read in count_paper1 summary stats: Number of subject-school years per student
		local ++varnum
		file read irslog line
		qui replace var="count_paper1" in `varnum'
		qui replace n=real(word(`"`line'"',-5)) in `varnum'
		qui replace mean=real(word(`"`line'"',-4)) in `varnum'
		qui replace sd=real(word(`"`line'"',-3)) in `varnum'
		qui replace paper=`papernum' in `varnum'
		
		* increment paper counter
		local blocknum=1
		local papernum=2
		
		* restart loop
		continue
	}
	
	if (trim(`"`line'"')=="Analysis Variable : count_paper2") {
		* find top of "count_paper2" table
		while (substr(trim(`"`line'"'),1,1)!="-") {
			file read irslog line
		}
		
		* read in count_paper2 summary stats: Number of subject-school years per student
		local ++varnum
		file read irslog line
		qui replace var="count_paper2" in `varnum'
		qui replace n=real(word(`"`line'"',-5)) in `varnum'
		qui replace mean=real(word(`"`line'"',-4)) in `varnum'
		qui replace sd=real(word(`"`line'"',-3)) in `varnum'
		qui replace paper=`papernum' in `varnum'	
	
		* exit loop
		continue, break
	}
	
	* If "Variable" isn't at the front of the line, augment block counter
	if (ltrim(`"`line'"')!=`"`line'"') local ++blocknum

	* advance 2 lines to first summary stats
	file read irslog line
	file read irslog line
	
	* continue until hit end of page, marked by "-------"
	while (substr(trim(`"`line'"'),1,1)!="-") {
		local ++varnum
		if (`blocknum'==1) qui replace var=word(`"`line'"',1) in `varnum'
		else qui replace var=word(`"`line'"',1)+"_block`blocknum'" in `varnum'
		qui replace n=real(word(`"`line'"',-5)) in `varnum'
		qui replace mean=real(word(`"`line'"',-4)) in `varnum'
		qui replace sd=real(word(`"`line'"',-3)) in `varnum'
		qui replace paper=`papernum' in `varnum'
		
		file read irslog line
	}
}
file close irslog

drop if missing(var)

save ${datadir}/summary_stats_from_IRS_${summstats_date}.dta, replace


***** Output csv for Paper 1

* Compute summary stats for t_exp_reg and CLass_size on the outside
use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}.dta, clear

sum t_exp_reg [w=CLass_size]
scalar __texp_mean=r(mean)
scalar __texp_sd=r(sd)
scalar __texp_n=r(sum_w)

sum CLass_size
scalar __classsize_mean=r(mean)
scalar __classsize_sd=r(sd)
scalar __classsize_n=r(N)

* Save to a new dataset
clear
set obs 2

gen str20 var=""
gen float mean=.
gen float sd=.
gen long n=.
gen byte paper=1

replace var="t_exp_reg" in 1
replace mean=__texp_mean in 1
replace sd=__texp_sd in 1
replace n=__texp_n in 1

replace var="CLass_size_classweighted" in 2
replace mean=__classsize_mean in 2
replace sd=__classsize_sd in 2
replace n=__classsize_n in 2

* Append IRS summary stats data
append using ${datadir}/summary_stats_from_IRS_${summstats_date}.dta
keep if paper==1

* Change the denominator on the fraction of obs with parents missing:
* --> report the fraction obs with parents missing out of the total, rather than out of those matched to tax data
list if var=="par_missing"
sum n if var=="CLass_size"
replace mean=((mean*n)+(r(mean)-n))/r(mean) if var=="par_missing"
replace sd=. if var=="par_missing"
replace n=r(mean) if var=="par_missing"
list if var=="par_missing"

* Rename the "blockN" summary stats
drop if inlist(var,"lunch_block2","miss_lunch_block2")
drop if inlist(var,"lunch_block3","lunch_orig_block3","miss_lunch_orig_block3")
drop if var=="par_age_birth_block4"
replace var=subinstr(var,"_block4","_subsample",.)
replace var=subinstr(var,"_block5","_subsample",.)
drop if var=="par_age_birth_block6"
replace var=subinstr(var,"_block7","_subsample",.)

* Output
outsheet using ${tab}/paper1/table1_summstatsdate${summstats_date}.csv, comma replace


***** A few summary stats are generated here to be sent to the IRS to check that they match.

log using ${logdir}/paper1_table1_summarystats_fromoutside.txt, text replace

use ${datadir}/schd_work_trim_${SCHD_worktrimdate}.dta, clear

* Generate minority dummy (black or hispanic)
g minority = CLETHNethnici_3+CLETHNethnici_4

* Mark the sample that was used to compute VA
mark VAsample
markout VAsample teacher year middle math score ${baseline_VAM_controls}

* Compute summary stats at the indiviudal-level
sum score if VAsample
sum female if VAsample 
sum minority if VAsample

* Compute class size summary stat
preserve
collapse (sum) class_size=VAsample, by(sch year class_id math)
sum class_size if class_size>0
restore

* Compute "# of subject-school-years per student" summary stat
collapse (max) VAsample, by(sch year math stuid)
collapse (sum) n_subject_sch_yr=VAsample, by(stuid)
sum n_subject_sch_yr if n_subject_sch_yr>0

log close

*******************
***** Table 2 *****
*******************

* see above in "VALUE-ADDED ESTIMATION" section.
* --> code is up there because the results of the quadratic fit are used for the generation of tv_sd in the "CROSS-CLASS ANALYSIS DATA SETUP" section.


*******************
***** Table 3 *****
*******************

*** Table 3, Col 1
use ${datadir}/tfx/score_r_${tfxdate}, clear
gen middle_math=middle*math

* Merge in tv from the _tym file so that the sample matches correctly
drop tv
merge m:1 teacher year math using ${datadir}/tfx/tfx_${tfxdate}_tym.dta, assert(3) nogen keepusing(tv)

estimates clear
reg score_r tv middle math middle_math, cluster(sch_cohort)
estimates store col1

esttab col* using ${tab}/paper1/table3_col1_irsdate${IRSdate}_tfxdate${tfxdate}.csv, replace keep(tv) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g))) obslast
estimates clear

* Figure 2a (corresponds to Col 1)
binscatter score_r tv, noaddmean controls(middle math middle_math) ///
	xscale(range(-.2 0.23)) ///
	yscale(range(-.2 0.235)) ///
	legend(off) ylabel(,angle(horizontal)) ///
	title("Actual Score", size(medium)) ///
	xtitle("Teacher Value-Added") ///
	ytitle("Score in Year t") /// 
	ylabel(-0.2(0.1)0.2, angle(0))
multi_graph_export using ${figdir}/paper1/fig2a


*** Table 3, Cols 2-3
use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}.dta, clear

* Col 2
reg diff_score_rminuspar tv middle math middle_math [w=diff_score_rminuspar_count], cluster(sch_cohort)
estimates store col2

sum diff_score_rminuspar [w=diff_score_rminuspar_count] if e(sample)
local col2_individuals=`r(sum_w)'

* Figure 2b (corresponds to Col 2)
binscatter diff_score_rminuspar tv [aw=diff_score_rminuspar_count], noaddmean controls(middle math middle_math) ///
	xscale(range(-.2 0.23)) ///
	yscale(range(-.2 0.235)) ///
	legend(off) ylabel(,angle(horizontal)) ///
	title("Predicted Score using Parent Characteristics", size(medium)) ///
	xtitle("Teacher Value-Added") ///
	ytitle("Predicted Score") /// 
	ylabel(-0.2(0.1)0.2, angle(0))
multi_graph_export using ${figdir}/paper1/fig2b

* Col 3
reg score_r_withpar tv middle math middle_math [w=score_r_withpar_count], cluster(sch_cohort)
estimates store col3

sum score_r_withpar [w=score_r_withpar_count] if e(sample)
local col3_individuals=`r(sum_w)'

* Output regressions
esttab col* using ${tab}/paper1/table3_col23_irsdate${IRSdate}_tfxdate${tfxdate}.csv, replace keep(tv) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g))) obslast
estimates clear

* Output number of individuals (i.e weighted N)
file open col23 using ${tab}/paper1/table3_col23_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text append
file write col23 "N_individuals,`col2_individuals',`col3_individuals'"
file close col23

* Paper only: Parent characteristic bias calcs
file open biascalc using ${tab}/paper1/paperonly_table3_bias_calcs_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text replace

qui reg diff_score_rminuspar middle math middle_math [w=diff_score_rminuspar_count]
predict diff_r if e(sample), r

sum diff_r [w=diff_score_rminuspar_count]
file write biascalc "The standard deviation of class-average predicted score residuals based on parent characteristics is:" _n
file write biascalc (r(sd)) _n

reg score_r diff_r [w=diff_score_rminuspar_count], cluster(sch_cohort)
file write biascalc "The F-statistic on the parent characteristics in the regression of test score residuals on residualized parent characteristics (run at the classroom level) is:" _n
file write biascalc (e(F)) _n

qui reg tv middle math middle_math [w=diff_score_rminuspar_count]
predict tv_r if e(sample), r

reg diff_score_rminuspar tv middle math middle_math [w=diff_score_rminuspar_count], cluster(sch_cohort)
scalar __coeff=_b[tv]

corr tv_r diff_r [w=diff_score_rminuspar_count]
file write biascalc "The correlation of class-average predicted score residuals based on parent characteristics and VA estimates is:" _n
file write biascalc (r(rho)) _n
file write biascalc "If this correlation were 1 instead then the bias due to sorting on parent characteristics would be:" _n
file write biascalc (__coeff/r(rho)) _n
file close biascalc

*** Table 3, Col 4
use ${datadir}/tfx/score_r_l2_score_notmiss_tfxdate${tfxdate}, clear
gen middle_math=middle*math
gen diff_score_l2score = score_r - score_r_l2

* Col 4
reg diff_score_l2score tv middle math middle_math, cluster(sch_cohort)
estimates store col4

esttab col* using ${tab}/paper1/table3_col4_irsdate${IRSdate}_tfxdate${tfxdate}.csv, replace keep(tv) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g))) obslast
estimates clear

* Figure 2c (corresponds to Col 4)
binscatter diff_score_l2score tv, noaddmean controls(middle math middle_math) ///
	xscale(range(-.2 0.23)) ///
	yscale(range(-.2 0.235)) ///
	legend(off) ylabel(,angle(horizontal)) ///
	title("Predicted Score using Year t-2 Score", size(medium)) ///
	xtitle("Teacher Value-Added") ///
	ytitle("Predicted Score") /// 
	ylabel(-0.2(0.1)0.2, angle(0))
multi_graph_export using ${figdir}/paper1/fig2c


* Paper only: Twice lagged score bias calcs

collapse (mean) score_r diff_score_l2score tv (count) diff_score_l2score_count=diff_score_l2score, by(sch year class_id middle math middle_math)

file open biascalc using ${tab}/paper1/paperonly_table3_bias_calcs_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text append
file write biascalc _n _n

qui reg diff_score_l2score middle math middle_math [w=diff_score_l2score_count]
predict diff_r if e(sample), r

sum diff_r [w=diff_score_l2score_count]
file write biascalc "The standard deviation of class-average predicted score residuals based on twice lagged scores is:" _n
file write biascalc (r(sd)) _n

qui reg tv middle math middle_math [w=diff_score_l2score_count]
predict tv_r if e(sample), r

reg diff_score_l2score tv middle math middle_math [w=diff_score_l2score_count]
scalar __coeff=_b[tv]

corr tv_r diff_r [w=diff_score_l2score_count]
file write biascalc "The correlation of class-average predicted score residuals based on twice lagged scores and VA estimates is:" _n
file write biascalc (r(rho)) _n
file write biascalc "If this correlation were 1 instead then the bias due to sorting on twice lagged scores would be:" _n
file write biascalc (__coeff/r(rho)) _n
file close biascalc


***************
*** Table 4 ***
***************

*** Generate the "teacher weights" and "SCHD_sch_gr_yr" with non-missing TV

** First construct teacher school weights using the class collapse with only those teachers who have non-missing tv
use ${datadir}/SCHD_class_year_collapse_${SCHDclasscollapsedate}, clear
keep sch year grade math teacher CLass_size

merge m:1 teacher year math sch grade using ${datadir}/teacher_school_weights, keepusing(new_to_* switch_*)
compress
keep if _merge==3
drop _merge

merge m:1 teacher year math using ${datadir}/tfx/tfx_${tfxdate}_tym
keep if _merge==3
drop _merge

keep if tv~=.
drop tv*

bys sch year grade math: egen n_rpool = sum(CLass_size)
g teach_wt = CLass_size/n_rpool
save ${datadir}/table4_teacher_school_weights_with_tv_only_tfxdate${tfxdate}, replace


** Second, construct school-grade collapse from class collapse, so we include only those with non-missing tv

*Only include classes where the modal grade is above 3
use ${datadir}/SCHD_class_year_collapse_${SCHDclasscollapsedate} if grade>3, clear

* Merge in pred_score_nocontrols
merge 1:1 sch year class_id math using ${datadir}/IRS_SCHD_class_collapse_${IRSdate}, keepusing(pred_score_nocontrols)
drop if _merge==2
drop _merge

* Merge in tv measure
merge m:1 teacher year math using ${datadir}/tfx/tfx_${tfxdate}_tym
drop if _merge==2
drop _merge

g covered_tv = tv~=.
drop tv*

*NOTE: Install gwtmean package if command below does not work (ssc inst _gwtmean, replace)
bys sch grade year math: egen mean_covered=wtmean(covered_tv), weight(CLass_size)
sum mean_covered,d
sum mean_covered if mean_covered>0,d

*Keep only those classes for which we have tv data - if we don't do this, we are effectively imputing other teachers' tv to the students who are not linked
keep if covered_tv

rename mean_score CLscore
bys sch grade year math: egen mean_score=wtmean(CLscore), weight(CLass_size)

rename mean_other CLother
bys sch grade year math: egen mean_other=wtmean(CLother), weight(CLass_size)

rename pred_score_nocontrols CLpred_score_nocontrols
bys sch grade year math: egen pred_score_nocontrols=wtmean(CLpred_score_nocontrols), weight(CLass_size)

drop mean_l_score
bys sch grade year math: egen mean_l_score=wtmean(CLPZl_score), weight(CLass_size)
bys sch grade year math: egen mean_l_other=wtmean(CLPOl_other), weight(CLass_size)
bys sch grade year math: egen mean_t_exp_reg=wtmean(t_exp_reg), weight(CLass_size)
bys sch grade year math: egen mean_t_exp_full=wtmean(t_exp_reg_full), weight(CLass_size)
bys sch grade year math: egen SGYsize=sum(CLass_size)
keep sch grade year math mean_score mean_other pred_score_nocontrols SGYsize mean_t_exp* mean_l*
bys sch grade year math: keep if _n==1

* Merge in middle school indicator
merge m:1 sch grade year using ${datadir}/sch_middle_irsdate${IRSdate}.dta
assert _merge!=1
drop if _merge==2
drop _merge

save ${datadir}/table4_SCHD_sch_gr_year_collapse_with_tv_only_tfxdate${tfxdate}, replace


*** Analysis

prepare_quasi, tfxfile(${datadir}/tfx/tfx_${tfxdate}_tym) ///
	tch_sch_weights(${datadir}/table4_teacher_school_weights_with_tv_only_tfxdate${tfxdate}) ///
	sch_gr_yr_collapse(${datadir}/table4_SCHD_sch_gr_year_collapse_with_tv_only_tfxdate${tfxdate}) ///
	drop_empty_tv_cells

estimates clear
* Col 1
areg d_mean_score d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(year)
estimates store score_a_year
local coef=string(_b[d_tv_sgm_1],"%9.3f")
local se=string(_se[d_tv_sgm_1],"%9.3f")

* Figure 4a
binscatter d_mean_score d_tv_sgm_1 [aw=SGYsize], legend(off) ///
	ylabel(-0.1(0.05)0.1) ///
	noaddmean absorb(year) ///
	title("Changes in Actual Scores Across Cohorts", size(medium)) ///
	ytitle("Changes in Scores") ///
	xtitle("Changes in Mean Teacher Value-Added") ///
	note("Coefficient = `coef'" "(`se')", position(5) ring(0) size(medsmall)) ///
	xlabel(-0.1(0.05)0.1)
multi_graph_export using ${figdir}/paper1/fig4a_irsdate${IRSdate}_tfxdate${tfxdate}


* Col 2
egen sch_yr = group(sch year)
areg d_mean_score d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(sch_yr)
estimates store score_a_sch_yr

* Col 3
tsset sgm_id year
g d_mean_l_other = d.mean_l_other
g d_mean_l_other2 = d_mean_l_other^2
g d_mean_l_other3 = d_mean_l_other^3
g d_mean_l_score = d.mean_l_score
g d_mean_l_score3 = d_mean_l_score^3
g d_mean_l_score2 = d_mean_l_score^2

areg d_mean_score d_tv_sgm_1 d_mean_l_score* d_mean_l_other* f.d_tv_sgm_1 l.d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(sch_yr)
estimates store score_a_sch_yr_lags

* Col 4
areg d_pred_score_nocontrols d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(sch_yr)
estimates store predscore
local coef=string(_b[d_tv_sgm_1],"%9.3f")
local se=string(_se[d_tv_sgm_1],"%9.3f")

* Figure 4b
binscatter d_pred_score_nocontrols d_tv_sgm_1 [aw=SGYsize], legend(off) ///
	ylabel(-0.1(0.05)0.1) ///
	noaddmean absorb(sch_yr) ///
	title("Changes in Predicted Scores Across Cohorts", size(medium)) ///
	xtitle("Changes in Mean Teacher Value-Added") ///
	ytitle("Changes in Predicted Scores") ///
	note("Coefficient = `coef'" "(`se')", position(5) ring(0) size(medsmall)) ///
	xlabel(-0.1(0.05)0.1)
multi_graph_export using ${figdir}/paper1/fig4b_irsdate${IRSdate}_tfxdate${tfxdate}


esttab * using ${tab}/paper1/table4_irsdate${IRSdate}_tfxdate${tfxdate}.csv, replace keep(d_tv_sgm_1) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g))) obslast
estimates clear

* Col 5
areg d_mean_score d_tv_sgm_1 d_tv_sgm_other [w=SGYsize] if max_middle==1, cluster(sch_cohort) a(year)
estimates store other_mid
local coef=string(_b[d_tv_sgm_other],"%9.3f")
local se=string(_se[d_tv_sgm_other],"%9.3f")

file open pval using ${tab}/paper1/paperonly_table4_col56_pvals_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text replace
file write pval "Table 4 Col 5 p-val," (2 * ttail(e(df_r), abs(_b[d_tv_sgm_other]/_se[d_tv_sgm_other]))) _n
file close pval

* Figure 5a
binscatter d_mean_score d_tv_sgm_other if max_middle==1 [aw=SGYsize], controls(d_tv_sgm_1) absorb(year) ///
	reportreg legend(off) ///
	ylabel(-0.1(0.05)0.1) ///
	noaddmean ///
	title("Changes in Other-Subject Scores Across Cohorts" "Middle Schools Only", size(medium)) ///
	xtitle("Changes in Mean Teacher Value-Added") ///
	ytitle("Changes in Other-Subject Scores") ///
	note("Coefficient = `coef'" "(`se')", position(5) ring(0) size(medsmall)) ///
	xlabel(-0.1(0.05)0.1)
multi_graph_export using ${figdir}/paper1/fig5a_irsdate${IRSdate}_tfxdate${tfxdate}

* Col 6
areg d_mean_score d_tv_sgm_1 d_tv_sgm_other [w=SGYsize] if max_middle==0, cluster(sch_cohort) a(year)
estimates store other_elem
local coef=string(_b[d_tv_sgm_other],"%9.3f")
local se=string(_se[d_tv_sgm_other],"%9.3f")

file open pval using ${tab}/paper1/paperonly_table4_col56_pvals_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text append
file write pval "Table 4 Col 6 p-val," (2 * ttail(e(df_r), abs(_b[d_tv_sgm_other]/_se[d_tv_sgm_other]))) _n
file close pval

* Figure 5b
binscatter d_mean_score d_tv_sgm_other if max_middle==0 [aw=SGYsize], controls(d_tv_sgm_1) absorb(year) ///
	reportreg legend(off) ///
	ylabel(-0.1(0.05)0.1) ///
	noaddmean ///
	title("Changes in Other-Subject Scores Across Cohorts" "Elementary Schools Only", size(medium)) ///
	xtitle("Changes in Mean Teacher Value-Added") ///
	ytitle("Changes in Other-Subject Scores") ///
	note("Coefficient = `coef'" "(`se')", position(5) ring(0) size(medsmall)) ///
	xlabel(-0.1(0.05)0.1)
multi_graph_export using ${figdir}/paper1/fig5b_irsdate${IRSdate}_tfxdate${tfxdate}


esttab * using ${tab}/paper1/table4_irsdate${IRSdate}_tfxdate${tfxdate}.csv, append keep(d_tv_sgm_other) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g))) obslast
estimates clear


***************
*** Table 5 ***
***************

prepare_quasi, tfxfile(${datadir}/tfx/tfx_${tfxdate}_tym) ///
	tch_sch_weights(${datadir}/table4_teacher_school_weights_with_tv_only_tfxdate${tfxdate}) ///
	sch_gr_yr_collapse(${datadir}/table4_SCHD_sch_gr_year_collapse_with_tv_only_tfxdate${tfxdate}) ///
	drop_empty_tv_cells ///
	entry_exit
	
* Open file to store mean_covered csv
file open meancovered using ${tab}/paper1/table5_bottomrow_meancovered_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text replace
file write meancovered "Fraction with non-missing VA,"

* Double check that OLS reg matches Table 4, Col 1
set more off
xi: reg d_mean_score d_tv_sgm_1 i.year [w=SGYsize], cluster(sch_cohort)

* Col 1: IV with teacher exiters from district or school
gen mean_tv_2yr_f_ds = mean_tv_2yr_f_d + mean_tv_2yr_f_s
set more off
xi: ivreg2 d_mean_score i.year (d_tv_sgm_1 = l.mean_tv_2yr_f_ds) [w=SGYsize], cluster(sch_cohort) first ffirst savefirst
estimates store col1

sum mean_covered_tv if e(sample) [w=SGYsize], meanonly
scalar __mean_cur=r(mean)
sum l.mean_covered_tv if e(sample) [w=SGYsize], meanonly
scalar __mean_lag=r(mean)
file write meancovered ((__mean_cur+__mean_lag)/2) ","

esttab col* using ${tab}/paper1/table5_irsdate${IRSdate}_tfxdate${tfxdate}.csv, replace keep(d_tv_sgm_1) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g))) obslast

* Paper Only: first stage coeff
estimates restore _ivreg2_d_tv_sgm_1

file open firststage using ${tab}/paper1/paperonly_table5iv_firststage_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text replace
file write firststage "var,coef,se,t" _n
file write firststage "l.mean_tv_2yr_f_ds," (_b[l.mean_tv_2yr_f_ds]) "," (_se[l.mean_tv_2yr_f_ds]) "," (_b[l.mean_tv_2yr_f_ds]/_se[l.mean_tv_2yr_f_ds])
file close firststage


*** Cols 2-4: Cut sample by amount of imputed data
estimates clear
prepare_quasi, tfxfile(${datadir}/tfx/tfx_${tfxdate}_tym) ///
	tch_sch_weights(${datadir}/teacher_school_weights) ///
	sch_gr_yr_collapse(${datadir}/SCHD_sch_gr_year_collapse_${SCHDgradecollapsedate})


*Correlation between actual and mean-tv-based VA to report in paper
corr d_tv_sgm_1 d_tv_sgm_mean [w=SGYsize]

file open corr_actual_meantv using ${tab}/paper1/paperonly_corr_actual_meantv_va_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text replace
file write corr_actual_meantv "Correlation between actual and mean-tv-based VA to report in paper:" _n (r(rho)) _n

scalar __drift_var_ub=1-r(rho)^2
file write corr_actual_meantv "Drift accounts for less than (1-corr^2) of the variance in Q_sgt:" _n (__drift_var_ub) _n
file close corr_actual_meantv


* Col 2: Full sample reg
areg d_mean_score d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(year)
estimates store col2

sum mean_covered_tv if e(sample) [w=SGYsize], meanonly
scalar __mean_cur=r(mean)
sum l.mean_covered_tv if e(sample) [w=SGYsize], meanonly
scalar __mean_lag=r(mean)
file write meancovered ((__mean_cur+__mean_lag)/2) ","

file open meancohort using ${tab}/paper1/paperonly_table5_col2_meancohort_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text replace
sum cohort if e(sample) [w=SGYsize], meanonly
file write meancohort (r(mean))
file close meancohort

* Col 3: Cut to sample with <25% imputed data
areg d_mean_score d_tv_sgm_1 [w=SGYsize] if mean_covered_tv>0.75 & l.mean_covered_tv>0.75, cluster(sch_cohort) a(year)
estimates store col3

sum mean_covered_tv if e(sample) [w=SGYsize], meanonly
scalar __mean_cur=r(mean)
sum l.mean_covered_tv if e(sample) [w=SGYsize], meanonly
scalar __mean_lag=r(mean)
file write meancovered ((__mean_cur+__mean_lag)/2) ","

* Col 4: Cut to sample with no imputed data
areg d_mean_score d_tv_sgm_1 [w=SGYsize] if mean_covered_tv==1 & l.mean_covered_tv==1, cluster(sch_cohort) a(year)
estimates store col4

sum mean_covered_tv if e(sample) [w=SGYsize], meanonly
scalar __mean_cur=r(mean)
sum l.mean_covered_tv if e(sample) [w=SGYsize], meanonly
scalar __mean_lag=r(mean)
file write meancovered ((__mean_cur+__mean_lag)/2) ","


* Output
file close meancovered

esttab * using ${tab}/paper1/table5_irsdate${IRSdate}_tfxdate${tfxdate}.csv, append keep(d_tv_sgm_1) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g))) obslast
estimates clear


***************
*** Table 6 ***
***************

use ${datadir}/schd_work_trim_${SCHD_worktrimdate}.dta, clear


***** PREPARATION *****

*** Define list of specifications that are run

global table6filelist "nofe TEXP lagscoreonly lagscoreonly_noschcl_nointer lagscoreonly_own_nointer justdemo nocontrols"

*** Define globals for different groups of baseline control vars

global VAM_score_ind_samesubject "PREZ*"
global VAM_score_ind_othersubject "PREO* MPREO*"

global VAM_demog_ind "ETHN* sped female age_current miss_lunch lunch limited_english repeat_grade repeat_test absences suspensions post99_sped post99_limited_eng"

global VAM_score_class_samesubject "CLPZ*"
global VAM_score_class_othersubject "CLPO* CLMPREO*"

global VAM_demog_class "CLETHN* CLsped CLfemale CLage_current CLmiss_lunch CLlunch CLlimited_english CLrepeat_grade CLrepeat_test CLabsences CLsuspensions CLpost99_sped CLpost99_limited_eng CLass_size hon rem enrich mod foreign"

global VAM_score_schgr_samesubject "SGPZ*"
global VAM_score_schgr_othersubject "SGPO* SYMPREO"

global VAM_demog_schgr "SYETHN* SYsped SYfemale SYage_current SYmiss_lunch SYlunch SYlimited_english SYrepeat_grade SYrepeat_test SYabsences SYsuspensions SYpost99_sped SYpost99_limited_eng"

global VAM_year_grade_fe "YEAR* GRDE*"


* Check that the sum of the grouped control vars equals the number of baseline vars
local count_group=0
foreach group in VAM_score_ind_samesubject VAM_score_ind_othersubject VAM_demog_ind VAM_score_class_samesubject VAM_score_class_othersubject VAM_demog_class VAM_score_schgr_samesubject VAM_score_schgr_othersubject VAM_demog_schgr VAM_year_grade_fe {
	foreach var of varlist $`group' {
		local ++count_group
	}
}

local count_baseline=0
foreach var of varlist $baseline_VAM_controls {
	local ++count_baseline
}

di "Number of vars in baseline VAM control vector: `count_baseline'"
di "Number of vars in VAM control vector groups: `count_group'"
assert `count_baseline'==`count_group'

*** Calculate TV measures

* Use same sample for each tv measure
mark VAsample
markout VAsample teacher year middle math score ${baseline_VAM_controls}
replace score=. if VAsample==0

* 1: "baseline". Just use the generated baseline files rather than recomputing.


* 2: "nofe".  Remove teacher FE but leave baseline controls
vam score,  teacher(teacher) year(year) class(class) output_addvars(sch class_id math) ///
			output(${datadir}/tfx/table6_tfx_nofe_${tfxdate}) ///
			by(middle math) driftlimit(7) quasi data(merge tv score_r) ///
			controls(${baseline_VAM_controls})
			
postvam_save_l2score, output(${datadir}/tfx/table6_l2bias_nofe_tfxdate${tfxdate}) score_r_l2 l2_score_r ///
			controls(${baseline_VAM_controls})
			
* 3: "TEXP". Add teacher experience indicators
vam score, teacher(teacher) year(year) class(class) output_addvars(sch class_id math) ///
	controls(${baseline_VAM_controls} TEXP*) output(${datadir}/tfx/tfx_TEXP_${tfxdate}) ///
	tfx_resid(teacher) by(middle math) driftlimit(7) quasi ///
	data(merge tv score_r)

postvam_save_l2score, output(${datadir}/tfx/table6_l2bias_TEXP_tfxdate${tfxdate}) score_r_l2 l2_score_r ///
			controls(${baseline_VAM_controls} TEXP*)

* 4: "lagscoreonly". Remove all non test controls except grade/year FE
vam score,	teacher(teacher) year(year) class(class) output_addvars(sch class_id math) ///
			output(${datadir}/tfx/table6_tfx_lagscoreonly_${tfxdate}) ///
			tfx_resid(teacher) by(middle math) driftlimit(7) quasi data(merge tv score_r) ///
			controls(${VAM_score_ind_samesubject} ${VAM_score_ind_othersubject} ///
					 ${VAM_score_class_samesubject} ${VAM_score_class_othersubject} ///
					 ${VAM_score_schgr_samesubject} ${VAM_score_schgr_othersubject} ///
					 ${VAM_year_grade_fe} ///
					)
					
postvam_save_l2score, output(${datadir}/tfx/table6_l2bias_lagscoreonly_tfxdate${tfxdate}) score_r_l2 l2_score_r ///
			controls(${VAM_score_ind_samesubject} ${VAM_score_ind_othersubject} ///
					 ${VAM_score_class_samesubject} ${VAM_score_class_othersubject} ///
					 ${VAM_score_schgr_samesubject} ${VAM_score_schgr_othersubject} ///
					 ${VAM_year_grade_fe} ///
					)


* 5: "lagscoreonly_noschcl_nointer" drop class/school lagged scores AND drop grade interactions of own score --> six prior score variables + missing prior other score cubic + grade/year FE
vam score,	teacher(teacher) year(year) class(class) output_addvars(sch class_id math) ///
			output(${datadir}/tfx/table6_tfx_lagscoreonly_noschcl_nointer_${tfxdate}) ///
			tfx_resid(teacher) by(middle math) driftlimit(7) quasi data(merge tv score_r) ///
			controls(PREZl_score PREZl_score2 PREZl_score3 ///
					 PREOl_other PREOl_other2 PREOl_other3 ///
					 MPREO MPREOPREZl_score MPREOPREZl_score2 MPREOPREZl_score3 ///
					 ${VAM_year_grade_fe} ///
					)

postvam_save_l2score, output(${datadir}/tfx/table6_l2bias_lagscoreonly_noschcl_nointer_tfxdate${tfxdate}) score_r_l2 l2_score_r ///
			controls(PREZl_score PREZl_score2 PREZl_score3 ///
					 PREOl_other PREOl_other2 PREOl_other3 ///
					 MPREO MPREOPREZl_score MPREOPREZl_score2 MPREOPREZl_score3 ///
					 ${VAM_year_grade_fe} ///
					)


* 6: "lagscoreonly_own_nointer"
vam score,	teacher(teacher) year(year) class(class) output_addvars(sch class_id math) ///
			output(${datadir}/tfx/table6_tfx_lagscoreonly_own_nointer_${tfxdate}) ///
			tfx_resid(teacher) by(middle math) driftlimit(7) quasi data(merge tv score_r) ///
			controls(PREZl_score PREZl_score2 PREZl_score3 ///
					 ${VAM_year_grade_fe} ///
					)

postvam_save_l2score, output(${datadir}/tfx/table6_l2bias_lagscoreonly_own_nointer_tfxdate${tfxdate}) score_r_l2 l2_score_r ///
			controls(PREZl_score PREZl_score2 PREZl_score3 ///
					 ${VAM_year_grade_fe} ///
					)

* 7: "justdemo". Remove all test controls but include non-test controls + grade/year FE
vam score,	teacher(teacher) year(year) class(class) output_addvars(sch class_id math) ///
			output(${datadir}/tfx/table6_tfx_justdemo_${tfxdate}) ///
			tfx_resid(teacher) by(middle math) driftlimit(7) quasi data(merge tv score_r) ///
			controls(${VAM_demog_ind} ${VAM_demog_class} ${VAM_demog_schgr} ///
					 ${VAM_year_grade_fe} ///
					)
	   
postvam_save_l2score, output(${datadir}/tfx/table6_l2bias_justdemo_tfxdate${tfxdate}) score_r_l2 l2_score_r ///
			controls(${VAM_demog_ind} ${VAM_demog_class} ${VAM_demog_schgr} ///
					 ${VAM_year_grade_fe} ///
					)


* 8: "nocontrols". Remove all controls except grade and year FE
vam score,	teacher(teacher) year(year) class(class) output_addvars(sch class_id math) ///
			output(${datadir}/tfx/table6_tfx_nocontrols_${tfxdate}) ///
			by(middle math) driftlimit(7) quasi data(merge tv score_r) ///
			controls(${VAM_year_grade_fe})
			
postvam_save_l2score, output(${datadir}/tfx/table6_l2bias_nocontrols_tfxdate${tfxdate}) score_r_l2 l2_score_r ///
			controls(${VAM_year_grade_fe})


*** Generate teacher-year-math versions of TV estimates
foreach file in $table6filelist {	
	use ${datadir}/tfx/table6_tfx_`file'_${tfxdate}, clear
	collapse (mean) tv*, by (teacher year math)
	save ${datadir}/tfx/table6_tfx_`file'_${tfxdate}_tym, replace
}


***** ANALYSIS *****

* Merge all the measures together by teacher year and subject

use ${datadir}/tfx/tfx_${tfxdate}_tym, clear
drop tv_*
rename tv tv_1

local i=2
set more off

foreach file in $table6filelist {
        di "${datadir}/tfx/table6_tfx_`file'_${tfxdate}_tym"
	merge 1:1 teacher year math using ${datadir}/tfx/table6_tfx_`file'_${tfxdate}_tym, assert(3) nogen keepusing(tv)
	rename tv tv_`i'
	local i=`i'+1
}


*** Column 1: correlation of different VA specifications with baseline VA specification
	
* Produce and save correlation matrix
correlate tv_*
matrix corr=r(C)
scalar corr_N=r(N)
local dim=rowsof(corr)

file open corr_output using ${tab}/paper1/table6_col1_tfxdate${tfxdate}.csv, write text replace
file write corr_output ",baseline" _n

forvalues i=1/`dim' {
	if (`i'==1) file write corr_output "baseline,"
	else file write corr_output (word("${table6filelist}",`i'-1)) ","

	file write corr_output (corr[1,`i']) _n
}
file write corr_output _n "N tv obs,"
file write corr_output (corr_N) 
file close corr_output


*** Column 2: Cross-cohort quasi-experimental bias estimates

capture erase ${tab}/paper1/table6_col2_tfxdate${tfxdate}.csv

set more off
foreach file in baseline $table6filelist {

		if ("`file'"=="baseline") local tfxfile ${datadir}/tfx/tfx_${tfxdate}_tym
		else local tfxfile ${datadir}/tfx/table6_tfx_`file'_${tfxdate}_tym

		* Note that the required teacher_school_weights are computed in Table 4 above.
		prepare_quasi, tfxfile(`tfxfile') ///
			tch_sch_weights(${datadir}/table4_teacher_school_weights_with_tv_only_tfxdate${tfxdate}) ///
			sch_gr_yr_collapse(${datadir}/table4_SCHD_sch_gr_year_collapse_with_tv_only_tfxdate${tfxdate}) ///
			drop_empty_tv_cells

		estimates clear
		* Note: the number reported in the table is 1 minus this reg coeff.
		areg d_mean_score d_tv_sgm_1 [w=SGYsize], cluster(sch_cohort) a(year)
		estimates store score_a_year
	
		esttab score_a_year using ${tab}/paper1/table6_col2_tfxdate${tfxdate}.csv, append keep(d_tv_sgm_1) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g))) obslast
		estimates clear
}


***************
*** Table 7 ***
***************

* True Tracking.  Note: Cols 3,4,6 use individual-level parent characteristics and are therefore produced at the IRS.

use ${datadir}/schd_work_trim_${SCHD_worktrimdate}.dta, clear

* Merge in score_r
merge 1:1 stuid teacher year class_id math middle using ${datadir}/tfx/score_r_${tfxdate}, assert(3) nogen keepusing(score_r)
gen middle_math=middle*math

* Merge in tv from the _tym file so that the sample matches correctly
merge m:1 teacher year math using ${datadir}/tfx/tfx_${tfxdate}_tym.dta, assert(3) nogen

* Restrict to obs with score_r non-missing, as is done on the inside
drop if missing(score_r)

* Generate minority indicator: hispanic or black
g minority = ETHNethnici_3+ETHNethnici_4
bys sch: egen mean_sch_minority = mean(minority)

* Generate grade 8 scores
gen gr8_score=score if grade==8

estimates clear

* Col 1: Lagged Scores
reg tv PREZl_score, cluster(teacher)
estimates store col1

* CALCULATE MULTIPLICATION FACTOR FOR TABLE 7 - multiply in excel after
merge m:1 middle math using ${datadir}/tfx/sd_tfx_${tfxdate}, assert(3) nogen
gen tv_sd = tv/sd_tfx
sum tv_sd if e(sample)
di "Scaling Factor for True VA on LHS = " 1/r(sd)

* Col 2: Special Education
reg tv sped, cluster(teacher)
estimates store col2

* Paper only: Special education conditional on lagged scores
reg tv sped PREZl_score, cluster(teacher)
estimates store paperonly

* Col 5: Race (minority dummy)
reg tv minority, cluster(teacher)
estimates store col5

* Col 7: School-level race (sch_minority fraction)
reg tv mean_sch_minority, cluster(teacher)
estimates store col7

esttab col* using ${tab}/paper1/table7_col1257_irsdate${IRSdate}_tfxdate${tfxdate}.csv, replace keep(PREZl_score sped minority mean_sch_minority) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g))) r2(%12.0g) obslast
esttab paperonly* using ${tab}/paper1/paperonly_table7_specialed_lagscore_irsdate${IRSdate}_tfxdate${tfxdate}.csv, replace keep(PREZl_score sped) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g))) r2(%12.0g) obslast

estimates clear


*** For text only: decompose the SD of tv and grade 8 scores

file open sd_decomp using ${tab}/paper1/paperonly_SD_decomposition_tv_gr8score.csv, write text replace
file write sd_decomp ",total,between sch,within sch,N,N_sch" _n

** Unadjusted

* Output SDs
xtset sch

xtsum tv
file write sd_decomp "tv,`r(sd)',`r(sd_b)',`r(sd_w)',`r(N)',`r(n)'" _n

xtsum gr8_score
file write sd_decomp "gr8_score,`r(sd)',`r(sd_b)',`r(sd_w)',`r(N)',`r(n)'" _n

** Adjusted for accumulation of TV impacts

* Generate vars
egen student_subject=group(stuid math)
tsset student_subject year

gen tv_gr7=l.tv if grade==8
gen tv_gr6=l2.tv if grade==8
gen tv_gr5=l3.tv if grade==8
gen tv_gr4=l4.tv if grade==8

egen tv_career=rowmean(tv tv_gr7 tv_gr6 tv_gr5 tv_gr4) if grade==8

preserve
insheet using ${tab}/paper2/appxtable10_irsdate062513_tfxdate042213.csv, clear comma
assert abs((coeff[4]+coeff[5])/2 - 0.25)<.015
scalar __allgrades_raise_score = coeff[1]+coeff[2]+coeff[3]+0.25*6
restore

gen gr8_score_corrected=gr8_score - __allgrades_raise_score * tv_career

* Output SDs
xtset sch

xtsum tv_career
file write sd_decomp "tv_career,`r(sd)',`r(sd_b)',`r(sd_w)',`r(N)',`r(n)'" _n

xtsum gr8_score_corrected
file write sd_decomp "gr8_score_corrected,`r(sd)',`r(sd_b)',`r(sd_w)',`r(N)',`r(n)'" _n

file write sd_decomp _n _n "Estimated effect of a 1 unit improvement in teacher quality in all grades K-8 on grade 8 test scores:," _n (__allgrades_raise_score)

file close sd_decomp

************************
*** Appendix Table 1 ***
************************

* Appendix Table 1 is just an illustration of the data structure; it does not contain any results.
* It is made in Excel.


****************
*** Figure 1 ***
****************

*** Figure 1, Panel A: Elementary school autocorrelation vector
insheet using ${datadir}/tfx/tfx_${tfxdate}_variance.csv, comma clear

local driftlimit_elem_reading=corr_lag_elementary_reading[7]
local driftlimit_elem_math=corr_lag_elementary_math[7]

twoway  (scatter corr_lag_elementary_reading lag if inrange(lag,1,7), c(l) sort) ///
	(scatter corr_lag_elementary_reading lag if inrange(lag,8,10), mcolor(navy)) ///
	(scatter corr_lag_elementary_math lag if inrange(lag,0,7), c(l) sort msymbol(T) lcolor(maroon) mcolor(maroon)) ///
	(scatter corr_lag_elementary_math lag if inrange(lag,8,10), msymbol(T) mcolor(maroon)) ///
	(function y=`driftlimit_elem_reading', range(7 10) lcolor(navy)) ///
	(function y=`driftlimit_elem_math', range(7 10) lcolor(maroon)), ///
	ylab(0(0.1)0.5) ///
	graphregion(fcolor(white)) ///
	title("Autocorrelation Vector in Elementary School for English and Math Scores", size(medium)) ///
	xtitle("Years Separation Between Classes") ///
	ytitle("Correlation") ///
	legend(order(1 "English" 3 "Math"))
multi_graph_export using ${figdir}/paper1/fig1a_autocovar_elem

*** Figure 1, Panel B: Middle school autocorrelation vector
local driftlimit_midd_reading=corr_lag_middle_reading[7]
local driftlimit_midd_math=corr_lag_middle_math[7]

twoway  (scatter corr_lag_middle_reading lag if inrange(lag,1,7), c(l) sort) ///
	(scatter corr_lag_middle_reading lag if inrange(lag,8,10), mcolor(navy)) ///
	(scatter corr_lag_middle_math lag if inrange(lag,0,7), c(l) sort msymbol(T) lcolor(maroon) mcolor(maroon)) ///
	(scatter corr_lag_middle_math lag if inrange(lag,8,10), msymbol(T) mcolor(maroon)) ///
	(function y=`driftlimit_midd_reading', range(7 10) lcolor(navy)) ///
	(function y=`driftlimit_midd_math', range(7 10) lcolor(maroon)), ///
	ylab(0(0.1)0.5) ///
	graphregion(fcolor(white)) ///
	title("Autocorrelation Vector in Middle School for English and Math Scores", size(medium)) ///
	xtitle("Years Separation Between Classes") ///
	ytitle("Correlation") ///
	legend(order(1 "English" 3 "Math"))
multi_graph_export using ${figdir}/paper1/fig1b_autocovar_middle


****************
*** Figure 2 ***
****************

* see above in Table 3 code.


****************************************************
***** Figure 3: Teacher Switcher Event Studies *****
****************************************************

***** DATA SETUP FOR TEACHER SWITCHER EVENT STUDIES *****

use $datadir/teacher_school_weights, clear

* Output percentages of type of switch
file open switchtype using ${tab}/paper1/paperonly_turnover_switchtype_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text replace
sum switch_grade
file write switchtype "Fraction switch grade:," (r(mean)) _n
sum switch_school
file write switchtype "Fraction switch school:," (r(mean)) _n
sum switch_district
file write switchtype "Fraction switch district:," (r(mean)) _n
file close switchtype

* Merge in VA
merge m:1 teacher year math using ${datadir}/tfx/tfx_${tfxdate}_tym, assert(1 3) nogen

assert !missing(grade)
save $datadir/teach_va_weights_${tfxdate}, replace

collapse (sum) mean_tv_ss=tv_ss [iw=teach_wt], by(sch grade year math)

*Use FULL school district data here (not just analysis sample cohorts) because we need many years for event studies
merge 1:1 sch grade year math using ${datadir}/SCHD_sch_gr_year_collapse_${SCHDgradecollapsedate}
keep if _merge==3
drop _merge

save $datadir/sch_gr_yr_work1_${tfxdate}, replace

*STEP 2: Identify teacher switchers by grade
use $datadir/teach_va_weights_${tfxdate}, clear


egen tsgm_id = group(sch teacher grade math)
tsset tsgm_id year

*Define leavers and entries by requiring that (1) teacher teaches a positive fraction of students in current year and (2) is not in the school-subject-grade for either the next 3 years or past 3 years
*Note that year of event is therefore 0 for entry (i.e. entry occurs in year 0) and +1 for exit (i.e. first year after exit is +1).  We adjust exit graphs x axis by subtracting 1 in code for figure 3b and figure 3d below.

g t_leave = f.teach_wt==.&f2.teach_wt==.&f3.teach_wt==. if year<2009 & teach_wt>0 & teach_wt<. /*& switch_district==0*/
g t_enter = l.teach_wt==.&l2.teach_wt==.&l3.teach_wt==. if year>1989 & teach_wt>0 & teach_wt<. /*& new_to_district==0*/

g va_leave = tv_ss if t_leave==1
g va_enter = tv_ss if t_enter==1


*** Break entrance and departure events up by whether the teacher left/entered the district, the school, or switched from within the school
* 		note: switch_district==1 and switch_school==1 are mutually exclusive. so these groups are a full partition.

* District
g t_leave_d = f.teach_wt==.&f2.teach_wt==.&f3.teach_wt==. if year<2009 & teach_wt>0 & teach_wt<. & switch_district==1
g t_enter_d = l.teach_wt==.&l2.teach_wt==.&l3.teach_wt==. if year>1989 & teach_wt>0 & teach_wt<. & new_to_district==1

g va_leave_d = tv_ss if t_leave_d==1
g va_enter_d = tv_ss if t_enter_d==1

* School
g t_leave_s = f.teach_wt==.&f2.teach_wt==.&f3.teach_wt==. if year<2009 & teach_wt>0 & teach_wt<. & switch_school==1
g t_enter_s = l.teach_wt==.&l2.teach_wt==.&l3.teach_wt==. if year>1989 & teach_wt>0 & teach_wt<. & new_to_school==1

g va_leave_s = tv_ss if t_leave_s==1
g va_enter_s = tv_ss if t_enter_s==1

* Grade (i.e. within-school)
g t_leave_g = f.teach_wt==.&f2.teach_wt==.&f3.teach_wt==. if year<2009 & teach_wt>0 & teach_wt<. & switch_school==0 & switch_district==0
g t_enter_g = l.teach_wt==.&l2.teach_wt==.&l3.teach_wt==. if year>1989 & teach_wt>0 & teach_wt<. & new_to_school==0 & new_to_district==0

g va_leave_g = tv_ss if t_leave_g==1
g va_enter_g = tv_ss if t_enter_g==1


*Define average value_added of leavers and enterers
bys sch grade year math: egen leave_n = sum(t_leave)
bys sch grade year math: egen enter_n = sum(t_enter)
bys sch grade year math: egen leave_va = mean(va_leave)
bys sch grade year math: egen enter_va = mean(va_enter)


*** Now break up the avg value added into three component parts: district, school, grade changes.
*		note that we do not take separate means by type of change, these would not sum to the total.
*		we sum VA within type and divide by the same denominator as with the overall average
* 		we also set these VA measures to zero if no leave/entrance of the type took place but a leave/entrance of another type took place

foreach type in d s g {
	bys sch grade year math: egen leave_n_`type' = sum(t_leave_`type')
	bys sch grade year math: egen enter_n_`type' = sum(t_enter_`type')

	bys sch grade year math: egen leave_va_`type' = sum(va_leave_`type')
	replace leave_va_`type'=0 if leave_n>0 & leave_va_`type'==.
	replace leave_va_`type'=leave_va_`type'/leave_n

    bys sch grade year math: egen enter_va_`type' = sum(va_enter_`type')
	replace enter_va_`type'=0 if enter_n>0 & enter_va_`type'==.
	replace enter_va_`type'=enter_va_`type'/enter_n
}

*Collapse the dataset to the school-grade-subject-year level
bys sch grade year math: keep if _n==1

keep sch grade year math leave_n-enter_va_g has_*rookie
order sch grade year math leave* enter* has*
compress

*Merge back on the school-grade-subject-year test score data
merge 1:1 sch grade year math using $datadir/sch_gr_yr_work1_${tfxdate}, keep(3) nogen

gen cohort =year-grade
egen cohort_id = group(sch cohort math)
egen grade_id = group(sch grade math)
tsset grade_id cohort


***********************************************************************************************************************************************
* REFEREE ASKS: WHEN A TEACHER SWITCHES OUT OF THEIR CURRENT SCHOOL-GRADE-SUBJECT, WHAT % OF THE TIME ARE THEY REPLACED WITH A NEW TEACHER,
* A TEACHER FROM ANOTHER SCHOOL, OR A TEACHER FROM WITHIN THE SAME SCHOOL?

gen prior_leave=l.leave_n>0 if l.leave_n<.

foreach type in g s d {
	gen enter_any_`type' = enter_n_`type'>0 & enter_n_`type'<.
}

log using ${logdir}/percent_replacement_for_referee, replace
bysort prior_leave: sum enter_any_*
log close

drop enter_any_* prior_leave
***********************************************************************************************************************************************


*Require school-grade-subject cell to exist for 5 years around event (this requirement is subsumed by balanced panel below)

tsset grade_id cohort

g close = f.mean_score==.|f2.mean_score==.
g open = l2.mean_score==.|l.mean_score==.
replace leave_n = 0 if close==1|open==1
replace enter_n = 0 if close==1|open==1


foreach type in d s g {
	replace leave_n_`type' = 0 if close==1|open==1
	replace enter_n_`type' = 0 if close==1|open==1
}


g d_score = mean_score-mean_l_score

keep if grade>3



***** Define events
* 		Note that the "subset" of events based on district, school, or grade switches are not strictly a subset because we are averaging va across all entries
* 		in the general case, and only among a subset of entries in the specific cases.
* 			ex: 1 great teacher may enter the district, but 1 bad teacher enters from within the school, and the total VA does not rise above the 95th percentile.

*Merge on middle school indicator, constructed from class data
merge m:1 sch grade year using ${datadir}/sch_middle_irsdate${IRSdate}, keep(1 3) nogen

set more off

* Create variables
g byte high_entry_event = 0
g byte low_entry_event = 0 
g byte high_exit_event = 0
g byte low_exit_event = 0 

foreach type in d s g {
	g byte high_entry_event_`type' = 0
	g byte low_entry_event_`type' = 0
	g byte high_exit_event_`type' = 0
	g byte low_exit_event_`type' = 0
}

* Define events by subject
forvalues math=0/1 {

	***TEACHER ENTRY
	quietly sum enter_va if math==`math',d
	scalar p95 = r(p95)
	scalar p5 = r(p5)

	replace high_entry_event = 1 if enter_va>p95 & math==`math' & enter_n>0 & enter_va<.
	
	replace low_entry_event = 1 if enter_va<p5 & math==`math' & enter_n>0

	foreach type in d s g {
		replace high_entry_event_`type' = 1 if enter_va_`type'>p95 & math==`math' & enter_n_`type'>0 & enter_va_`type'<.
		
		replace low_entry_event_`type' = 1 if enter_va_`type'<p5 & math==`math' & enter_n_`type'>0
	}


	***TEACHER EXIT     
	quietly sum leave_va if math==`math',d
	scalar p95 = r(p95)
	scalar p5 = r(p5)

	replace high_exit_event = 1 if leave_va>p95 & math==`math' & leave_n>0 & leave_va<.

	replace low_exit_event = 1 if leave_va<p5 & math==`math' & leave_n>0

	foreach type in d s g {
		replace high_exit_event_`type' = 1 if leave_va_`type'>p95 & math==`math' & leave_n_`type'>0 & leave_va_`type'<.

		replace low_exit_event_`type' = 1 if leave_va_`type'<p5 & math==`math' & leave_n_`type'>0
	}
}

save ${datadir}/eventstudy_analysis_${tfxdate}, replace


****EVENT STUDY GRAPHS****
*These are subject-specific top 5% entrants (ok to include cheaters here b/c they affect contemporaneous scores as expected)
*Balanced panel, run on full school district data

use ${datadir}/eventstudy_analysis_${tfxdate}, clear

egen sch_cohort = group(sch cohort)


*** Calculate mean change in TV for each event

	*1: High Entry
	eventstudy mean_tv_ss if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(high_entry_event) testvalone(0)  preyrs(3) postyrs(2) balanced pickevent(stack) xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph
	scalar high_entry_tv_change =e(coef_aft_dot)
	scalar high_entry_tv_se =e(se_aft_dot)

	*2: High Exit
	eventstudy mean_tv_ss if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(high_exit_event) testvalone(0)  preyrs(2) postyrs(3) balanced pickevent(stack) xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph
	scalar high_exit_tv_change = e(coef_aft_dot)
	scalar high_exit_tv_se = e(se_aft_dot)

	*3: Low Entry
	eventstudy mean_tv_ss if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(low_entry_event) testvalone(0)  preyrs(3) postyrs(2) balanced pickevent(stack) xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph
	scalar low_entry_tv_change = e(coef_aft_dot)
	scalar low_entry_tv_se = e(se_aft_dot)

	*4: Low Exit
	eventstudy mean_tv_ss if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(low_exit_event) testvalone(0)  preyrs(2) postyrs(3) balanced pickevent(stack) xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph
	scalar low_exit_tv_change =  e(coef_aft_dot)
	scalar low_exit_tv_se =  e(se_aft_dot)

 
*** Hypothesis tests

*First test hypothesis that observed change equals change forecasted from change in TV (can't reject equality)

	*1: High Entry
	eventstudy d_score if d_score<.,  timevar(year) unitvar(grade_id) eventvar(high_entry_event) testvalone(high_entry_tv_change) absorb(year) cluster(sch_cohort)  preyrs(3) postyrs(2) balanced pickevent(stack) xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph
	scalar high_entry_score_change =e(coef_aft_dot)
	scalar high_entry_score_se =e(se_aft_dot)
	scalar high_entry_score_forecast_p =e(testvalone_p)

	*2: High Exit
	eventstudy d_score if d_score<.,  timevar(year) unitvar(grade_id) eventvar(high_exit_event) testvalone(high_exit_tv_change) absorb(year) cluster(sch_cohort)  preyrs(2) postyrs(3) balanced pickevent(stack) xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph
	scalar high_exit_score_change = e(coef_aft_dot)
	scalar high_exit_score_se =e(se_aft_dot)
	scalar high_exit_score_forecast_p =e(testvalone_p)
	
	*3: Low Entry
	eventstudy d_score if d_score<.,  timevar(year) unitvar(grade_id) eventvar(low_entry_event) testvalone(low_entry_tv_change) absorb(year) cluster(sch_cohort)  preyrs(3) postyrs(2) balanced pickevent(stack) xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph
	scalar low_entry_score_change = e(coef_aft_dot)
	scalar low_entry_score_se =e(se_aft_dot)
	scalar low_entry_score_forecast_p =e(testvalone_p)
	
	*4: Low Exit
	eventstudy d_score if d_score<.,  timevar(year) unitvar(grade_id) eventvar(low_exit_event) testvalone(low_exit_tv_change) absorb(year) cluster(sch_cohort)  preyrs(2) postyrs(3) balanced pickevent(stack) xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph
	scalar low_exit_score_change =  e(coef_aft_dot)
	scalar low_exit_score_se =e(se_aft_dot)
	scalar low_exit_score_forecast_p =e(testvalone_p)
	
*Now test hypothesis that change is zero (all are highly significant)

	*1: High Entry
	eventstudy d_score if d_score<.,  timevar(year) unitvar(grade_id) eventvar(high_entry_event) testvalone(0) absorb(year) cluster(sch_cohort)  preyrs(3) postyrs(2) balanced pickevent(stack) xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph
	scalar high_entry_score_0_p =e(testvalone_p)

	*2: High Exit
	eventstudy d_score if d_score<.,  timevar(year) unitvar(grade_id) eventvar(high_exit_event) testvalone(0) absorb(year) cluster(sch_cohort)  preyrs(2) postyrs(3) balanced pickevent(stack) xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph
	scalar high_exit_score_0_p =e(testvalone_p)

	*3: Low Entry
	eventstudy d_score if d_score<.,  timevar(year) unitvar(grade_id) eventvar(low_entry_event) testvalone(0) absorb(year) cluster(sch_cohort)  preyrs(3) postyrs(2) balanced pickevent(stack) xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph
	scalar low_entry_score_0_p =e(testvalone_p)

	*4: Low Exit
	eventstudy d_score if d_score<.,  timevar(year) unitvar(grade_id) eventvar(low_exit_event) testvalone(0) absorb(year) cluster(sch_cohort)  preyrs(2) postyrs(3) balanced pickevent(stack) xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph
	scalar low_exit_score_0_p =e(testvalone_p)


*** Plot graphs: event study of current scores

	*1: High Entry
	eventstudy mean_score if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(high_entry_event)  preyrs(3) postyrs(2) balanced pickevent(stack) ///
		xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph ///
		savedata(${datadir}/eventstudy/fig3a_high_entry_score_${tfxdate})
	scalar high_entry_N_events = e(N_events)
	* Output change in score between -1 and 0 for paper:
	file open dscore using ${tab}/paper1/paperonly_fig3a_Dscore_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text replace
	file write dscore "High VA Entry,Change in 'Score' from -1 to 0," (e(coef_aft_dot)) _n
	file close dscore

	*2: High Exit
	eventstudy mean_score if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(high_exit_event)  preyrs(2) postyrs(3) balanced pickevent(stack) ///
		xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph ///
		savedata(${datadir}/eventstudy/fig3b_high_exit_score_${tfxdate})
	scalar high_exit_N_events = e(N_events)
	
	*3: Low Entry
	eventstudy mean_score if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(low_entry_event)  preyrs(3) postyrs(2) balanced pickevent(stack) ///
		xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph ///
		savedata(${datadir}/eventstudy/fig3c_low_entry_score_${tfxdate})
	scalar low_entry_N_events = e(N_events)
	
	*4: Low Exit
	eventstudy mean_score if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(low_exit_event)  preyrs(2) postyrs(3) balanced pickevent(stack) ///
		xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph ///
		savedata(${datadir}/eventstudy/fig3d_low_exit_score_${tfxdate})
	scalar low_exit_N_events = e(N_events)
	

*** Plot graphs: mean lag scores

	*1: High Entry
	eventstudy mean_l_score if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(high_entry_event) testvalone(0)  preyrs(3) postyrs(2) balanced pickevent(stack) ///
		xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph ///
		savedata(${datadir}/eventstudy/fig3a_high_entry_l_score_${tfxdate})
	* Output change in lag score between -1 and 0 for paper:
	file open dscore using ${tab}/paper1/paperonly_fig3a_Dscore_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text append
	file write dscore "High VA Entry,Change in 'Score in Previous Grade' from -1 to 0," (e(coef_aft_dot)) _n
	file close dscore


	*2: High Exit
	eventstudy mean_l_score if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(high_exit_event)  testvalone(0)  preyrs(2) postyrs(3) balanced pickevent(stack) ///
		xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph ///
		savedata(${datadir}/eventstudy/fig3b_high_exit_l_score_${tfxdate})

	*3: Low Entry
	eventstudy mean_l_score if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(low_entry_event) testvalone(0)  preyrs(3) postyrs(2) balanced pickevent(stack) ///
		xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph ///
		savedata(${datadir}/eventstudy/fig3c_low_entry_l_score_${tfxdate})

	*4: Low Exit
	eventstudy mean_l_score if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(low_exit_event) testvalone(0)  preyrs(2) postyrs(3) balanced pickevent(stack) ///
		xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph ///
		savedata(${datadir}/eventstudy/fig3d_low_exit_l_score_${tfxdate})
	
*** Check for changes in class size around entry/exit
	file open dclasssize using ${tab}/paper1/paperonly_fig3_Dclasssize_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text replace
	file write dclasssize ",coef -1 to 0, se -1 to 0, p -1 to 0" _n

	*1: High Entry
	eventstudy mean_CLass_size if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(high_entry_event) testvalone(0) preyrs(3) postyrs(2) balanced pickevent(stack) xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph
	file write dclasssize "High VA Entry," (e(coef_aft_dot)) "," (e(se_aft_dot)) "," (e(testvalone_p)) _n
	
	*2: High Exit
	eventstudy mean_CLass_size if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(high_exit_event) testvalone(0) preyrs(2) postyrs(3) balanced pickevent(stack) xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph
	file write dclasssize "High VA Exit," (e(coef_aft_dot)) "," (e(se_aft_dot)) "," (e(testvalone_p)) _n
	
	*3: Low Entry
	eventstudy mean_CLass_size if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(low_entry_event) testvalone(0) preyrs(3) postyrs(2) balanced pickevent(stack) xlabel(-3(1)2)  xline(-0.5) graphregion(fcolor(white)) nograph
	file write dclasssize "Low VA Entry," (e(coef_aft_dot)) "," (e(se_aft_dot)) "," (e(testvalone_p)) _n
	
	*4: Low Exit
	eventstudy mean_CLass_size if d_score<.,  timevar(year) unitvar(grade_id) absorb(year) cluster(sch_cohort) eventvar(low_exit_event) testvalone(0) preyrs(2) postyrs(3) balanced pickevent(stack) xlabel(-2(1)3)  xline(0.5) graphregion(fcolor(white)) eventyr_plus1 nograph
	file write dclasssize "Low VA Exit," (e(coef_aft_dot)) "," (e(se_aft_dot)) "," (e(testvalone_p)) _n

	file close dclasssize

***** Combine and save graphs

*** Figure 3a: High Value-Added Teacher Entry

* Load data
use ${datadir}/eventstudy/fig3a_high_entry_score_${tfxdate}, clear
merge 1:1 event_time using ${datadir}/eventstudy/fig3a_high_entry_l_score_${tfxdate}
gen d_score=mean_score_coeffs-mean_l_score_coeffs

* Perform shift
scalar shift_score=mean_score_coeffs[1]
scalar shift_lscore=mean_l_score_coeffs[1]

replace mean_score_coeffs=mean_score_coeffs-shift_score
replace mean_l_score_coeffs=mean_l_score_coeffs-shift_lscore

* Store numbers to be displayed as locals
local score_change=string(high_entry_score_change,"%9.3f")
local score_se=string(high_entry_score_se,"%9.3f")

local tv_change=string(high_entry_tv_change,"%9.3f")
local tv_se=string(high_entry_tv_se,"%9.3f")

if (high_entry_score_forecast_p<0.001) local score_forecast_p="< 0.001"
else local score_forecast_p="= "+string(high_entry_score_forecast_p,"%9.2f")

if (high_entry_score_0_p<0.001) local score_0_p="< 0.001"
else local score_0_p="= "+string(high_entry_score_0_p,"%9.2f")

local N_events=string(high_entry_N_events,"%9.0f")

* Graph mean/lag figure for paper
twoway  (scatter mean_score_coeffs event_time, c(l)) ///
	(scatter mean_l_score_coeffs event_time, c(l) lcolor(black) mcolor(black)), ///
	graphregion(fcolor(white)) ///
	xline(-0.5) ///
	title("High Value-Added Teacher Entry") ///
	xtitle("Year Relative to Entry of High Value-Added Teacher") ///
	ytitle("School-Grade-Cohort Mean Test Score") ///
	legend(order(1 "Score" 2 "Score in Previous Grade")) ///
	note(	"D Score = `score_change'" ///
		"                (`score_se')" ///
		"D TVA = `tv_change'" ///
		"             (`tv_se')" ///
		" " ///
		"p [D score = 0] `score_0_p'" ///
		"p [D score = D TVA] `score_forecast_p'" ///
		" " ///
		"Number of Events = `N_events'" ///
		, pos(10) ring(0) size(small))
multi_graph_export using ${figdir}/paper1/fig3a_high_entry_${tfxdate}

* Graph diff figure for slides
twoway  (scatter d_score event_time, c(l)), ///
	graphregion(fcolor(white)) ///
	xline(-0.5) ///
	title("High Value-Added Teacher Entry") ///
	xtitle("Year Relative to Entry of High Value-Added Teacher") ///
	ytitle("School-Grade-Cohort Mean Test Score") ///
	note(	"D Score = `score_change'" ///
		"                (`score_se')" ///
		"D TVA = `tv_change'" ///
		"             (`tv_se')" ///
		" " ///
		"p [D score = 0] `score_0_p'" ///
		"p [D score = D TVA] `score_forecast_p'" ///
		" " ///
		"Number of Events = `N_events'" ///
		, pos(10) ring(0) size(small))
multi_graph_export using ${figdir}/paper1/slidesonly_fig3a_high_entry_${tfxdate}_D_SCORE


*** Figure 3b: High Value-Added Teacher Exit

* Load data
use ${datadir}/eventstudy/fig3b_high_exit_score_${tfxdate}, clear
merge 1:1 event_time using ${datadir}/eventstudy/fig3b_high_exit_l_score_${tfxdate}
gen d_score=mean_score_coeffs-mean_l_score_coeffs
replace event_time=event_time-1

* Perform shift
scalar shift_score=mean_score_coeffs[_N]
scalar shift_lscore=mean_l_score_coeffs[_N]

replace mean_score_coeffs=mean_score_coeffs-shift_score
replace mean_l_score_coeffs=mean_l_score_coeffs-shift_lscore

* Store numbers to be displayed as locals
local score_change=string(high_exit_score_change,"%9.3f")
local score_se=string(high_exit_score_se,"%9.3f")

local tv_change=string(high_exit_tv_change,"%9.3f")
local tv_se=string(high_exit_tv_se,"%9.3f")

if (high_exit_score_forecast_p<0.001) local score_forecast_p="< 0.001"
else local score_forecast_p="= "+string(high_exit_score_forecast_p,"%9.2f")

if (high_exit_score_0_p<0.001) local score_0_p="< 0.001"
else local score_0_p="= "+string(high_exit_score_0_p,"%9.2f")

local N_events=string(high_exit_N_events,"%9.0f")

* Graph mean/lag figure for paper
twoway  (scatter mean_score_coeffs event_time, c(l)) ///
	(scatter mean_l_score_coeffs event_time, c(l) lcolor(black) mcolor(black)), ///
	graphregion(fcolor(white)) ///
	xline(-0.5) ///
	title("High Value-Added Teacher Exit") ///
	xtitle("Year Relative to Departure of High Value-Added Teacher") ///
	ytitle("School-Grade-Cohort Mean Test Score") ///
	legend(order(1 "Score" 2 "Score in Previous Grade")) ///
	note(	"D Score = `score_change'" ///
		"                (`score_se')" ///
		"D TVA = `tv_change'" ///
		"             (`tv_se')" ///
		" " ///
		"p [D score = 0] `score_0_p'" ///
		"p [D score = D TVA] `score_forecast_p'" ///
		" " ///
		"Number of Events = `N_events'" ///
		, pos(2) ring(0) size(small))
multi_graph_export using ${figdir}/paper1/fig3b_high_exit_${tfxdate}

* Graph diff figure for slides
twoway  (scatter d_score event_time, c(l)), ///
	graphregion(fcolor(white)) ///
	xline(-0.5) ///
	title("High Value-Added Teacher Exit") ///
	xtitle("Year Relative to Departure of High Value-Added Teacher") ///
	ytitle("School-Grade-Cohort Mean Test Score") ///
	note(	"D Score = `score_change'" ///
		"                (`score_se')" ///
		"D TVA = `tv_change'" ///
		"             (`tv_se')" ///
		" " ///
		"p [D score = 0] `score_0_p'" ///
		"p [D score = D TVA] `score_forecast_p'" ///
		" " ///
		"Number of Events = `N_events'" ///
		, pos(2) ring(0) size(small))
multi_graph_export using ${figdir}/paper1/slidesonly_fig3b_high_exit_${tfxdate}_D_SCORE


*** Figure 3c: Low Value-Added Teacher Entry

* Load data
use ${datadir}/eventstudy/fig3c_low_entry_score_${tfxdate}, clear
merge 1:1 event_time using ${datadir}/eventstudy/fig3c_low_entry_l_score_${tfxdate}
gen d_score=mean_score_coeffs-mean_l_score_coeffs

* Perform shift
scalar shift_score=mean_score_coeffs[1]
scalar shift_lscore=mean_l_score_coeffs[1]

replace mean_score_coeffs=mean_score_coeffs-shift_score
replace mean_l_score_coeffs=mean_l_score_coeffs-shift_lscore

* Store numbers to be displayed as locals
local score_change=string(low_entry_score_change,"%9.3f")
local score_se=string(low_entry_score_se,"%9.3f")

local tv_change=string(low_entry_tv_change,"%9.3f")
local tv_se=string(low_entry_tv_se,"%9.3f")

if (low_entry_score_forecast_p<0.001) local score_forecast_p="< 0.001"
else local score_forecast_p="= "+string(low_entry_score_forecast_p,"%9.2f")

if (low_entry_score_0_p<0.001) local score_0_p="< 0.001"
else local score_0_p="= "+string(low_entry_score_0_p,"%9.2f")

local N_events=string(low_entry_N_events,"%9.0f")

* Graph mean/lag figure for paper
twoway  (scatter mean_score_coeffs event_time, c(l)) ///
	(scatter mean_l_score_coeffs event_time, c(l) lcolor(black) mcolor(black)), ///
	graphregion(fcolor(white)) ///
	xline(-0.5) ///
	title("Low Value-Added Teacher Entry") ///
	xtitle("Year Relative to Entry of Low Value-Added Teacher") ///
	ytitle("School-Grade-Cohort Mean Test Score") ///
	legend(order(1 "Score" 2 "Score in Previous Grade")) ///
	note(	"D Score = `score_change'" ///
		"                (`score_se')" ///
		"D TVA = `tv_change'" ///
		"             (`tv_se')" ///
		" " ///
		"p [D score = 0] `score_0_p'" ///
		"p [D score = D TVA] `score_forecast_p'" ///
		" " ///
		"Number of Events = `N_events'" ///
		, pos(7) ring(0) size(small))
multi_graph_export using ${figdir}/paper1/fig3c_low_entry_${tfxdate}

* Graph diff figure for slides
twoway  (scatter d_score event_time, c(l)), ///
	graphregion(fcolor(white)) ///
	xline(-0.5) ///
	title("Low Value-Added Teacher Entry") ///
	xtitle("Year Relative to Entry of Low Value-Added Teacher") ///
	ytitle("School-Grade-Cohort Mean Test Score") ///
	note(	"D Score = `score_change'" ///
		"                (`score_se')" ///
		"D TVA = `tv_change'" ///
		"             (`tv_se')" ///
		" " ///
		"p [D score = 0] `score_0_p'" ///
		"p [D score = D TVA] `score_forecast_p'" ///
		" " ///
		"Number of Events = `N_events'" ///
		, pos(7) ring(0) size(small))
multi_graph_export using ${figdir}/paper1/slidesonly_fig3c_low_entry_${tfxdate}_D_SCORE

*** Figure 3d: Low Value-Added Teacher Exit

* Load data
use ${datadir}/eventstudy/fig3d_low_exit_score_${tfxdate}, clear
merge 1:1 event_time using ${datadir}/eventstudy/fig3d_low_exit_l_score_${tfxdate}
gen d_score=mean_score_coeffs-mean_l_score_coeffs
replace event_time=event_time-1

* Perform shift
scalar shift_score=mean_score_coeffs[_N]
scalar shift_lscore=mean_l_score_coeffs[_N]

replace mean_score_coeffs=mean_score_coeffs-shift_score
replace mean_l_score_coeffs=mean_l_score_coeffs-shift_lscore

* Store numbers to be displayed as locals
local score_change=string(low_exit_score_change,"%9.3f")
local score_se=string(low_exit_score_se,"%9.3f")

local tv_change=string(low_exit_tv_change,"%9.3f")
local tv_se=string(low_exit_tv_se,"%9.3f")

if (low_exit_score_forecast_p<0.001) local score_forecast_p="< 0.001"
else local score_forecast_p="= "+string(low_exit_score_forecast_p,"%9.2f")

if (low_exit_score_0_p<0.001) local score_0_p="< 0.001"
else local score_0_p="= "+string(low_exit_score_0_p,"%9.2f")

local N_events=string(low_exit_N_events,"%9.0f")

* Graph mean/lag figure for paper
twoway  (scatter mean_score_coeffs event_time, c(l)) ///
	(scatter mean_l_score_coeffs event_time, c(l) lcolor(black) mcolor(black)), ///
	graphregion(fcolor(white)) ///
	xline(-0.5) ///
	ylab(-.03(.01).02) ///
	title("Low Value-Added Teacher Exit") ///
	xtitle("Year Relative to Departure of Low Value-Added Teacher") ///
	ytitle("School-Grade-Cohort Mean Test Score") ///
	legend(order(1 "Score" 2 "Score in Previous Grade")) ///
	note(	"D Score = `score_change'" ///
		"                (`score_se')" ///
		"D TVA = `tv_change'" ///
		"             (`tv_se')" ///
		" " ///
		"p [D score = 0] `score_0_p'" ///
		"p [D score = D TVA] `score_forecast_p'" ///
		" " ///
		"Number of Events = `N_events'" ///
		, pos(5) ring(0) size(small))
multi_graph_export using ${figdir}/paper1/fig3d_low_exit_${tfxdate}

* Graph diff figure for slides
twoway  (scatter d_score event_time, c(l)), ///
	graphregion(fcolor(white)) ///
	xline(-0.5) ///
	title("Low Value-Added Teacher Exit") ///
	xtitle("Year Relative to Departure of Low Value-Added Teacher") ///
	ytitle("School-Grade-Cohort Mean Test Score") ///
	note(	"D Score = `score_change'" ///
		"                (`score_se')" ///
		"D TVA = `tv_change'" ///
		"             (`tv_se')" ///
		" " ///
		"p [D score = 0] `score_0_p'" ///
		"p [D score = D TVA] `score_forecast_p'" ///
		" " ///
		"Number of Events = `N_events'" ///
		, pos(5) ring(0) size(small))
multi_graph_export using ${figdir}/paper1/slidesonly_fig3d_low_exit_${tfxdate}_D_SCORE


********************
***** Figure 4 *****
********************

* See code in Table 4 above.

********************
***** Figure 5 *****
********************

* See code in Table 4 above.

*****************************
***** Appendix Figure 1 *****
*****************************

use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}.dta, clear

* Demean tv by middle-math
foreach var of varlist tv {
	forvalues middle=0/1 {
		forvalues math=0/1 {
			sum `var' [w=CLass_size] if middle==`middle' & math==`math', meanonly
			replace `var'=`var'-r(mean) if middle==`middle' & math==`math'
		}
	}
}

*** AFig 1a: Kernel density of teacher VA by subject for elementary

*List the following 2 SD's on the figure 
qui sum tv [w=CLass_size] if middle==0 & math==0
local sd_read=string(r(sd),"%9.3f")

qui sum tv [w=CLass_size] if middle==0 & math==1
local sd_math=string(r(sd),"%9.3f")

twoway  (kdensity tv [w=CLass_size] if abs(tv)<.3 & middle==0 & math==0, bwidth(.01)) ///
	(kdensity tv [w=CLass_size] if abs(tv)<.3 & middle==0 & math==1, bwidth(.01)), ///
	graphregion(fcolor(white)) ///
	xlab(-.3(.1).3) ///
	title("Empirical Distribution of Teacher VA Estimates in Elementary School", size(medium)) ///
	xtitle("Teacher Value-Added") ///
	ytitle("Density") ///
	note("SD of English = `sd_read'" "SD of Math = `sd_math'", position(2) ring(0) size(medsmall)) ///
	legend(order(1 "English" 2 "Math"))
multi_graph_export using ${figdir}/paper1/afig1a

*** AFig 1b: Kernel density of teacher VA by subject for middle

*List the following 2 SD's on the figure 
qui sum tv [w=CLass_size] if middle==1 & math==0
local sd_read=string(r(sd),"%9.3f")

qui sum tv [w=CLass_size] if middle==1 & math==1
local sd_math=string(r(sd),"%9.3f")

twoway  (kdensity tv [w=CLass_size] if abs(tv)<.3 & middle==1 & math==0, bwidth(.01)) ///
	(kdensity tv [w=CLass_size] if abs(tv)<.3 & middle==1 & math==1, bwidth(.01)), ///
	graphregion(fcolor(white)) ///
	xlab(-.3(.1).3) ///
	title("Empirical Distribution of Teacher VA Estimates in Middle School", size(medium)) ///
	xtitle("Teacher Value-Added") ///
	ytitle("Density") ///
	note("SD of English = `sd_read'" "SD of Math = `sd_math'", position(2) ring(0) size(medsmall)) ///
	legend(order(1 "English" 2 "Math"))
multi_graph_export using ${figdir}/paper1/afig1b


*************************************
***** Figures not used in paper *****
*************************************

*** Kernel density of teacher quality within vs across schools

use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}.dta, clear

* Demean tv by middle-math
forvalues middle=0/1 {
	forvalues math=0/1 {
		sum tv [w=CLass_size] if middle==`middle' & math==`math', meanonly
		replace tv=tv-r(mean) if middle==`middle' & math==`math'
	}
}

* Compute means
bys sch: egen sch_mean_tv = wtmean(tv), weight(CLass_size)
gen tv_diff_sch_mean = tv - sch_mean_tv

bys sch: egen sch_size = sum(CLass_size)
bys sch: gen one_obs_per_sch=(_n==1)


* Check computed SDs below against xtsum output.
*    The ones computed below should match except that xtsum doesn't support weights
xtset sch
xtsum tv

* Overall variance
qui sum tv [w=CLass_size]
local sd_overall=string(r(sd),"%9.3f")
di "SD overall: `sd_overall'"

* Within variance
qui sum tv_diff_sch_mean [w=CLass_size]
local sd_within=string(r(sd),"%9.3f")
di "SD within: `sd_within'"

* Between variance
sum sch_mean_tv if one_obs_per_sch==1 [w=sch_size]
local sd_between=string(r(sd),"%9.3f")
di "SD between: `sd_between'"

twoway  (kdensity sch_mean_tv if one_obs_per_sch & abs(sch_mean_tv)<.2 [w=sch_size], bwidth(.01)) ///
	(kdensity tv_diff_sch_mean [w=CLass_size] if abs(tv_diff_sch_mean)<.2, bwidth(.01)), ///
	graphregion(fcolor(white)) ///
	title("Variation in Value-Added Within vs Across Schools", size(medium)) ///
	xtitle("Teacher Value-Added") ///
	ytitle("Density") ///
	note("SD between schools = `sd_between'" "SD within schools = `sd_within'" "Total SD = `sd_overall'", position(2) ring(0) size(medsmall)) ///
	legend(order(1 "Mean School-Level VA" 2 "VA Within Schools"))



*~*~*~*~*~*~*~*~*~**~*~*~*~*~*~*~
*~*~*~*~*~* PAPER 2 *~*~*~*~*~*~*
*~*~*~*~*~*~*~*~*~**~*~*~*~*~*~*~

*******************
***** Table 1 *****
*******************

* Table 1 is generated at the IRS, except for the t_exp_reg & CLass_size rows.
* --> note: data from IRS log is read into Stata in the Paper 1, Table 1 code block.


***** Output csv for Paper 2

* Compute summary stats for t_exp_reg and CLass_size on the outside
use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}.dta, clear

sum t_exp_reg [w=CLass_size] if any_l97==1
scalar __texp_mean=r(mean)
scalar __texp_sd=r(sd)
scalar __texp_n=r(sum_w)

sum CLass_size if any_l97==1
scalar __classsize_mean=r(mean)
scalar __classsize_sd=r(sd)
scalar __classsize_n=r(N)

* Store the computed summary stats as data in a new dataset
clear
set obs 2

gen str20 var=""
gen float mean=.
gen float sd=.
gen long n=.
gen byte paper=2

replace var="t_exp_reg" in 1
replace mean=__texp_mean in 1
replace sd=__texp_sd in 1
replace n=__texp_n in 1

replace var="CLass_size_classweighted" in 2
replace mean=__classsize_mean in 2
replace sd=__classsize_sd in 2
replace n=__classsize_n in 2

* Append IRS summary stats data
append using ${datadir}/summary_stats_from_IRS_${summstats_date}.dta
keep if paper==2

* Rename the "blockN" summary stats
drop if inlist(var,"lunch_block2","miss_lunch_block2")
replace var=subinstr(var,"_block3","_subsample",.)
replace var=subinstr(var,"_block4","_subsample",.)
replace var=subinstr(var,"_block5","_subsample",.)

outsheet using ${tab}/paper2/table1_summstatsdate${summstats_date}.csv, comma replace



*******************
***** Table 2 *****
*******************

* Cross-Class, Impacts of Teacher Value-Added on College Attendance

use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}, clear
estimates clear

* Col 1: college at age20 with baseline controls
longterm_crossclass_table college20, ///
	controls(${controls}) replace r_suffix(_bl) ///
	output(${tab}/paper2/table2_irsdate${IRSdate}_tfxdate${tfxdate}.csv)
scalar __coeff=_b[tv_sd]
scalar __se=_se[tv_sd]

* Figure 1a
sum college20 [w=college20_count] if !missing(college20_r_bl)
gen college20_r_bl_percent=(college20_r_bl+r(mean))*100

local coeff=string(__coeff*100,"%9.2f")
local se=string(__se*100,"%9.2f")
binscatter college20_r_bl_percent tv_sd [aw=college20_count], controls(middle math middle_math)  ///
	title("College Attendance at Age 20") ///
	xtitle("Teacher Value Added") ///
	ytitle("Percent in College at Age 20") ///
	xlab(-1.5(.5)1.5) ///
	note("Coefficient = `coeff'%" "(`se')", position(5) ring(0) size(medsmall))
multi_graph_export using ${figdir}/paper2/fig1a_college20_scatter_irsdate${IRSdate}_tfxdate${tfxdate}


* Col 2: college at age20 with baseline controls + parent controls
longterm_crossclass_table college20, ///
	controls(${controls} ${par_controls}) r_suffix(_par) append ///
	output(${tab}/paper2/table2_irsdate${IRSdate}_tfxdate${tfxdate}.csv)
	
* Col 3: college at age20 with baseline controls + l2_z_score
longterm_crossclass_table college20 if grade>4, ///
	controls(${controls} l2_z_score) r_suffix(_l2) append ///
	output(${tab}/paper2/table2_irsdate${IRSdate}_tfxdate${tfxdate}.csv)
	
* Text only: Col 1 re-run on sample of Col 3
longterm_crossclass_table college20 if !missing(college20_r_l2), ///
	controls(${controls}) r_suffix(_bl_l2sample) replace ///
	output(${tab}/paper2/paperonly_col1table2_rerun_col3sample_irsdate${IRSdate}_tfxdate${tfxdate}.csv)

* Col 4: cwage20 with baseline controls
longterm_crossclass_table cwage20, ///
	controls(${controls}) r_suffix(_bl) append ///
	output(${tab}/paper2/table2_irsdate${IRSdate}_tfxdate${tfxdate}.csv)
scalar __coeff=_b[tv_sd]
scalar __se=_se[tv_sd]

* Figure 1b
sum cwage20 [w=cwage20_count] if !missing(cwage20_r_bl)
gen cwage20_r_bl_binsc=(cwage20_r_bl+r(mean))

local coeff=string(__coeff,"%9.0f")
local se=string(__se,"%9.0f")
binscatter cwage20_r_bl_binsc tv_sd [aw=cwage20_count], controls(middle math middle_math)  ///
	title("College Quality at Age 20") ///
	xtitle("Teacher Value Added") ///
	ytitle("Projected Earnings from College at Age 20") ///
	xlab(-1.5(.5)1.5) ///
	note("Coefficient = $`coeff'" "(`se')", position(5) ring(0) size(medsmall))
multi_graph_export using ${figdir}/paper2/fig1b_cwage20_scatter_irsdate${IRSdate}_tfxdate${tfxdate}

* Col 5: cwage20 with baseline controls + parent controls
longterm_crossclass_table cwage20, ///
	controls(${controls} ${par_controls}) r_suffix(_par) append ///
	output(${tab}/paper2/table2_irsdate${IRSdate}_tfxdate${tfxdate}.csv)
	
* Col 6: cwage20 with baseline controls + l2_z_score
longterm_crossclass_table cwage20 if grade>4, ///
	controls(${controls} l2_z_score) r_suffix(_l2) append ///
	output(${tab}/paper2/table2_irsdate${IRSdate}_tfxdate${tfxdate}.csv)

* Col 7: High Quality College with baseline controls
longterm_crossclass_table high_cwage20, ///
	controls(${controls}) append ///
	output(${tab}/paper2/table2_irsdate${IRSdate}_tfxdate${tfxdate}.csv)
	
* Col 8: Indicator for four or more years in college, with baseline controls
longterm_crossclass_table coll1822_more4yrs, ///
	controls(${controls}) append ///
	output(${tab}/paper2/table2_irsdate${IRSdate}_tfxdate${tfxdate}.csv)


*** Paper only

reg college20_r_bl middle math middle_math
predict college20_r_bl_centered if e(sample), r

file open fstat using ${tab}/paper2/paperonly_table2_selection_Fstats_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text replace


* F-statistic for selection on parent characteristics
foreach var of varlist $par_controls {
	residualize_middle_math `var'_r=`var', tv_insample controls(${controls})
	
	* Scale some vars down in order to avoid an overflow error with the F-stat (F-stat becomes missing)
	sum `var'_r, meanonly
	scalar __magnitude=floor(log(abs(r(mean)))/log(10))
	if (__magnitude>=5) replace `var'_r=`var'_r/10^__magnitude
}

local par_controls_r=""
foreach var of varlist $par_controls {
	local par_controls_r `par_controls_r' `var'_r
}
reg college20_r_bl_centered `par_controls_r', cluster(sch_cohort) noconstant
file write fstat "par_controls_r," (e(F)) _n

* F-statistic for selection on lagged test scores
residualize_middle_math l2_z_score_r=l2_z_score if grade>4, tv_insample controls(${controls})

reg college20_r_bl_centered l2_z_score_r if grade>4, cluster(sch_cohort) noconstant
file write fstat "l2_z_score_r," (e(F)) _n

file close fstat


*******************
***** Table 3 *****
*******************

* Cross-Class, Impacts of Teacher Value-Added on Earnings

use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}, clear
estimates clear

* Col 1: wage_trim28 with baseline controls
longterm_crossclass_table wage_trim28, ///
	controls(${controls}) r_suffix(_bl) replace ///
	output(${tab}/paper2/table3_irsdate${IRSdate}_tfxdate${tfxdate}.csv)
scalar __coeff=_b[tv_sd]
scalar __se=_se[tv_sd]

* Figure 2a
sum wage_trim28 [w=wage_trim28_count] if !missing(wage_trim28_r_bl)
gen wage_trim28_r_bl_binsc=(wage_trim28_r_bl+r(mean))

local coeff=string(__coeff,"%9.0f")
local se=string(__se,"%9.0f")
binscatter wage_trim28_r_bl_binsc tv_sd [aw=wage_trim28_count], controls(middle math middle_math)  ///
	title("Effect of Teacher Value-Added on Earnings at Age 28") ///
	xtitle("Teacher Value Added") ///
	ytitle("Earnings at Age 28") ///
	xlab(-1.5(.5)1.5) ///
	note("Coefficient = $`coeff'" "(`se')", position(5) ring(0) size(medsmall))
multi_graph_export using ${figdir}/paper2/fig2a_wagetrim28_scatter_irsdate${IRSdate}_tfxdate${tfxdate}


* Col 2: wage_trim28 with baseline controls + parent controls
longterm_crossclass_table wage_trim28, ///
	controls(${controls} ${par_controls}) r_suffix(_par) append ///
	output(${tab}/paper2/table3_irsdate${IRSdate}_tfxdate${tfxdate}.csv)

* Col 3: wage_trim28 with baseline controls + l2_z_score
longterm_crossclass_table wage_trim28 if grade>4, ///
	controls(${controls} l2_z_score) r_suffix(_l2) append ///
	output(${tab}/paper2/table3_irsdate${IRSdate}_tfxdate${tfxdate}.csv)

* Col 4: nowage28 with baseline controls
longterm_crossclass_table nowage28, ///
	controls(${controls}) r_suffix(_bl) append ///
	output(${tab}/paper2/table3_irsdate${IRSdate}_tfxdate${tfxdate}.csv)

* Col 5: 1040-based income with baseline controls
longterm_crossclass_table wage_plus_seinc28, ///
	controls(${controls}) r_suffix(_bl) append ///
	output(${tab}/paper2/table3_irsdate${IRSdate}_tfxdate${tfxdate}.csv)

* Col 6: wage_growth28 with baseline controls
longterm_crossclass_table wage_growth28, ///
	controls(${controls}) r_suffix(_bl) append ///
	output(${tab}/paper2/table3_irsdate${IRSdate}_tfxdate${tfxdate}.csv)

*******************
***** Table 4 *****
*******************

* Cross-Class, Impacts of Teacher Value-Added on Other Outcomes

use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}, clear
estimates clear

* Col 1: Teenage birth with baseline controls
longterm_crossclass_table teenbirth_fem, ///
	controls(${controls}) r_suffix(_bl) replace ///
	output(${tab}/paper2/table4_irsdate${IRSdate}_tfxdate${tfxdate}.csv)
scalar __coeff=_b[tv_sd]
scalar __se=_se[tv_sd]

*** Figure 3a
sum teenbirth_fem [w=teenbirth_fem_count] if !missing(teenbirth_fem_r_bl)
gen teenbirth_fem_r_bl_percent=(teenbirth_fem_r_bl+r(mean))*100

local coeff=string(__coeff*100,"%9.2f")
local se=string(__se*100,"%9.2f")
binscatter teenbirth_fem_r_bl_percent tv_sd [aw=teenbirth_fem_count], controls(middle math middle_math)  ///
	title("Women with Teenage Births") ///
	xtitle("Teacher Value-Added") ///
	ytitle("Percent of Women with Teenage Births") ///
	xlab(-1.5(.5)1.5) ///
	note("Coefficient = `coeff'%" "(`se')", position(2) ring(0) size(medsmall))
multi_graph_export using ${figdir}/paper2/fig3a_teenbirth_scatter_irsdate${IRSdate}_tfxdate${tfxdate}

* Col 2: Percent college grads in ZIP at age 28 with baseline controls
longterm_crossclass_table pctcollgrad28, ///
	controls(${controls}) r_suffix(_bl) append ///
	output(${tab}/paper2/table4_irsdate${IRSdate}_tfxdate${tfxdate}.csv)
scalar __coeff=_b[tv_sd]
scalar __se=_se[tv_sd]

*** Figure 3b
sum pctcollgrad28 [w=pctcollgrad28_count] if !missing(pctcollgrad28_r_bl)
gen pctcollgrad28_r_bl_percent=(pctcollgrad28_r_bl+r(mean))*100

local coeff=string(__coeff*100,"%9.2f")
local se=string(__se*100,"%9.2f")
binscatter pctcollgrad28_r_bl_percent tv_sd [aw=pctcollgrad28_count], controls(middle math middle_math)  ///
	title("Neighborhood Quality at Age 28") ///
	xtitle("Teacher Value-Added") ///
	ytitle("Percent College Graduates in ZIP at Age 28") ///
	xlab(-1.5(.5)1.5) ///
	note("Coefficient = `coeff'%" "(`se')", position(5) ring(0) size(medsmall))
multi_graph_export using ${figdir}/paper2/fig3b_pctcollgrad28_scatter_irsdate${IRSdate}_tfxdate${tfxdate}
	
* Col 3: have401k28 with baseline controls
longterm_crossclass_table have401k28, ///
	controls(${controls}) r_suffix(_bl) append ///
	output(${tab}/paper2/table4_irsdate${IRSdate}_tfxdate${tfxdate}.csv)	
scalar __coeff=_b[tv_sd]
scalar __se=_se[tv_sd]

*** Figure 3c
sum have401k28 [w=have401k28_count] if !missing(have401k28_r_bl)
gen have401k28_r_bl_percent=(have401k28_r_bl+r(mean))*100

local coeff=string(__coeff*100,"%9.2f")
local se=string(__se*100,"%9.2f")
binscatter have401k28_r_bl_percent tv_sd [aw=have401k28_count], controls(middle math middle_math)  ///
	title("Retirement Savings at Age 28") ///
	xtitle("Teacher Value-Added") ///
	ytitle("Percent with Retirement Savings at Age 28") ///
	xlab(-1.5(.5)1.5) ///
	note("Coefficient = `coeff'%" "(`se')", position(5) ring(0) size(medsmall))
multi_graph_export using ${figdir}/paper2/fig3c_have401k28_scatter_irsdate${IRSdate}_tfxdate${tfxdate}


*******************
***** Table 5 *****
*******************

*Long Term Impact (college) Results: Cross-Cohort

prepare_quasi, tfxfile(${datadir}/tfx/tfx_${tfxdate}) ///
	tch_sch_weights(${datadir}/teacher_school_weights) ///
	sch_gr_yr_collapse(${datadir}/IRS_SCHD_sch_gr_yr_collapse_${IRSdate}) ///
	trim_threshold(99) ///
	tv_sd
	
egen sch_yr = group(sch year)

g d_mean_l_other = d.mean_PREOl_other
g d_mean_l_other2 = d_mean_l_other^2
g d_mean_l_other3 = d_mean_l_other^3
g d_mean_l_score = d.mean_l_score
g d_mean_l_score3 = d_mean_l_score^3
g d_mean_l_score2 = d_mean_l_score^2

*** Panel A: college20
*** Panel B: cwage20
estimates clear
set more off

file open meancovered using ${tab}/paper2/paperonly_cross_cohort_meancovered_tfxdate${tfxdate}.csv, write text replace

foreach var of varlist college20 cwage20 {
	if ("`var'"=="college20") local predvar="predcoll20_nocontrols"
	if ("`var'"=="cwage20") local predvar="predcwage20_nocontrols"
	
	* Col 1: Baseline
	areg d.`var' d_tv_sgm_1 [w=`var'_count], cluster(sch_cohort) a(year)
	estimates store tab1`var'
	scalar __`var'_coeff=_b[d_tv_sgm_1]
	scalar __`var'_se=_se[d_tv_sgm_1]
	
	sum mean_covered_tv if e(sample) [w=`var'_count], meanonly
	scalar __mean_cur=r(mean)
	sum l.mean_covered_tv if e(sample) [w=`var'_count], meanonly
	scalar __mean_lag=r(mean)
	file write meancovered "`var' Baseline mean_covered," ((__mean_cur+__mean_lag)/2) _n
	
	sum cohort if e(sample) [w=`var'_count], meanonly
	file write meancovered "`var' Baseline mean cohort," (r(mean)) _n

	* Col 2: Add sch*yr fixed effects
	areg d.`var' d_tv_sgm_1 [w=`var'_count], cluster(sch_cohort) a(sch_yr)
	estimates store tab2`var'

	* Col 3: Add control for lagged scores, and lead & lag change in VA
	areg d.`var' d_tv_sgm_1 d_mean_l_score* d_mean_l_other* f.d_tv_sgm_1 l.d_tv_sgm_1 [w=`var'_count], cluster(sch_cohort) a(sch_yr)
	estimates store tab3`var'

	* PAPER ONLY: same spec as col 2 on identical sample to col 3
	areg d.`var' d_tv_sgm_1 [w=`var'_count] if e(sample), cluster(sch_cohort) a(sch_yr)
	estimates store paper1`var'

	* Col 4: no imputation, baseline spec
	areg d.`var' d_tv_sgm_1 [w=`var'_count] if mean_covered==1&l.mean_covered==1, cluster(sch_cohort) a(sch_yr)
	estimates store tab4`var'

	* Col 5: Predicted college with sch*yr fixed effects
	areg d.`predvar' d_tv_sgm_1 [w=`predvar'_count], cluster(sch_cohort) a(sch_yr)
	estimates store tab5`var'
}

file close meancovered

* PAPER ONLY: Wage_trim28 specs to report in paper, not in tables
areg d.wage_trim28 d_tv_sgm_1 [w=wage_trim28_count], cluster(sch_cohort) a(year)
estimates store paper_wage_1

areg d.wage_trim28 d_tv_sgm_1 [w=wage_trim28_count] if mean_covered>0.5&l.mean_covered>0.5, cluster(sch_cohort) a(year)
estimates store paper_wage_2

* Output
esttab tab* using ${tab}/paper2/table5_cross_cohort_college_irsdate${IRSdate}_tfxdate${tfxdate}.csv, replace keep(d_tv_sgm_1) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g)) p(fmt(%12.0g))) obslast
esttab paper* using ${tab}/paper2/paperonly_cross_cohort_college_irsdate${IRSdate}_tfxdate${tfxdate}.csv, replace keep(d_tv_sgm_1) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g))  p(fmt(%12.0g))) obslast
estimates clear

*** Figure 5a: cross-cohort scatter for college20
local coef=string(__college20_coeff*100,"%9.2f")
local se=string(__college20_se*100,"%9.2f")
binscatter d_college20 d_tv_sgm_1 [aw=college20_count], absorb(year) reportreg ///
	title("Change in College Attendance Across Cohorts vs Change in Mean Teacher VA", size(medium)) ///
	ytitle("Change in College Attendance Across Cohorts") ///
	xtitle("Change in Mean Teacher VA") ///
	note("Coefficient = `coef'%" "(`se')", position(5) ring(0) size(medsmall))
multi_graph_export using ${figdir}/paper2/fig5a_cross_cohort_college20_irsdate${IRSdate}_tfxdate${tfxdate}


*** Figure 5b: cross-cohort scatter for cwage20
local coef=string(__cwage20_coeff,"%9.0f")
local se=string(__cwage20_se,"%9.0f")
binscatter d_cwage20 d_tv_sgm_1 [aw=cwage20_count], absorb(year) reportreg ///
	title("Change in College Quality Across Cohorts vs Change in Mean Teacher VA", size(medium)) ///
	ytitle("Change in College Quality Across Cohorts") ///
	xtitle("Change in Mean Teacher VA") ///
	note("Coefficient = $`coef'" "(`se')", position(5) ring(0) size(medsmall))
multi_graph_export using ${figdir}/paper2/fig5b_cross_cohort_cwage20_irsdate${IRSdate}_tfxdate${tfxdate}

*** Figure 6: event study of coefficients
gen int lag = _n-5 in 1/9

foreach var of varlist college20 predcoll20_nocontrols cwage20 predcwage20_nocontrols {
	areg d.`var' F(-4/4).d_tv_sgm_1 [w=`var'_count], cluster(sch_cohort) a(year)
	
	test _b[d_tv_sgm_1] = _b[l.d_tv_sgm_1]
	scalar _pval_l1_`var'=r(p)
	test _b[d_tv_sgm_1] = _b[f.d_tv_sgm_1]
	scalar _pval_f1_`var'=r(p)
	
	matrix coeff=e(b)'
	matrix se=vecdiag(cholesky(diag(vecdiag(e(V)))))'
	svmat coeff, names(coeff_`var'_)
	svmat se, names(se_`var'_)
	gen upper_`var'=coeff_`var'+1.96*se_`var'
	gen lower_`var'=coeff_`var'-1.96*se_`var'
}

* Figure 6a: event study of coefficients on college20
local coeff=string(coeff_college20[5],"%9.3f")
local se=string(se_college20[5],"%9.3f")
local pval_l1=string(_pval_l1_college20,"%9.3f")
local pval_f1=string(_pval_f1_college20,"%9.3f")
twoway  (scatter coeff_college20 /*coeff_predcoll20_nocontrols*/ lag, c(l l)), ///
	xline(0, lpattern(dash) lcolor(gs8)) ///
	xlabel(-4(1)4) graphregion(fcolor(white)) ///
	ytitle("Coefficient on Change in Mean VA in Year 0") ///
	xtitle("Lag or Lead") ///
	title("Event Study of Coefficients on College Attendance") ///
	legend(order(1 "College Attendance" 2 "Predicted College Attendance")) ///
	note("Coefficient at 0 = `coeff'" "(`se')" "Coeff -1 equals coeff 0: p=`pval_l1'" "Coeff +1 equals coeff 0: p=`pval_f1'", position(2) ring(0) size(medsmall))
multi_graph_export using ${figdir}/paper2/fig6a_cross_cohort_coeffs_college20_irsdate${IRSdate}_tfxdate${tfxdate}


* Figure 6b: event study of coefficients on cwage20
local coeff=string(coeff_cwage20[5],"%9.3f")
local se=string(se_cwage20[5],"%9.3f")
local pval_l1=string(_pval_l1_cwage20,"%9.3f")
local pval_f1=string(_pval_f1_cwage20,"%9.3f")
twoway  (scatter coeff_cwage20 /*coeff_predcwage20_nocontrols*/ lag, c(l l)), ///
	xline(0, lpattern(dash) lcolor(gs8)) ///
	xlabel(-4(1)4) ///
	graphregion(fcolor(white)) ///
	ytitle("Coefficient on Change in Mean VA in Year 0") ///
	xtitle("Lag or Lead") ///
	title("Event Study of Coefficients on College Quality") ///
	legend(order(1 "College Quality" 2 "Predicted College Quality")) ///
	note("Coefficient at 0 = `coeff'" "(`se')" "Coeff -1 equals coeff 0: p=`pval_l1'" "Coeff +1 equals coeff 0: p=`pval_f1'", position(2) ring(0) size(medsmall))
multi_graph_export using ${figdir}/paper2/fig6b_cross_cohort_coeffs_cwage20_irsdate${IRSdate}_tfxdate${tfxdate}

*******************
***** Table 6 *****
*******************

* Cross-Class, Heterogeneity in Impacts of Teacher Value-Added

use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}, clear
estimates clear

*** Panel A

* Wage variables
longterm_crossclass_table cwage20_fem cwage20_male cwage20_lopi cwage20_hipi cwage20_minority cwage20_nonminority, ///
	controls(${controls} ${par_controls}) r_suffix(_par) replace ///
	output(${tab}/paper2/table6_panelA_irsdate${IRSdate}_tfxdate${tfxdate}.csv)

* Score variables
longterm_crossclass_table score_fem score_male score_lopi score_hipi score_minority score_nonminority, ///
	controls(${controls} ${par_controls}) r_suffix(_par) append ///
	output(${tab}/paper2/table6_panelA_irsdate${IRSdate}_tfxdate${tfxdate}.csv)

* Paper only: test equality of impacts for cwage20_fem and cwage20_male
insheet using ${tab}/paper2/table6_panelA_irsdate${IRSdate}_tfxdate${tfxdate}.csv, comma clear

keep if inlist(tv_sd,"cwage20_fem_r_par","cwage20_male_r_par")
assert _N==2

scalar __diff=abs(coeff[1]-coeff[2])
scalar __se_diff=sqrt(se[1]^2+se[2]^2)
scalar __p_diff=2*(1-normal(__diff/__se_diff))

file open equ_fem_male using ${tab}/paper2/paperonly_table6a_cwage20_fem_male_equ_tfxdate${tfxdate}.csv, write text replace
file write equ_fem_male "diff,se(diff),p-val" _n
file write equ_fem_male (__diff) "," (__se_diff) "," (__p_diff) "," 
file close equ_fem_male


***** Panel B
use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}, clear
estimates clear

egen idvar = group(sch year class_id)
tsset idvar math

g tv_math = tv if middle == 0 & math == 1
g tv_math_sd = tv_sd if middle == 0 & math == 1
replace tv_math = f.tv if middle == 0 & math == 0
replace tv_math_sd = f.tv_sd if middle == 0 & math == 0

g tv_reading = l.tv if middle == 0 & math == 1
g tv_reading_sd = l.tv_sd if middle == 0 & math == 1
replace tv_reading = tv if middle==0 & math == 0
replace tv_reading_sd = tv_sd if middle==0 & math == 0

count if teacher!=l.teacher & middle==0 & math==1 & !missing(teacher,l.teacher)
g tv_insample_jointelem = (tv_insample==1 & l.tv_insample==1 & teacher==l.teacher) if middle==0 & math==1
replace tv_insample_jointelem = f.tv_insample_jointelem if middle==0 & math==0
 
*** Elementary Columns

** Create elem residual
qui areg cwage20 ${controls} ${par_controls} if tv_insample_jointelem==1 & middle==0 & math == 1 & tv_math<. & tv_reading<. [w=cwage20_count], a(teacher)
qui predict cwage20_r_jointelem if e(sample), dr

** Note: There are slightly different students who attend the Math and English classes taught by the same teacher.
**       But this difference is negligible, so we don't address it.
count if middle==0 & math==1
count if CLass_size!=l.CLass_size & middle==0 & math==1
count if cwage20_count!=l.cwage20_count & middle==0 & math==1
corr cwage20 l.cwage20 if middle==0 & math==1

residualize_middle_math test_residualize_separately=cwage20 if tv_insample_jointelem==1, controls(${controls} ${par_controls})
gen test_residualize_together = cwage20_r_jointelem
replace test_residualize_together = f.cwage20_r_jointelem if middle==0 & math==0
corr test_residualize_together test_residualize_separately if middle==0 & math==0
corr test_residualize_together test_residualize_separately if middle==0 & math==1

* Col 1
reg cwage20_r_jointelem tv_math_sd			if tv_insample_jointelem==1 [w=cwage20_count], cluster(sch_cohort)
estimates store col1

sum cwage20_count if e(sample)
local col1_individuals=`r(sum)'

* Col 2
reg cwage20_r_jointelem tv_reading_sd			if tv_insample_jointelem==1 [w=cwage20_count], cluster(sch_cohort)
estimates store col2

qui sum cwage20_count if e(sample)
local col2_individuals=`r(sum)'

* Col 3
reg cwage20_r_jointelem tv_math_sd tv_reading_sd	if tv_insample_jointelem==1 [w=cwage20_count], cluster(sch_cohort)
estimates store col3

qui sum cwage20_count if e(sample)
local col3_individuals=`r(sum)'

* Paper only: correlation between math and reading VA
file open corr using ${tab}/paper2/paperonly_VAcorr_elem_mathread_tfxdate${tfxdate}.csv, write text replace
corr tv_math_sd tv_reading_sd if tv_insample_jointelem==1 & middle==0 & math==1 [w=CLass_size]
file write corr (r(rho))
file close corr

*** Middle columns

** Generate middle sch residual
** --> NOTE: residualizing on tv_other rather than 'tv_sd_other' makes no difference, because tv_sd is a linear transformation of tv within middle-math
residualize_middle_math cwage20_r_jointmid=cwage20, tv_insample controls(tv_other ${controls} ${par_controls})

* Col 4
reg cwage20_r_jointmid tv_sd	if tv_insample==1 & middle==1 & math==1 [w=cwage20_count], cluster(sch_cohort)
estimates store col4

qui sum cwage20_count if e(sample)
local col4_individuals=`r(sum)'

* Col 5
reg cwage20_r_jointmid tv_sd	if tv_insample==1 & middle==1 & math==0 [w=cwage20_count], cluster(sch_cohort)
estimates store col5

qui sum cwage20_count if e(sample)
local col5_individuals=`r(sum)'

** Output

* Output regression results
esttab col* using ${tab}/paper2/table6_panelB_irsdate${IRSdate}_tfxdate${tfxdate}.csv, replace keep(tv_math_sd tv_reading_sd tv_sd) cells(b(fmt(%12.0g)) se(abs par fmt(%12.0g)) p(fmt(%12.0g))) obslast

* Output number of individuals (i.e weighted N)
file open Nind using ${tab}/paper2/table6_panelB_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text append
file write Nind "N_individuals,`col1_individuals',`col2_individuals',`col3_individuals',`col4_individuals',`col5_individuals'"
file close Nind



************************
*** Appendix Table 1 ***
************************

* Appendix Table 1 is just an illustration of the data structure; it does not contain any results.
* It is made in Excel.


************************
*** Appendix Table 2 ***
************************

* College Ranking Stability

*** Panel A: Variation in age of earnings
use "${datadir}/cq_trim_3.dta", clear
keep if inrange(age_wage,23,32) & age==20 & coll_yr==1999
keep w2_wage_mean coll_id age_wage
reshape wide w2_wage_mean, i(coll_id) j(age_wage)
spearman w2_wage_mean23 w2_wage_mean24 w2_wage_mean25 w2_wage_mean26 w2_wage_mean27 w2_wage_mean28 w2_wage_mean29 w2_wage_mean30 w2_wage_mean31 w2_wage_mean32
matrix spear=r(Rho)

* Output to csv
file open corrcoll using "${tab}/paper2/appxtable2_panelA_irsdate${IRSdate}_tfxdate${tfxdate}.csv", write text replace

file write corrcoll ","
forvalues age=23/32 {
	file write corrcoll "Age `age',"
}
file write corrcoll _n

forvalues age=23/32 {
	file write corrcoll "Age `age',"
	local i=`age'-22
	forvalues j=1/`i' {
		file write corrcoll (spear[`i',`j']) "," 
	}
	file write corrcoll _n
}
file close corrcoll


*** Panel B: Variation in age in college
use "${datadir}/cq_trim_3.dta", clear	
keep if (coll_yr-age) == 1981 & age_wage == 30 & inrange(age,18,25)
keep w2_wage_mean coll_id age
reshape wide w2_wage_mean, i(coll_id) j(age)
spearman w2_wage_mean18 w2_wage_mean19 w2_wage_mean20 w2_wage_mean21 w2_wage_mean22 w2_wage_mean23 w2_wage_mean24 w2_wage_mean25
matrix spear=r(Rho)

* Output to csv
file open corrcoll using "${tab}/paper2/appxtable2_panelB_irsdate${IRSdate}_tfxdate${tfxdate}.csv", write text replace

file write corrcoll ","
forvalues age=18/25 {
	file write corrcoll "Age `age',"
}
file write corrcoll _n

forvalues age=18/25 {
	file write corrcoll "Age `age',"
	local i=`age'-17
	forvalues j=1/`i' {
		file write corrcoll (spear[`i',`j']) "," 
	}
	file write corrcoll _n
}
file close corrcoll


*** Panel C: Variation in cohort year
use "${datadir}/cq_trim_3.dta", clear	
g cohort = coll_yr - age
keep if age == 20 & age_wage == 30 & inrange(cohort,1979,1981)	
keep w2_wage_mean coll_id cohort
reshape wide w2_wage_mean, i(coll_id) j(cohort)
spearman w2_wage_mean1979 w2_wage_mean1980 w2_wage_mean1981
matrix spear=r(Rho)

* Output to csv
file open corrcoll using "${tab}/paper2/appxtable2_panelC_irsdate${IRSdate}_tfxdate${tfxdate}.csv", write text replace

file write corrcoll ","
forvalues cohort=1979/1981 {
	file write corrcoll "Cohort `cohort',"
}
file write corrcoll _n

forvalues cohort=1979/1981 {
	file write corrcoll "Cohort `cohort',"
	local i=`cohort'-1978
	forvalues j=1/`i' {
		file write corrcoll (spear[`i',`j']) "," 
	}
	file write corrcoll _n
}
file close corrcoll


*** Panel D: Correlation across wage measures
use "${datadir}/cq_trim_3.dta", clear
keep if age==20 & coll_yr==1999 & age_wage==30
merge 1:1 coll_id using "${datadir}/cq_3x2b_mskd.dta", nogen
spearman w2_wage w2_wage_med w2_schedc
matrix spear=r(Rho)

* Output to csv
file open corrcoll using "${tab}/paper2/appxtable2_panelD_irsdate${IRSdate}_tfxdate${tfxdate}.csv", write text replace

file write corrcoll ",Mean W-2,Median W-2,Mean W-2 + S-E" _n

local i=1
foreach wage in "Mean W-2" "Median W-2" "Mean W-2 + S-E" {
	file write corrcoll "`wage',"
	forvalues j=1/`i' {
		file write corrcoll (spear[`i',`j']) "," 
	}
	file write corrcoll _n
	local ++i
}
file close corrcoll


**********************************
***** Appendix Tables 3 to 6 *****
**********************************

***** APPENDIX TABLE 3: Cross-Sectional Correlations Between Outcomes in Adulthood and Test Scores

* Prepare dataset for saving coeffs
clear
set obs 10
qui gen str22 model=""
qui replace model="No Controls" in 1
qui replace model="With Controls" in 3
qui replace model="Math, Full Controls" in 5
qui replace model="English, Full Controls" in 7
qui replace model="Mean of Dep. Var." in 10

* Open IRS Log
file open irslog using "${datadir}/from_IRS/cross_section_app_tables_${crosssec_apptable_date}.lst", read
file read irslog line


foreach var in wage_trim28 cwage20 college20 teenbirth_fem pctcollgrad25 {
	qui gen `var'=.
	
	* Process first reg: "proc reg data = &dataset (where =  (4 <= grade <= 8))"
	while (strpos(`"`line'"',"Number of Observations Read")==0 & r(eof)==0) {
		file read irslog line
	}
	while ((`"`1'"'!="Variable" | `"`2'"'!="DF" | `"`3'"'!="Estimate" | `"`4'"'!="Error") & r(eof)==0) {
		file read irslog line
		tokenize `"`line'"', parse(" ")
	}
	while (`"`1'"'!="score" & r(eof)==0) {
		file read irslog line
		tokenize `"`line'"', parse(" ")
	}
	
	qui replace `var'=`3' in 1
	qui replace `var'=`4' in 2
	
	* Process second-fourth regs.
	forvalues i=1/3 {
		* Find new regression
		while (strpos(`"`line'"',"Number of Observations Read")==0 & r(eof)==0) {
			file read irslog line
		}
		
		* Save dep var mean of 'With Controls' sample
		if (`i'==1) {
			while ((`"`1'"'!="R-Square" | `"`2'"'!="Coeff" | `"`3'"'!="Var") & r(eof)==0) {
				file read irslog line
				tokenize `"`line'"', parse(" ")
			}
			file read irslog line
			tokenize `"`line'"', parse(" ")
			while (trim(`"`line'"')=="" & r(eof)==0) {
				file read irslog line
				tokenize `"`line'"', parse(" ")
			}
			qui replace `var'=`4' in 10
		}

		
		* Proceed to the coeff of score
		while ((`"`1'"'!="Parameter" | `"`2'"'!="Estimate" | `"`3'"'!="Error") & r(eof)==0) {
			file read irslog line
			tokenize `"`line'"', parse(" ")
		}
		while (`"`1'"'!="score" & r(eof)==0) {
			file read irslog line
			tokenize `"`line'"', parse(" ")
		}
		
		* Store in dataset
		local coef_pos=2*`i'+1
		local se_pos=2*`i'+2
		
		qui replace `var'=`2' in `coef_pos'
		qui replace `var'=`3' in `se_pos'
	}
}



outsheet using "${tab}/paper2/appxtable3_crosssecdate${crosssec_apptable_date}.csv", comma replace


***** APPENDIX TABLE 4: Cross-Sectional Correlations Between Test Scores and Earnings by Age

* Prepare dataset for saving coeffs
clear
set obs 8
qui gen str27 model=""
qui replace model="No Controls" in 1
qui replace model="With Controls" in 3
qui replace model="Mean Earnings" in 6
qui replace model="Percent Effect (w Controls)" in 8


forvalues age=20/30 {
	local var="wage_trim`age'"
	qui gen `var'=.
	
	** Process first reg: No Controls
	while (strpos(`"`line'"',"Number of Observations Read")==0 & r(eof)==0) {
		file read irslog line
	}
	while ((`"`1'"'!="Variable" | `"`2'"'!="DF" | `"`3'"'!="Estimate" | `"`4'"'!="Error") & r(eof)==0) {
		file read irslog line
		tokenize `"`line'"', parse(" ")
	}
	while (`"`1'"'!="score" & r(eof)==0) {
		file read irslog line
		tokenize `"`line'"', parse(" ")
	}
	
	qui replace `var'=`3' in 1
	qui replace `var'=`4' in 2
	
	** Process second reg: With Controls
	forvalues i=1/1 {
		* Find new regression
		while (strpos(`"`line'"',"Number of Observations Read")==0 & r(eof)==0) {
			file read irslog line
		}
		
		* Save dep var mean of 'With Controls' sample
		if (`i'==1) {
			while ((`"`1'"'!="R-Square" | `"`2'"'!="Coeff" | `"`3'"'!="Var") & r(eof)==0) {
				file read irslog line
				tokenize `"`line'"', parse(" ")
			}
			file read irslog line
			tokenize `"`line'"', parse(" ")
			while (trim(`"`line'"')=="" & r(eof)==0) {
				file read irslog line
				tokenize `"`line'"', parse(" ")
			}
			qui replace `var'=`4' in 6
		}

		
		* Proceed to the coeff of score
		while ((`"`1'"'!="Parameter" | `"`2'"'!="Estimate" | `"`3'"'!="Error") & r(eof)==0) {
			file read irslog line
			tokenize `"`line'"', parse(" ")
		}
		while (`"`1'"'!="score" & r(eof)==0) {
			file read irslog line
			tokenize `"`line'"', parse(" ")
		}
		
		* Store in dataset
		qui replace `var'=`2' in 3
		qui replace `var'=`3' in 4
	}
	
	** Compute % effect of regression with controls
	qui replace `var'=`var'[3]/`var'[6] in 8
}


outsheet using "${tab}/paper2/appxtable4_crosssecdate${crosssec_apptable_date}.csv", comma replace



***** APPENDIX TABLE 5: Heterogeneity in Cross-Sectional Correlations Across Demographic Groups

* Prepare dataset for saving coeffs
clear
set obs 18
qui gen str22 model=""
qui replace model="Male" in 1
qui replace model="Female" in 4
qui replace model="Non-minority" in 7
qui replace model="Minority" in 10
qui replace model="Low Parent Income" in 13
qui replace model="High Parent Income" in 16


forvalues i=0/2 {
	foreach var in wage_trim28 cwage20 college20 teenbirth_fem {
		if (`i'==0) qui gen `var'=.
		
		* Process first and second regs
		forvalues j=1/2 {
			* Skip male if var is teenbirth_fem
			if ("`var'"=="teenbirth_fem" & `i'==0 & `j'==1) continue			
		
			* Find new regression
			while (strpos(`"`line'"',"Number of Observations Read")==0 & r(eof)==0) {
				file read irslog line
			}
			
			* Save dep var mean
			while ((`"`1'"'!="R-Square" | `"`2'"'!="Coeff" | `"`3'"'!="Var") & r(eof)==0) {
				file read irslog line
				tokenize `"`line'"', parse(" ")
			}
			file read irslog line
			tokenize `"`line'"', parse(" ")
			while (trim(`"`line'"')=="" & r(eof)==0) {
				file read irslog line
				tokenize `"`line'"', parse(" ")
			}
			local mean_pos=(2*`i'+`j')*3
			qui replace `var'=`4' in `mean_pos'
	
			
			* Proceed to the coeff of score
			while ((`"`1'"'!="Parameter" | `"`2'"'!="Estimate" | `"`3'"'!="Error") & r(eof)==0) {
				file read irslog line
				tokenize `"`line'"', parse(" ")
			}
			while (`"`1'"'!="score" & r(eof)==0) {
				file read irslog line
				tokenize `"`line'"', parse(" ")
			}
			
			* Store in dataset
			local coef_pos=(2*`i'+`j')*3-2
			local se_pos=(2*`i'+`j')*3-1
			
			qui replace `var'=`2' in `coef_pos'
			qui replace `var'=`3' in `se_pos'
		}
	}
}


order model wage_trim28 college20 cwage20 teenbirth_fem
outsheet using "${tab}/paper2/appxtable5_crosssecdate${crosssec_apptable_date}.csv", comma replace


***** APPENDIX TABLE 6: Cross-Sectional Correlations between Test Scores and Outcomes in Adulthood by Grade

* Prepare dataset for saving coeffs
clear
set obs 10
qui gen str27 model=""
qui replace model="Grade 4" in 1
qui replace model="Grade 5" in 3
qui replace model="Grade 6" in 5
qui replace model="Grade 7" in 7
qui replace model="Grade 8" in 9


forvalues gr=0/4 {
	local coef_pos=2*`gr'+1
	local se_pos=2*`gr'+2

	foreach var in wage_trim28 college20 cwage20 {
		if (`gr'==0) {
			qui gen `var'_nocontrols=.
			qui gen `var'_WITHcontrols=.
		}
		
		** Process first reg: No Controls
		while (strpos(`"`line'"',"Number of Observations Read")==0 & r(eof)==0) {
			file read irslog line
		}
		while ((`"`1'"'!="Variable" | `"`2'"'!="DF" | `"`3'"'!="Estimate" | `"`4'"'!="Error") & r(eof)==0) {
			file read irslog line
			tokenize `"`line'"', parse(" ")
		}
		while (`"`1'"'!="score" & r(eof)==0) {
			file read irslog line
			tokenize `"`line'"', parse(" ")
		}
		
		qui replace `var'_nocontrols=`3' in `coef_pos'
		qui replace `var'_nocontrols=`4' in `se_pos'
		
		** Process second reg: With Controls
		* Find new regression
		while (strpos(`"`line'"',"Number of Observations Read")==0 & r(eof)==0) {
			file read irslog line
		}
		
		* Proceed to the coeff of score
		while ((`"`1'"'!="Parameter" | `"`2'"'!="Estimate" | `"`3'"'!="Error") & r(eof)==0) {
			file read irslog line
			tokenize `"`line'"', parse(" ")
		}
		while (`"`1'"'!="score" & r(eof)==0) {
			file read irslog line
			tokenize `"`line'"', parse(" ")
		}
		
		local coef_pos=2*`gr'+1
		local se_pos=2*`gr'+2
		
		qui replace `var'_WITHcontrols=`2' in `coef_pos'
		qui replace `var'_WITHcontrols=`3' in `se_pos'
	}		
}

file close irslog

order model wage_trim28_nocontrols college20_nocontrols cwage20_nocontrols wage_trim28_WITHcontrols college20_WITHcontrols cwage20_WITHcontrols

outsheet using "${tab}/paper2/appxtable6_crosssecdate${crosssec_apptable_date}.csv", comma replace


****************************
***** Appendix Table 7 *****
****************************

file open atab7 using "${tab}/paper2/appxtable7_irsdate${IRSdate}_tfxdate${tfxdate}.csv", write text replace
file write atab7 ",college20 coeff,college20 se,college20 Nind,cwage20 coeff,cwage20 se,cwage20 Nind,wage_trim28 coeff,wage_trim28 se,wage_trim28 Nind"

***** Panel A *****

*** Row 1: Baseline results, copied from main tables
file write atab7 _n "baseline,"

reshape_longterm_cc_output college20_r_bl cwage20_r_bl using "${tab}/paper2/table2_irsdate${IRSdate}_tfxdate${tfxdate}.csv", ///
	file_write(atab7)

reshape_longterm_cc_output wage_trim28_r_bl using "${tab}/paper2/table3_irsdate${IRSdate}_tfxdate${tfxdate}.csv", ///
	file_write(atab7)


*** Row 2: Adding student controls [and therefore run on the inside]
file write atab7 _n "individual controls,"

file open irslog using "${datadir}/from_IRS/nyc_130528_v4_070213.lst", read

file read irslog line

foreach residvar in college20_r_ci cwage20_r_ci wage_trim28_r_ci {
	while (trim(`"`line'"')!="Regression Analysis for Dependent Variable `residvar'" & r(eof)==0) {
		file read irslog line
	}
	while (`"`1'"'!="Number" & `"`2'"'!="of" & `"`3'"'!="Observations" & r(eof)==0) {
		file read irslog line
		tokenize `"`line'"', parse(" ")
	}
	di "`line'"
	local N="`4'"
	while (trim(`"`line'"')!="Estimated Regression Coefficients" & r(eof)==0) {
		file read irslog line
	}
	while (`"`1'"'!="tv_sd" & r(eof)==0) {
		file read irslog line
		tokenize `"`line'"', parse(" ")
	}
	di `"`line'"'
	local coeff="`2'"
	local se="`3'"
	file write atab7 "`coeff',`se',`N',"
}

file close irslog

***** Panel B *****
file write atab7 _n

*** Not in table: Clustering by class instead of sch_cohort
file write atab7 _n "class clusters,"

use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}, clear

longterm_crossclass_table college20 cwage20 wage_trim28, ///
	controls(${controls}) replace r_suffix(_bl) ///
	output(${datadir}/paper2_appxtable7_classcluster_irsdate${IRSdate}_tfxdate${tfxdate}.csv) ///
	robust

reshape_longterm_cc_output college20_r_bl cwage20_r_bl wage_trim28_r_bl ///
	using "${datadir}/paper2_appxtable7_classcluster_irsdate${IRSdate}_tfxdate${tfxdate}.csv", ///
	file_write(atab7)
	

*** Not in table: Bootstrap
file write atab7 _n "bootstrap,"

use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}, clear

keep college20 college20_count cwage20 cwage20_count wage_trim28 wage_trim28_count ///
	tv_sd middle math middle_math sch_cohort teacher tv_insample ${controls}

capture program drop _bootstrap_reg
program define _bootstrap_reg
	syntax varname
	
	capture drop `varlist'_r_bootstrap
	longterm_crossclass_table `varlist', ///
		controls(${controls}) r_suffix(_bootstrap)
end

foreach var of varlist college20 cwage20 wage_trim28 {
	
	bootstrap tv_sd=_b[tv_sd], reps(100) seed(823795) : _bootstrap_reg `var'

	file write atab7 (_b[tv_sd]) "," (_se[tv_sd]) ","
	sum `var'_count if e(sample)
	file write atab7 (r(sum)) ","
}


*** Row 1: Clustering by school instead of sch_cohort
file write atab7 _n "sch clusters,"

use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}, clear

longterm_crossclass_table college20 cwage20 wage_trim28, ///
	controls(${controls}) replace r_suffix(_bl) ///
	output(${datadir}/paper2_appxtable7_schcluster_irsdate${IRSdate}_tfxdate${tfxdate}.csv) ///
	cluster(sch)

reshape_longterm_cc_output college20_r_bl cwage20_r_bl wage_trim28_r_bl ///
	using "${datadir}/paper2_appxtable7_schcluster_irsdate${IRSdate}_tfxdate${tfxdate}.csv", ///
	file_write(atab7)



***** Panel C *****
file write atab7 _n

*** Row 1: Repeat baseline but condition on mean_covered>=0.95
file write atab7 _n "mean_covered>=0.95,"

use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}, clear

* Generate mean_covered
g covered_tv = (tv~=.)
bys sch grade year math: egen mean_covered=wtmean(covered_tv), weight(CLass_size)

* Residualize & perform regs
longterm_crossclass_table college20 cwage20 wage_trim28 if mean_covered>=0.95, ///
	controls(${controls}) replace r_suffix(_lowimpute) ///
	output(${datadir}/paper2_appxtable7_lowimpute_irsdate${IRSdate}_tfxdate${tfxdate}.csv)

* Load results and output
reshape_longterm_cc_output college20_r_lowimpute cwage20_r_lowimpute wage_trim28_r_lowimpute ///
	using "${datadir}/paper2_appxtable7_lowimpute_irsdate${IRSdate}_tfxdate${tfxdate}.csv", ///
	file_write(atab7)


*** Row 2: Repeat baseline but condition on mean_matched>median(mean_matched)
file write atab7 _n "mean_matched>median(mean_matched),"

use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}, clear

* Generate mean_matched & mean_matched>median(mean_matched) indicator
bys sch grade year math: egen mean_matched = wtmean(matched), weight(CLass_size)
gen high_matched=.
forvalues middle=0/1 {
	forvalues math=0/1 {
		qui sum mean_matched if middle==`middle' & math==`math', d
		replace high_matched=(mean_matched>r(p50)) if !missing(mean_matched) & middle==`middle' & math==`math'
	}
}

* Residualize & perform regs
longterm_crossclass_table college20 cwage20 wage_trim28 if high_matched==1, ///
	controls(${controls}) replace r_suffix(_highmatch) ///
	output(${datadir}/paper2_appxtable7_highmatch_irsdate${IRSdate}_tfxdate${tfxdate}.csv)

* Load results and output
reshape_longterm_cc_output college20_r_highmatch cwage20_r_highmatch wage_trim28_r_highmatch ///
	using "${datadir}/paper2_appxtable7_highmatch_irsdate${IRSdate}_tfxdate${tfxdate}.csv", ///
	file_write(atab7)


file close atab7

****************************
***** Appendix Table 8 *****
****************************

*** Sensitivity to Trimming

use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}, clear
estimates clear

file open trimming using ${tab}/paper2/appxtable8_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text replace
file write trimming ",coeff,se,N,yvar mean,weighted N,if cond" _n
file close trimming

foreach var of varlist score college20 cwage20 wage_trim28 {
	if ("`var'"=="score") local tv_var="tv"
	else local tv_var="tv_sd"
	
	* Trim Upper Tail by 5% to 0%
	forval i=95/100 {
		longterm_crossclass_table `var' if percent_tv<=`i', ///
			notvinsample tv_var(`tv_var') ///
			controls(${controls}) append r_suffix(_trim_`i') ///
			output(${tab}/paper2/appxtable8_irsdate${IRSdate}_tfxdate${tfxdate}.csv)
	}
	
	* Trim Bottom and Top 1%
	longterm_crossclass_table `var' if percent_tv>=2 & percent_tv<=99, ///
		notvinsample tv_var(`tv_var') ///
		controls(${controls}) append r_suffix(_trim_bt2) ///
		output(${tab}/paper2/appxtable8_irsdate${IRSdate}_tfxdate${tfxdate}.csv)
		
	* Jacob and Levitt Proxy
	longterm_crossclass_table `var' if flag_levitt==0, ///
		notvinsample tv_var(`tv_var') ///
		controls(${controls}) append r_suffix(_trim_jl) ///
		output(${tab}/paper2/appxtable8_irsdate${IRSdate}_tfxdate${tfxdate}.csv)
}

****************************
***** Appendix Table 9 *****
****************************

*** Panel A: Impact of Teacher VA on College Attendance by Age
use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}, clear
estimates clear

longterm_crossclass_table college18 college19 college20 college21 college22 college23 college24 college25 college26 college27 college28, ///
	controls(${controls}) replace r_suffix(_bl) ///
	output(${tab}/paper2/appxtable9_panelA_irsdate${IRSdate}_tfxdate${tfxdate}.csv)


*** Figure 1c
insheet using ${tab}/paper2/appxtable9_panelA_irsdate${IRSdate}_tfxdate${tfxdate}.csv, comma clear
drop tv_sd
gen age=_n+17
gen upper=coeff+1.96*se
gen lower=coeff-1.96*se

foreach var of varlist coeff upper lower {
	replace `var'=`var'*100
}

twoway  (scatter coeff age, c(l)) ///
	(scatter upper age, m(i) c(l) lcolor(black)) ///
	(scatter lower age, m(i) c(l) lcolor(black)), ///
	graphregion(fcolor(white)) ///
	title("Impact of Teacher Value-Added on College Attendance by Age", size(medium)) ///
	xtitle("Age") ///
	ytitle("Impact of 1 SD of VA on College Attendance Rate") ///
	ylab(-.25(.25)1) ///
	legend(order(1 "Impact of 1 SD Increase in TVA on College Attendance" 2 "95% CI"))
multi_graph_export using ${figdir}/paper2/fig1c_college_by_age_irsdate${IRSdate}_tfxdate${tfxdate}


*** Panel B: Impacts of Teacher Value-Added on Earnings by Age

use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}, clear
estimates clear

longterm_crossclass_table wage_trim20 wage_trim21 wage_trim22 wage_trim23 wage_trim24 wage_trim25 wage_trim26 wage_trim27 wage_trim28 wage_trim29 wage_trim30 wage_trim31, ///
	controls(${controls}) replace r_suffix(_bl) ///
	output(${tab}/paper2/appxtable9_panelB_irsdate${IRSdate}_tfxdate${tfxdate}.csv)


*** Figure 2b
insheet using ${tab}/paper2/appxtable9_panelB_irsdate${IRSdate}_tfxdate${tfxdate}.csv, comma clear
drop tv_sd
gen age=_n+19

gen effect=coeff/yvarmean*100
gen upper=(coeff+1.96*se)/yvarmean*100
gen lower=(coeff-1.96*se)/yvarmean*100

drop if age>28
twoway  (scatter effect age, c(l)) ///
	(scatter upper age, m(i) c(l) lcolor(black)) ///
	(scatter lower age, m(i) c(l) lcolor(black)), ///
	graphregion(fcolor(white)) ///
	title("Impact of Teacher Value-Added on Earnings by Age", size(medium)) ///
	xtitle("Age") ///
	ytitle("Impact of 1 SD of VA on Earnings, in %") ///
	legend(order(1 "Impact of 1 SD Increase in TVA on Earnings" 2 "95% CI"))
multi_graph_export using ${figdir}/paper2/fig2b_earnings_by_age_irsdate${IRSdate}_tfxdate${tfxdate}



*****************************
***** Appendix Table 10 *****
*****************************

* Fade-Out Coefficients

use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}, clear

longterm_crossclass_table score f_z_score f2_z_score f3_z_score f4_z_score, ///
	controls(${controls}) replace r_suffix(_fadeout) ///
	output(${tab}/paper2/appxtable10_irsdate${IRSdate}_tfxdate${tfxdate}.csv) ///
	tv_var(tv)

* Figure 4: Fade-out figure
insheet using ${tab}/paper2/appxtable10_irsdate${IRSdate}_tfxdate${tfxdate}.csv, comma clear
gen event_year=_n-1
gen upper=coeff+1.96*se
gen lower=coeff-1.96*se
drop tv

twoway  (scatter coeff event_year, c(l)) ///
	(scatter upper event_year, msymbol(i) c(l) lcolor(gs8)) ///
	(scatter lower event_year, msymbol(i) c(l) lcolor(gs8)), ///
	graphregion(fcolor(white)) ///
	xlabel(0/4) ///
	ylabel(0(0.2)1) ///
	ytitle("Impact of Current Teacher VA on Test Score") ///
	xtitle("Year") ///
	title("Impacts of Teacher Value-Added on Future Test Scores") ///
	legend(order(1 "Coefficient" 2 "95% CI"))
multi_graph_export using ${figdir}/paper2/fig4_fadeout_irsdate${IRSdate}_tfxdate${tfxdate}


***********************************
***** Appendix Tables 11 & 12 *****
***********************************

* These are the grade-by-grade tables.  They are done together because the numbers in Appx Table 11 rely on those in Appx Table 12


***** APPENDIX TABLE 12: Tracking Coefficients

*** Prepare tracking analysis from full school-district data

* Generate class-collapse file that only contains tv_sd (to increase merge speed)
use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}.dta, clear
reg college20 tv_sd, cluster(sch_cohort)
sum tv_sd [w=CLass_size] if e(sample)
di "Scaling Factor for True VA on LHS = " 1/r(sd)
scalar scaling = 1/r(sd)
keep sch year class_id math tv_sd
sort sch year class_id math
save ${datadir}/class_tvsd_tfxdate${tfxdate}.dta, replace

* Merge tv_sd onto the individual-level data
use stuid math year class_id sch grade using ${datadir}/schd_work_${SCHD_workdate}.dta, clear
sort sch year class_id math
merge m:1 sch year class_id math using ${datadir}/class_tvsd_tfxdate${tfxdate}.dta, sorted keep(3) nogen

* Store values of future tv_sd, restricting to those who proceed through grades at normal pace
egen stu_course_id = group(stuid math)
sort stu_course_id year
tsset stu_course_id year

forvalues i=1/4 {
	gen f`i'_tv_sd=f`i'.tv_sd if f`i'.grade==(grade+`i')
}

* Collapse tracking data to class-level
collapse (mean) tv_sd f1_tv_sd f2_tv_sd f3_tv_sd f4_tv_sd ///
	 (count) tv_sd_count=tv_sd f1_tv_sd_count=f1_tv_sd f2_tv_sd_count=f2_tv_sd f3_tv_sd_count=f3_tv_sd f4_tv_sd_count=f4_tv_sd ///
	 , by(sch year class_id math)
save ${datadir}/tracking_analysis_tfxdate${tfxdate}.dta, replace


*** Analyze tracking

* Merge on additional class-level variables
use ${datadir}/tracking_analysis_tfxdate${tfxdate}.dta, clear
merge 1:1 sch year class_id math using ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}.dta, ///
	keepusing(tv_insample teacher grade middle middle_math sch_cohort ${controls} ${par_controls}) ///
	assert(3) nogen

* Residualize each future tv_sd variable
forvalues i=1/4 {
	residualize_middle_math f`i'_tv_sd_r=f`i'_tv_sd, tv_insample controls(${controls} ${par_controls})
}

* Compute coef & SE of tracking, and store in matrices
matrix sortTV = I(5)
matrix sortTVSE = I(5)

forvalues grade=4/7 {
	forvalues lead=1/`=8-`grade'' {
		qui reg f`lead'_tv_sd_r tv_sd middle math middle_math if grade==`grade' [w=f`lead'_tv_sd_count], cluster(sch_cohort)
			
		mat sortTV[`grade'-3+`lead',`grade'-3]=scaling*_b[tv_sd]
		mat sortTVSE[`grade'-3+`lead',`grade'-3]=scaling*_se[tv_sd]
	}
}

* Output coef & SE of tracking to csv
file open tracking using ${tab}/paper2/appxtable12_tracking_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text replace
file write tracking ",Grade 5,Grade 6,Grade 7,Grade 8" _n

forvalues grade=4/7 {
	file write tracking "Grade `grade' Teacher VA,"
	
	* Output coeffs
	forvalues i=1/`=`grade'-4' {
		file write tracking ","
	}
	forvalues lead=1/`=8-`grade'' {
		file write tracking (sortTV[`grade'-3+`lead',`grade'-3]) ","
	}
	file write tracking _n
	
	* Output SEs
	forvalues i=0/`=`grade'-4' {
		file write tracking ","
	}
	forvalues lead=1/`=8-`grade'' {
		file write tracking (sortTVSE[`grade'-3+`lead',`grade'-3]) ","
	}
	file write tracking _n
}

file close tracking

* Output coef & SE of tracking to screen
mat list sortTV
mat list sortTVSE



***** APPENDIX TABLE 11: Impacts of Value-Added on College Quality by Grade

*** Calculate structural coefficients

use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}, clear

*Cut sample at cohort>=1990 (i.e. KG in 1990 or later --> 4th grade in 1994 or later) to have more balanced data across grades
/* Note: sharp drop in frac missing in grades 7-8 starting in cohort 1990
g miss_tv = missing(tv_sd)
table cohort grade [w=CLass_size] if cohort>1986, c(mean miss_tv)
*/

global cohortcutoff_gradebygrade = 1990

matrix reducedForm = J(5,1,.)
matrix reducedFormSE = J(5,1,.)
matrix ste = J(5,1,.)

residualize_middle_math cwage20_r_par=cwage20 if cohort>=${cohortcutoff_gradebygrade}, tv_insample controls(${controls} ${par_controls})

forvalues grade=4/8 {
	di "Grade " `grade' ":"
	
	longterm_crossclass_table cwage20 if cohort>=${cohortcutoff_gradebygrade} & grade==`grade', ///
		noresid ///
		controls(${controls} ${par_controls}) r_suffix(_par)

	matrix reducedForm[`grade'-3,1]= _b[tv_sd]
	matrix reducedFormSE[`grade'-3,1]= _se[tv_sd]
	di "--------------------------"
}

mat ste[5,1] = reducedForm[5,1]
mat ste[4,1] = reducedForm[4,1] - ste[5,1]*sortTV[5,4]
mat ste[3,1] = reducedForm[3,1] - ste[5,1]*sortTV[5,3] - ste[4,1]*sortTV[4,3]
mat ste[2,1] = reducedForm[2,1] - ste[5,1]*sortTV[5,2] - ste[4,1]*sortTV[4,2] - ste[3,1]*sortTV[3,2]
mat ste[1,1] = reducedForm[1,1] - ste[5,1]*sortTV[5,1] - ste[4,1]*sortTV[4,1] - ste[3,1]*sortTV[3,1] - ste[2,1]*sortTV[2,1]


file open struc using ${tab}/paper2/appxtable11_gradebygrade_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text replace
file write struc "grade,reduced_form_coeff,reduced_form_SE,structural_est" _n

forvalues i=1/5 {
	file write struc (`i'+3) "," (reducedForm[`i',1]) "," (reducedFormSE[`i',1]) "," (ste[`i',1]) "," _n
}
file close struc


di "These are tracking coefficients, destination grade by row, base grade by column"
mat list sortTV
di "These are tracking SEs, destination grade by row, base grade by column"
mat list sortTV
di "These are reduced form coefs"
mat list reducedForm
di "These are reduced form SEs"
mat list reducedFormSE
di "These are structural estimates"
mat list ste


***** Figure 7: plot of Appendix Table 11

insheet using "${tab}/paper2/appxtable11_gradebygrade_irsdate${IRSdate}_tfxdate${tfxdate}.csv", comma clear

gen reduced_form_upper=reduced_form_coeff+1.96*reduced_form_se
gen reduced_form_lower=reduced_form_coeff-1.96*reduced_form_se

twoway (scatter reduced_form_coeff grade, c(l) lc(navy) mc(navy)) ///
	(scatter reduced_form_upper grade, c(l) lc(gs8) m(i)) ///
	(scatter reduced_form_lower grade, c(l) lc(gs8) m(i)) ///
	(scatter structural_est grade, c(l) lc(maroon) m(T) mc(maroon)), ///
	graphregion(fcolor(white)) ///
	ylab(0(200)800) ///
	title("Impacts of Teacher Value-Added on College Quality by Grade", size(medium)) ///
	xtitle("Grade") ///
	ytitle("Impact of VA on College Quality at Age 20") ///
	legend(order(1 "Reduced Form Coeffs" 2 "Reduced Form 95% CI" 4 "Net of Teacher Tracking"))
multi_graph_export using ${figdir}/paper2/fig7_cwage20_bygrade_irsdate${IRSdate}_tfxdate${tfxdate}


******************************
*****  Appendix Table 13 *****
******************************


***** Paper Only: Attrition Stats *****

* Use a file with all teachers, not just those matched with class data.  Those matched with class data have longer tenures
*   mechanically because some started in the district well before we got class/course data from their schools/grades.
use teacher year sch using ${datadir}/final_teacher_list_in_schd_work_schools.dta, clear

sum year
assert r(min)==1989
assert r(max)==2009

* Generate indicator for whether the teacher is new to teaching in the district
*   (note: could define this for 1989 using experience==0, but we can't define new to school in 1989)
bys teacher (year): gen new_to_district=(_n==1) if year>1989

* Keep only teachers who entered the district after 1989
bys teacher: egen evernew=max(new_to_district)
keep if evernew==1

* Generate attrition indicators 
bys teacher (year): gen switch_district=(teacher!=teacher[_n+1]) if year<2009

* Generate var for years in district
bys teacher (year): gen years_in_district=_n

* Generate indicator for teachers who spend at least 3 years teaching in the district
bys teacher: egen ever3=max(years_in_district==3)

* Output attrition stats
preserve
collapse (mean) switch_district, by(years_in_district)

gen cum_switch_district=switch_district in 1
forvalues n=2/`=_N' {
	* increment cum_switch_district by P(switch_district|still in district) * P(still in district)
	replace cum_switch_district=cum_switch_district[_n-1]+switch_district*(1-cum_switch_district[_n-1]) in `n'
}

list, clean noobs
outsheet using ${tab}/paper2/paperonly_district_attrition_by_tenure.csv, replace comma
restore

* Output attrition stats conditional on reaching 3 years of teaching in district
preserve	
keep if ever3==1
collapse (mean) switch_district, by(years_in_district)

gen cum_switch_district=switch_district in 1
forvalues n=2/`=_N' {
	* increment cum_switch_district by P(switch_district|still in district) * P(still in district)
	replace cum_switch_district=cum_switch_district[_n-1]+switch_district*(1-cum_switch_district[_n-1]) in `n'
}

list, clean noobs
outsheet using ${tab}/paper2/paperonly_district_attrition_by_tenure_y3plus.csv, replace comma
restore




***** PERFORM POLICY IMPACT SIMULATIONS *****

*** Adjust elem cov_sameyear to use the quadratic extrapolation

* Compute square of the quadratic extrap
use ${datadir}/tfx/sd_tfx_${tfxdate}, clear

sum sd_tfx if middle==0 & math==0
scalar _cov_sameyear_elem_read=r(mean)^2

sum sd_tfx if middle==0 & math==1
scalar _cov_sameyear_elem_math=r(mean)^2

* Store in variance csv
insheet using "${datadir}/tfx/tfx_${tfxdate}_variance.csv", comma clear
replace cov_sameyear_elementary_reading=_cov_sameyear_elem_read in -1
replace cov_sameyear_elementary_math=_cov_sameyear_elem_math in -1

outsheet using "${datadir}/tfx/tfx_${tfxdate}_variance_elem_quadextrap.csv", comma replace

* Get mean class size (note: class-weighted, whereas Table 1 is student-weighted)
use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}, clear
sum CLass_size if any_l97==1
scalar __classsize = r(mean)

*** Policy impact when one observes class scores in previous years
local classsize=__classsize
vam_policysim using "${datadir}/tfx/tfx_${tfxdate}_variance_elem_quadextrap.csv", ///
	output("${datadir}/policyimpact_tfxdate${tfxdate}") ///
	nteachers(1000000) nyears(16) nstudents(`classsize') nclasses(1) ///
	cut(0.05) impacthorizon(1) decisionyears(1/15) ///
	onlygroups(1 2) ///
	max_futuresumhorizon(10) ///
	driftlimit(7)

*** Policy impact supposing one observes true VA in previous years
local classsize=__classsize
vam_policysim using "${datadir}/tfx/tfx_${tfxdate}_variance_elem_quadextrap.csv", ///
	output("${datadir}/policyimpact_tfxdate${tfxdate}_trueVA") ///
	nteachers(1000000) nyears(16) nstudents(`classsize') nclasses(1) ///
	cut(0.05) impacthorizon(1) decisionyears(1/15) ///
	onlygroups(1 2) ///
	driftlimit(7) ///
	max_futuresumhorizon(10) ///
	zero_var_ind zero_var_class

*** Policy impact when one observes class scores in previous years, and discounts based on survival vector
insheet using ${tab}/paper2/paperonly_district_attrition_by_tenure.csv, comma clear
gen cum_survival=1-cum_switch_district[_n-1]
replace cum_survival=1 in 1
local cum_survival=""
forvalues i=1/16 {
	local cum_survival `cum_survival' `=cum_survival[`i']'
}
di `"`cum_survival'"'

local classsize=__classsize
vam_policysim using "${datadir}/tfx/tfx_${tfxdate}_variance_elem_quadextrap.csv", ///
	output("${datadir}/policyimpact_tfxdate${tfxdate}_discountsurvival") ///
	nteachers(1000000) nyears(16) nstudents(`classsize') nclasses(1) ///
	cut(0.05) decisionyears(3) ///
	onlygroups(1 2) ///
	max_futuresumhorizon(10) ///
	driftlimit(7) ///
	survival(`cum_survival') impacthorizon(10)


*** Transform from impact on tv to impact on tv_sd
set more off
foreach file in "${datadir}/policyimpact_tfxdate${tfxdate}" "${datadir}/policyimpact_tfxdate${tfxdate}_trueVA" "${datadir}/policyimpact_tfxdate${tfxdate}_discountsurvival" {

	use `file', clear
	gen middle=inlist(group,3,4)
	gen math=inlist(group,2,4)
	merge m:1 middle math using ${datadir}/tfx/sd_tfx_${tfxdate}, assert(2 3) keep(3) nogen
	foreach var of varlist effect exacteffect_nextyear year* {
		replace `var'=`var'/sd_tfx
	}

	save, replace
}

***** DEFINE SCALARS USED IN TABLE AND FIG CALCS ******

* Define scalar for class size
use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}, clear
sum CLass_size if any_l97==1
scalar __classsize = r(mean)

* Define scalar for wage effect of better teacher
insheet using ${tab}/paper2/table3_irsdate062513_tfxdate042213.csv, comma clear
keep if tv_sd=="wage_trim28_r_par"
assert _N==1
scalar __b=coeff/yvarmean

* Define other scalars
scalar __p5_mean_sd=normalden(invnormal(0.05)) / normal(invnormal(0.05)) /* this is an inverse mills ratio */
scalar __NPV_wage = 521669.17
scalar __undisc_scale = 2886507.71/ __NPV_wage



***** Paper Only: Ideal Gains *****
file open idealeff using ${tab}/paper2/paperonly_policy_ideal_effects_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text replace

file write idealeff "Gains from deselecting teacher in bottom 5% of distribution:" _n
file write idealeff "NPV student," (__p5_mean_sd * __NPV_wage * __b) _n
di __p5_mean_sd * __NPV_wage * __b

file write idealeff "NPV class," (__p5_mean_sd * __NPV_wage * __b * __classsize) _n
di __p5_mean_sd * __NPV_wage * __b * __classsize

file write idealeff "Undiscounted student," (__undisc_scale * __p5_mean_sd * __NPV_wage * __b) _n
di __undisc_scale * __p5_mean_sd * __NPV_wage * __b

file write idealeff "Undiscounted class," (__undisc_scale * __p5_mean_sd * __NPV_wage * __b * __classsize) _n
di __undisc_scale * __p5_mean_sd * __NPV_wage * __b * __classsize


file write idealeff _n "Gains from deselecting teacher in bottom 5% of distribution with correlated English and Math r=0.6:" _n
clear
scalar __VAcorr=0.6

matrix P = (1,__VAcorr \__VAcorr, 1)
matrix A = cholesky(P)
matrix list A

set obs 1000000
set seed 2015623

gen va1= rnormal()
gen va2 = A[2,1]*va1 + A[2,2]*rnormal()
gen mean_va=(va1+va2)/2

sum mean_va, d
sum mean_va if mean_va < r(p5)
local VAgain=-r(mean)
file write idealeff "VA gain," (`VAgain') _n

file write idealeff "Earnings impact of 1 SD gain in a single subject," (__b/(1+__VAcorr)) _n

file write idealeff "NPV student," (__NPV_wage * 2 * `VAgain' * (__b/(1+__VAcorr))) _n
file write idealeff "NPV class," (__NPV_wage * 2 * `VAgain' * (__b/(1+__VAcorr)) * __classsize) _n
file write idealeff "Undiscounted student," (__undisc_scale * __NPV_wage * 2 * `VAgain' * (__b/(1+__VAcorr))) _n
file write idealeff "Undiscounted class," (__undisc_scale * __NPV_wage * 2 * `VAgain' * (__b/(1+__VAcorr)) * __classsize) _n


file write idealeff _n "Gains from retaining teacher 1 SD above mean:" _n

file write idealeff "NPV student," (__NPV_wage * __b) _n
di __NPV_wage * __b

file write idealeff "NPV class," (__NPV_wage * __b * __classsize) _n
di __NPV_wage * __b * __classsize

file write idealeff "Undiscounted student," (__undisc_scale * __NPV_wage * __b) _n
di __undisc_scale * __NPV_wage * __b

file write idealeff "Undiscounted class," (__undisc_scale * __NPV_wage * __b * __classsize) _n
di __undisc_scale * __NPV_wage * __b * __classsize

file close idealeff


***** Paper Only: Rookie Stats *****
file open rookie using ${tab}/paper2/paperonly_policy_rookies_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text replace

use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}, clear

sum score_r if t_exp_reg==0 [w=score_r_count]
file write rookie "Mean test score residual for rookie teachers:" _n (r(mean)) _n _n

sum score_r [w=score_r_count]
file write rookie "Sample mean test score residual:" _n (r(mean)) _n _n

insheet using ${tab}/paper2/paperonly_district_attrition_by_tenure_y3plus.csv, comma clear
sum years_in_district if cum_switch_district>0.5
file write rookie "Median number of years spent in district, conditional on spending at least 3 years:" _n (r(min)) _n _n

use ${datadir}/tfx/sd_tfx_${tfxdate}, clear
keep if middle==0
sum sd_tfx
file write rookie "Average SD of teacher effects across subjects:" _n (r(mean)) _n _n

file close rookie



***** PANEL A *****

*** Prep
use ${datadir}/policyimpact_tfxdate${tfxdate}, clear
rename exacteffect_nextyear exacteffect_nextyear_est

merge 1:1 _n using ${datadir}/policyimpact_tfxdate${tfxdate}_trueVA, keepusing(exacteffect_nextyear) nogenerate assert(3)
rename exacteffect_nextyear exacteffect_nextyear_true

* Horizontal Line:
scalar __ideal_NPVclass =  __p5_mean_sd * __NPV_wage * __classsize * __b

* 2 Data Series (Estimated VA, True VA)
gen NPVclass_est  = -1 * __NPV_wage * __classsize * __b * exacteffect_nextyear_est
gen NPVclass_true = -1 * __NPV_wage * __classsize * __b * exacteffect_nextyear_true

* Paper only calcs
file open policy using ${tab}/paper2/paperonly_policy_estimated_effects_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text replace

sum exacteffect_nextyear_est if decisionyear==1
assert r(N)==2
file write policy "VA gain from deselecting after 1 year using estimated VA:" _n (-r(mean)) _n _n

sum NPVclass_est if decisionyear==3
assert r(N)==2
file write policy "NPV class gain from deselecting after 3 years if forecast bias is 9.1%:" _n (0.91*r(mean)) _n _n

sum effect if decisionyear==3 & decisionrule==3
assert r(N)==2
local gain_nodrift=r(mean)
sum effect if decisionyear==3 & decisionrule==1
assert r(N)==2
local gain_drift=r(mean)
file write policy "When selecting based on 3 years of data not accounting for drift yields this percentage of the gains::" _n (`gain_nodrift'/`gain_drift'*100) _n _n

file close policy

* Collapse the two subjects
keep if decisionrule==1
collapse (mean) NPVclass_est NPVclass_true, by(decisionyear)

* Generate undiscounted vars for Cols 2 & 4
gen NPVclass_undisc_est = NPVclass_est * __undisc_scale
gen NPVclass_undisc_true = NPVclass_true * __undisc_scale
order decisionyear NPVclass_est NPVclass_undisc_est NPVclass_true NPVclass_undisc_true


*** Output Table Panel
outsheet using ${tab}/paper2/appxtable13_panelA_irsdate${IRSdate}_tfxdate${tfxdate}.csv, comma replace

* add max effect
file open maxeff using ${tab}/paper2/appxtable13_panelA_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text append
file write maxeff _n "max effect," (__ideal_NPVclass) "," (__ideal_NPVclass*__undisc_scale)
file close maxeff

*** Figure 8a
replace NPVclass_est=NPVclass_est/1000
replace NPVclass_true=NPVclass_true/1000

local ideal_NPVclass=string(__ideal_NPVclass,"%12.0fc")
twoway (scatter NPVclass_est decisionyear in 1/10, c(l)), ///
       yline(`=__ideal_NPVclass/1000', lc(maroon)) ///
	   xtitle("Number of Years Observed") ///
	   ytitle("Lifetime Earnings Gain Per Class ($1000s)") ///
	   ylabel(0(100)400, gmin gmax) yscale(range(0 450)) ///
	   legend(off) ///
	   title("Earnings Impacts in First Year After Deselection") ///
	   text(425 7 "Gain from Deselection on True VA = $`ideal_NPVclass'") ///
	   graphregion(color(white))
multi_graph_export using ${figdir}/paper2/fig8a_policy_nextyear_irsdate${IRSdate}_tfxdate${tfxdate}



***** PANEL B *****

*** Prep Cols 1 & 2
use ${datadir}/policyimpact_tfxdate${tfxdate}, clear

keep if decisionyear==3 & decisionrule==1

* Make number in first year match Panel A, which doesn't use Monte Carlo
replace year4meanVA=exacteffect_nextyear

forvalues t=4/13 {
	gen NPV_year`t'= -1 * __NPV_wage * __classsize * __b * year`t'meanVA
}

* Collapse the two subjects together
collapse (mean) NPV_year*

* Reshape long
gen id=1
reshape long NPV_year, i(id) j(year)
rename NPV_year NPV
drop id

* Generate undiscounted var
gen NPV_undisc = NPV *  __undisc_scale


*** Output Cols 1 & 2
outsheet using ${tab}/paper2/appxtable13_panelB_cols12_irsdate${IRSdate}_tfxdate${tfxdate}.csv, comma replace

* add avg effect
file open avgeff using ${tab}/paper2/appxtable13_panelB_cols12_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text append
file write avgeff _n "avg effect"

sum NPV
scalar __avgNPV_est=r(mean)
file write avgeff "," (r(mean))

sum NPV_undisc
file write avgeff "," (r(mean))

file close avgeff


* Save a dataset with col1 for figure
gen NPV_est=NPV/1000
keep year NPV_est
save ${datadir}/policy_overtime_est, replace


*** Prep Cols 3 & 4
use ${datadir}/policyimpact_tfxdate${tfxdate}_trueVA, clear

keep if decisionyear==1 & decisionrule==1

* Make number in first year match Panel A, which doesn't use Monte Carlo
gen NPV_year1 = __NPV_wage * __classsize * __b * __p5_mean_sd

forvalues t=2/10 {
	gen NPV_year`t'= -1 * __NPV_wage * __classsize * __b * year`t'meanVA
}

* Collapse the two subjects together
collapse (mean) NPV_year*

* Reshape long
gen id=1
reshape long NPV_year, i(id) j(year)
rename NPV_year NPV
drop id

* Generate undiscounted var
gen NPV_undisc = NPV *  __undisc_scale


*** Output Cols 3 & 4
outsheet using ${tab}/paper2/appxtable13_panelB_cols34_irsdate${IRSdate}_tfxdate${tfxdate}.csv, comma replace

* add avg effect
file open avgeff using ${tab}/paper2/appxtable13_panelB_cols34_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text append
file write avgeff _n "avg effect"

sum NPV
scalar __avgNPV_true=r(mean)
file write avgeff "," (r(mean))

sum NPV_undisc
file write avgeff "," (r(mean))

file close avgeff

* Prepare dataset with col 1 & col 3 for figure
gen NPV_true=NPV/1000
keep year NPV_true
replace year=year+3

merge 1:1 year using ${datadir}/policy_overtime_est, assert(3) nogen


*** Figure 8b
local avg_effect_est=string(__avgNPV_est,"%12.0fc")
local avg_effect_true=string(__avgNPV_true,"%12.0fc")

twoway (scatter NPV_est year, c(l)) ///
       (scatter NPV_true year, c(l) ms(T)), ///
       xline(3.5, lc(gs8)) ///
	   xtitle("School Years Since Teacher Was Hired") ///
	   xlabel(1(1)13) ///
	   ytitle("Lifetime Earnings Gain Per Class ($1000s)") ///
	   ylabel(0(100)400, gmin gmax) yscale(range(0 450)) ///
	   legend(order(1 "Deselected on Estimated VA" 2 "Deselected on True VA")) ///
	   title("Earnings Impact Over Time") ///
	   text(120 10 "Average Gain = $`avg_effect_est'") ///
	   text(250 10 "Average Gain = $`avg_effect_true'") ///
	   graphregion(color(white))
multi_graph_export using ${figdir}/paper2/fig8b_policy_after3yrs_irsdate${IRSdate}_tfxdate${tfxdate}


***** Paper only: gain from projecting VA over all future years and discounting by survival probabilities
use ${datadir}/policyimpact_tfxdate${tfxdate}_discountsurvival.dta, clear

sum effect if decisionrule==1
assert r(N)==2
local gain_nextyear=r(mean)
sum effect if decisionrule==2
assert r(N)==2
local gain_discsum=r(mean)

di (`gain_discsum'/`gain_nextyear')
file open policy using ${tab}/paper2/paperonly_policy_estimated_effects_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text append
file write policy "Relative gain over 10 years from deselecting after 3 years based on projected future VA discounted by survival probabilities instead of simple next year projection:" _n (`gain_discsum'/`gain_nextyear') _n _n
file close policy

*** Paper only: retention policy
use ${datadir}/policyimpact_tfxdate${tfxdate}, clear

sum exacteffect_nextyear if decisionyear==3 & decisionrule==1
assert r(N)==2
local retention_gain=-1 * r(mean) * (invnormal(0.95) / __p5_mean_sd) * __NPV_wage * __classsize * __b

file open policy using ${tab}/paper2/paperonly_policy_estimated_effects_irsdate${IRSdate}_tfxdate${tfxdate}.csv, write text append

file write policy "Gain in subsequent year from retaining a teacher at the 95th percentile of the estimated VA distribution using 3 years of data:" _n (`retention_gain') _n _n
di `retention_gain'

file write policy "Estimated average benefit of $1800 bonus policy:" _n (`retention_gain'*.015) _n _n
di `retention_gain'*.015

file close policy



********************
***** Figure 1 *****
********************

* Figure 1ab: see above in Table 2 code.
* Figure 1c: see above in Appendix Table 9 code.


********************
***** Figure 2 *****
********************

* Figure 2a: see above in Table 3 code.
* Figure 2b: see above in Appendix Table 9 code.


********************
***** Figure 3 *****
********************

* see above in Table 4 code.


********************
***** Figure 4 *****
********************

* see above in Appendix Table 10 code.


********************
***** Figure 5 *****
********************

* see above in Table 5 code.


********************
***** Figure 6 *****
********************

* see above in Table 5 code.


********************
***** Figure 7 *****
********************

* see above in Appendix Table 11 & 12 code.


********************
***** Figure 8 *****
********************

* see above in Appendix Table 13 code.


*****************************
***** Appendix Figure 1 *****
*****************************

* Prep
use "${datadir}/cq_trim_3.dta" , clear
keep if age==20
keep if coll_yr==1999
drop age wage_yr coll_yr
drop w2_wage_med earnings_mean

rename w2_wage_mean w2_wage

bys coll_id: egen mean_n_obs = mean(n_obs)
*keep if mean_n_obs>100
drop n_obs

order coll_id age_wage
sort coll_id age_wage

reshape wide w2_wage, i(coll_id) j(age_wage)


* Appendix Figure 1a: College Quality Ranks with earnings measured at different ages
xtile pctile32 = w2_wage32, nq(100)
xtile pctile27 = w2_wage27, nq(100)
xtile pctile23 = w2_wage23, nq(100)

binscatter pctile23 pctile27 pctile32, symbols(o t) colors(navy maroon) nbins(100) ///
	graphregion(fcolor(white)) ///
	title("Earnings-Based Ranks of Colleges: 1 Year Out vs. 5 Years Out", size(medium)) ///
	xtitle("Percentile Ranking of College Based on Earnings Measured 10 Years Out (Age 32)") ///
	ytitle("Percentile Ranking of College Based on Earnings 1 or 5 Years Out") ///
	legend(lab(1 "1 Year Out of College") lab(2 "5 Years Out of College") order(1 2))
multi_graph_export using ${figdir}/paper2/appxfig1a_collqual_rank1vs5

* Appendix Figure 1b: College Quality Rank Correlation by Age
gen int corr_year=.
replace corr_year=_n+20 in 1/12
gen float corr_value=.

set more off
spearman w2_wage*

mata:
	c=st_matrix("r(Rho)")
	//c[12,.]'
	st_store((1::12),"corr_value",c[12,.]')
end

scatter corr_value corr_year if inrange(corr_year,23,31), ///
	c(l) ///
	graphregion(fcolor(white)) ///
	xlab(23(2)31) ///
	xtitle("Age") ///
	ytitle("Correlation with Mean Earnings at Age 32") ///
	title("Correlation of College Rankings Based on Earnings at Age 32" "with Rankings Based on Earnings at Earlier Ages", size(medium))
multi_graph_export using ${figdir}/paper2/appxfig1b_collqual_corrquality_by_age


*****************************
***** Appendix Figure 2 *****
*****************************

*(a) College Attendance at Age 20
*(b) College Quality
*(c) Earnings
*(d) Teenage Birth

local i=1
set more off
foreach var in college20 cwage20 wage_trim28 teenbirth_fem {

	* Get coeff computed from microdata
	insheet using "${tab}/paper2/appxtable3_crosssecdate${crosssec_apptable_date}.csv", comma clear
	keep model `var'
	keep if model=="With Controls" | model[_n-1]=="With Controls"
	scalar __coeff=`var'[1]
	scalar __se=`var'[2]

	* Generate and save binscatter points
	tempfile binsc_nocontrols
	insheet using "${datadir}/mskd_nyc_binscat_`var'.csv", clear names
	binscatter `var' score, unique(0) savedata(`binsc_nocontrols')
	
	tempfile binsc_WITHcontrols
	insheet using "${datadir}/mskd_nyc_binscat_`var'_r22.csv", clear names
	sum score_fullsample_mean 
	replace score_r_in2 = score_r_in2 + r(mean)  /* add back mean */
	sum `var'_fullsample_mean
	replace `var'_r2 = `var'_r2 + r(mean)  /* add back mean */
	binscatter `var'_r2 score_r_in2, unique(0) savedata(`binsc_WITHcontrols')
	
	* Combine the binscatters
	use "`binsc_WITHcontrols'", clear
	rename score_r_in2 score
	append using "`binsc_nocontrols'"
	
	* Adjust the units
	if inlist("`var'","college20","teenbirth") {
		replace `var' = `var'*100
		replace `var'_r = `var'_r*100
		
		local units="(%)"
		local coef=string(__coeff*100,"%9.2f")+"%"
		local se=string(__se*100,"%9.2f")
	}
	else if inlist("`var'","cwage20","wage_trim28") {
		replace `var' = `var'/1000
		replace `var'_r = `var'_r/1000
		
		local units="($ 1000s)"
		local coef="$"+string(__coeff,"%9.0fc")
		local se=string(__se,"%9.0fc")
	}
	
	* Generate fig
	qui sum score
	local min = `r(min)'
	local max = `r(max)'
	twoway (scatter `var' score, c(l)) ///
		(scatter `var'_r score, m(t)) ///
		(lfit `var'_r score, lcolor(maroon) range(`min' `max')), ///
		graphregion(fcolor(white)) ///
		title("`var'") ///
		xtitle("Score") ///
		ytitle("`var' `units'") ///
		legend(order(1 "No Controls" 2 "With Controls")) ///
		/*note("Coefficient = `coef'" "(`se')", position(5) ring(0) size(medsmall))*/

	* Save fig
	local panel_letter=char(`i'+96)
	multi_graph_export using ${figdir}/paper2/appxfig2`panel_letter'_`var'_scorescatter

	local ++i
}




*****************************
***** Appendix Figure 3 *****
*****************************

use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}, clear

replace outlier=outlier*100
binscatter outlier percent_tv if grade>3, nbins(100) legend(off) xline(99.5) ///
	linetype(noline) ///
	title("Jacob and Levitt (2003) Proxy for Test" "Manipulation vs. Value-Added Estimates", size(medium)) ///
	xtitle("Percentile of Teacher Value-Added (based on other years)") ///
	ytitle("Percentage of Jacob and Levitt (2003) Outliers")
multi_graph_export using ${figdir}/paper2/appxfig3_jacoblevitt_irsdate${IRSdate}_tfxdate${tfxdate}


*****************************
***** Appendix Figure 4 *****
*****************************

use "${datadir}/14year_corr_table.dta", clear

scatter corr_99_11_ctzn age99 if inrange(age99,18,60), ///
	graphregion(fcolor(white)) ///
	c(l) msymbol(o) ///
	title("Correlation of Individual Earnings with Earnings 12 Years Later, by Age", size(medium)) ///
	xtitle("Age") ///
	ytitle("Correlation of Earnings at Age x with Earnings at Age x+12") ///
	xline(23, lcolor(gs8)) ///
	xline(27, lcolor(gs8)) ///
	xline(32, lcolor(gs8))
multi_graph_export using ${figdir}/paper2/appxfig4_earningscorr_14year_irsdate${IRSdate}_tfxdate${tfxdate}



*************************************
***** Figures not used in paper *****
*************************************

*** Stability of College Quality by Cohort Size

use "${datadir}/collqual_collapse_v6_mskd.dta", clear

g age_wage = age+wage_yr-coll_yr
keep if age==20 & age_wage==30 & inrange(coll_yr,1999,2001)

tsset coll_id coll_yr

g n_obs_avg = (n_obs+l.n_obs)/2
xtile nbin = n_obs_avg, nq(20)

g l_coll_wages = l.coll_wages

g corr_mean = .

forvalues b = 1/20 {
	qui corr coll_wages l_coll_wages if nbin==`b'
	qui replace corr_mean = r(rho) if nbin==`b'
}

binscatter corr_mean n_obs_avg , x_q(nbin) linetype(noline) ///
	xline(100) ///
	xtitle("Average Cohort Size") ///
	ytitle("Between Cohort Reliability of College Quality") ///
	title("Stability of College Quality by Cohort Size")

************************************
***** True VA and Estimated VA *****
************************************

*** Adjust elem cov_sameyear to use the quadratic extrapolation
* Compute square of the quadratic extrap
use ${datadir}/tfx/sd_tfx_${tfxdate}, clear
sum sd_tfx if middle==0 & math==0
scalar _cov_sameyear_elem_read=r(mean)^2
sum sd_tfx if middle==0 & math==1
scalar _cov_sameyear_elem_math=r(mean)^2

* Store in variance csv
insheet using ${datadir}/tfx/tfx_${tfxdate}_variance.csv, comma clear
replace cov_sameyear_elementary_reading=_cov_sameyear_elem_read in -1
replace cov_sameyear_elementary_math=_cov_sameyear_elem_math in -1
outsheet using ${datadir}/tfx/tfx_${tfxdate}_variance_elem_quadextrap_ps.csv, comma replace

* Get mean class size (note: class-weighted, whereas Table 1 is student-weighted)
use ${datadir}/analysis_irsdate${IRSdate}_tfxdate${tfxdate}, clear
sum CLass_size if any_l97==1
local classsize = r(mean)

insheet using ${datadir}/tfx/tfx_${tfxdate}_variance_elem_quadextrap_ps.csv, clear
* Use data for elementary only
mata: onlygroups = 1, 2
	
set seed 15977701

* Give Mata options to policysim ado
mata: nteachers = 1e7
mata: nyears = 16
mata: nstudents = `classsize'
mata: driftlimit = 7
mata: max_futuresumhorizon = 10
mata: cut = 0.05

* Give Mata some numbers
mata: n_obs = st_nobs()
mata: cov_lag = st_data((1, n_obs-1), "cov_lag*")[., onlygroups]
mata: var_total = st_data(n_obs, "var_total*")[., onlygroups]
mata: var_ind = st_data(n_obs, "var_ind*")[., onlygroups]
mata: cov_sameyear = st_data(n_obs, "cov_sameyear*")[., onlygroups]
mata: var_class = var_total - var_ind - cov_sameyear
mata: groups = groups = onlygroups
mata: teacher_variance = cov_sameyear 
mata: other_variance = var_class + var_ind / nstudents

* Simulation for elementary math
mata: i = 2  // 1 is reading and 2 is math - if you change this then change file name on line 80!
mata: teacher_vcv_vector = create_m(cov_lag[.,i], teacher_variance[i], n_obs-1,driftlimit)
mata: other_vcv_vector = create_m(0*cov_lag[.,i], other_variance[i], n_obs-1,driftlimit)
* Truncate vcv vector (we have autocovariance for 19 lags, but we simulate 16 years of data)
mata: teacher_vcv_vector = teacher_vcv_vector[1..nyears]
mata: other_vcv_vector = other_vcv_vector[1..nyears]
mata: teacher_vcv = vectorToStripeDiag(teacher_vcv_vector)
mata: other_vcv = vectorToStripeDiag(other_vcv_vector)
* Draw simulation sample
mata: teacher_simscores = invnormal(uniform(nteachers, cols(teacher_vcv)))*cholesky(teacher_vcv)'
mata: other_simscores = invnormal(uniform(nteachers, cols(other_vcv)))*cholesky(other_vcv)'
mata: simscores = teacher_simscores + other_simscores

* Deselection
mata: decisionyear = 3
mata: predecision = (1::3)
mata: t = 4
mata: weights = computeweights(variance(simscores), t, predecision)
mata: predtv = simscores[.,predecision]*weights'
mata: effecteachyear_nextyear =	mean(select(simscores, predtv:<=mm_quantile(predtv,1,cut)))
mata: effecteachyear_nextyear

* Save to csv
mata: va = teacher_simscores[1..nteachers, t]
mata: deselected = predtv:<=mm_quantile(predtv,1,cut)
mata: A = va, predtv, deselected
mata: mm_outsheet("${datadir}/dist_math.csv", strofreal(A), "replace")

* Count if true VA > median, but estimated VA in bottom 5%
insheet using ${datadir}/dist_math.csv, clear
gen id = _n
ren v1 va
ren v2 predicted_tv
ren v3 deselected
su va, d
gen above_median = va >= r(p50)
tab above_median if deselected
